/* DO NOT EDIT - This file generated automatically by unmarshal_table_c.py script */

/*
 * Copyright (C) 2012 Intel Corporation
 * All Rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sub license,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT.  IN NO EVENT SHALL
 * INTEL CORPORATION,
 * AND/OR THEIR SUPPLIERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
 * OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#include "glthread_marshal.h"

const _mesa_unmarshal_func _mesa_unmarshal_dispatch[NUM_DISPATCH_CMD] = {
   [DISPATCH_CMD_NewList] = (_mesa_unmarshal_func)_mesa_unmarshal_NewList,
   [DISPATCH_CMD_EndList] = (_mesa_unmarshal_func)_mesa_unmarshal_EndList,
   [DISPATCH_CMD_CallList] = (_mesa_unmarshal_func)_mesa_unmarshal_CallList,
   [DISPATCH_CMD_CallLists] = (_mesa_unmarshal_func)_mesa_unmarshal_CallLists,
   [DISPATCH_CMD_DeleteLists] = (_mesa_unmarshal_func)_mesa_unmarshal_DeleteLists,
   [DISPATCH_CMD_ListBase] = (_mesa_unmarshal_func)_mesa_unmarshal_ListBase,
   [DISPATCH_CMD_Begin] = (_mesa_unmarshal_func)_mesa_unmarshal_Begin,
   [DISPATCH_CMD_Bitmap] = (_mesa_unmarshal_func)_mesa_unmarshal_Bitmap,
   [DISPATCH_CMD_Color3b] = (_mesa_unmarshal_func)_mesa_unmarshal_Color3b,
   [DISPATCH_CMD_Color3bv] = (_mesa_unmarshal_func)_mesa_unmarshal_Color3bv,
   [DISPATCH_CMD_Color3d] = (_mesa_unmarshal_func)_mesa_unmarshal_Color3d,
   [DISPATCH_CMD_Color3dv] = (_mesa_unmarshal_func)_mesa_unmarshal_Color3dv,
   [DISPATCH_CMD_Color3f] = (_mesa_unmarshal_func)_mesa_unmarshal_Color3f,
   [DISPATCH_CMD_Color3fv] = (_mesa_unmarshal_func)_mesa_unmarshal_Color3fv,
   [DISPATCH_CMD_Color3i] = (_mesa_unmarshal_func)_mesa_unmarshal_Color3i,
   [DISPATCH_CMD_Color3iv] = (_mesa_unmarshal_func)_mesa_unmarshal_Color3iv,
   [DISPATCH_CMD_Color3s] = (_mesa_unmarshal_func)_mesa_unmarshal_Color3s,
   [DISPATCH_CMD_Color3sv] = (_mesa_unmarshal_func)_mesa_unmarshal_Color3sv,
   [DISPATCH_CMD_Color3ub] = (_mesa_unmarshal_func)_mesa_unmarshal_Color3ub,
   [DISPATCH_CMD_Color3ubv] = (_mesa_unmarshal_func)_mesa_unmarshal_Color3ubv,
   [DISPATCH_CMD_Color3ui] = (_mesa_unmarshal_func)_mesa_unmarshal_Color3ui,
   [DISPATCH_CMD_Color3uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_Color3uiv,
   [DISPATCH_CMD_Color3us] = (_mesa_unmarshal_func)_mesa_unmarshal_Color3us,
   [DISPATCH_CMD_Color3usv] = (_mesa_unmarshal_func)_mesa_unmarshal_Color3usv,
   [DISPATCH_CMD_Color4b] = (_mesa_unmarshal_func)_mesa_unmarshal_Color4b,
   [DISPATCH_CMD_Color4bv] = (_mesa_unmarshal_func)_mesa_unmarshal_Color4bv,
   [DISPATCH_CMD_Color4d] = (_mesa_unmarshal_func)_mesa_unmarshal_Color4d,
   [DISPATCH_CMD_Color4dv] = (_mesa_unmarshal_func)_mesa_unmarshal_Color4dv,
   [DISPATCH_CMD_Color4f] = (_mesa_unmarshal_func)_mesa_unmarshal_Color4f,
   [DISPATCH_CMD_Color4fv] = (_mesa_unmarshal_func)_mesa_unmarshal_Color4fv,
   [DISPATCH_CMD_Color4i] = (_mesa_unmarshal_func)_mesa_unmarshal_Color4i,
   [DISPATCH_CMD_Color4iv] = (_mesa_unmarshal_func)_mesa_unmarshal_Color4iv,
   [DISPATCH_CMD_Color4s] = (_mesa_unmarshal_func)_mesa_unmarshal_Color4s,
   [DISPATCH_CMD_Color4sv] = (_mesa_unmarshal_func)_mesa_unmarshal_Color4sv,
   [DISPATCH_CMD_Color4ub] = (_mesa_unmarshal_func)_mesa_unmarshal_Color4ub,
   [DISPATCH_CMD_Color4ubv] = (_mesa_unmarshal_func)_mesa_unmarshal_Color4ubv,
   [DISPATCH_CMD_Color4ui] = (_mesa_unmarshal_func)_mesa_unmarshal_Color4ui,
   [DISPATCH_CMD_Color4uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_Color4uiv,
   [DISPATCH_CMD_Color4us] = (_mesa_unmarshal_func)_mesa_unmarshal_Color4us,
   [DISPATCH_CMD_Color4usv] = (_mesa_unmarshal_func)_mesa_unmarshal_Color4usv,
   [DISPATCH_CMD_EdgeFlag] = (_mesa_unmarshal_func)_mesa_unmarshal_EdgeFlag,
   [DISPATCH_CMD_EdgeFlagv] = (_mesa_unmarshal_func)_mesa_unmarshal_EdgeFlagv,
   [DISPATCH_CMD_End] = (_mesa_unmarshal_func)_mesa_unmarshal_End,
   [DISPATCH_CMD_Indexd] = (_mesa_unmarshal_func)_mesa_unmarshal_Indexd,
   [DISPATCH_CMD_Indexdv] = (_mesa_unmarshal_func)_mesa_unmarshal_Indexdv,
   [DISPATCH_CMD_Indexf] = (_mesa_unmarshal_func)_mesa_unmarshal_Indexf,
   [DISPATCH_CMD_Indexfv] = (_mesa_unmarshal_func)_mesa_unmarshal_Indexfv,
   [DISPATCH_CMD_Indexi] = (_mesa_unmarshal_func)_mesa_unmarshal_Indexi,
   [DISPATCH_CMD_Indexiv] = (_mesa_unmarshal_func)_mesa_unmarshal_Indexiv,
   [DISPATCH_CMD_Indexs] = (_mesa_unmarshal_func)_mesa_unmarshal_Indexs,
   [DISPATCH_CMD_Indexsv] = (_mesa_unmarshal_func)_mesa_unmarshal_Indexsv,
   [DISPATCH_CMD_Normal3b] = (_mesa_unmarshal_func)_mesa_unmarshal_Normal3b,
   [DISPATCH_CMD_Normal3bv] = (_mesa_unmarshal_func)_mesa_unmarshal_Normal3bv,
   [DISPATCH_CMD_Normal3d] = (_mesa_unmarshal_func)_mesa_unmarshal_Normal3d,
   [DISPATCH_CMD_Normal3dv] = (_mesa_unmarshal_func)_mesa_unmarshal_Normal3dv,
   [DISPATCH_CMD_Normal3f] = (_mesa_unmarshal_func)_mesa_unmarshal_Normal3f,
   [DISPATCH_CMD_Normal3fv] = (_mesa_unmarshal_func)_mesa_unmarshal_Normal3fv,
   [DISPATCH_CMD_Normal3i] = (_mesa_unmarshal_func)_mesa_unmarshal_Normal3i,
   [DISPATCH_CMD_Normal3iv] = (_mesa_unmarshal_func)_mesa_unmarshal_Normal3iv,
   [DISPATCH_CMD_Normal3s] = (_mesa_unmarshal_func)_mesa_unmarshal_Normal3s,
   [DISPATCH_CMD_Normal3sv] = (_mesa_unmarshal_func)_mesa_unmarshal_Normal3sv,
   [DISPATCH_CMD_RasterPos2d] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos2d,
   [DISPATCH_CMD_RasterPos2dv] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos2dv,
   [DISPATCH_CMD_RasterPos2f] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos2f,
   [DISPATCH_CMD_RasterPos2fv] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos2fv,
   [DISPATCH_CMD_RasterPos2i] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos2i,
   [DISPATCH_CMD_RasterPos2iv] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos2iv,
   [DISPATCH_CMD_RasterPos2s] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos2s,
   [DISPATCH_CMD_RasterPos2sv] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos2sv,
   [DISPATCH_CMD_RasterPos3d] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos3d,
   [DISPATCH_CMD_RasterPos3dv] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos3dv,
   [DISPATCH_CMD_RasterPos3f] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos3f,
   [DISPATCH_CMD_RasterPos3fv] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos3fv,
   [DISPATCH_CMD_RasterPos3i] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos3i,
   [DISPATCH_CMD_RasterPos3iv] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos3iv,
   [DISPATCH_CMD_RasterPos3s] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos3s,
   [DISPATCH_CMD_RasterPos3sv] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos3sv,
   [DISPATCH_CMD_RasterPos4d] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos4d,
   [DISPATCH_CMD_RasterPos4dv] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos4dv,
   [DISPATCH_CMD_RasterPos4f] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos4f,
   [DISPATCH_CMD_RasterPos4fv] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos4fv,
   [DISPATCH_CMD_RasterPos4i] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos4i,
   [DISPATCH_CMD_RasterPos4iv] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos4iv,
   [DISPATCH_CMD_RasterPos4s] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos4s,
   [DISPATCH_CMD_RasterPos4sv] = (_mesa_unmarshal_func)_mesa_unmarshal_RasterPos4sv,
   [DISPATCH_CMD_Rectd] = (_mesa_unmarshal_func)_mesa_unmarshal_Rectd,
   [DISPATCH_CMD_Rectdv] = (_mesa_unmarshal_func)_mesa_unmarshal_Rectdv,
   [DISPATCH_CMD_Rectf] = (_mesa_unmarshal_func)_mesa_unmarshal_Rectf,
   [DISPATCH_CMD_Rectfv] = (_mesa_unmarshal_func)_mesa_unmarshal_Rectfv,
   [DISPATCH_CMD_Recti] = (_mesa_unmarshal_func)_mesa_unmarshal_Recti,
   [DISPATCH_CMD_Rectiv] = (_mesa_unmarshal_func)_mesa_unmarshal_Rectiv,
   [DISPATCH_CMD_Rects] = (_mesa_unmarshal_func)_mesa_unmarshal_Rects,
   [DISPATCH_CMD_Rectsv] = (_mesa_unmarshal_func)_mesa_unmarshal_Rectsv,
   [DISPATCH_CMD_TexCoord1d] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord1d,
   [DISPATCH_CMD_TexCoord1dv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord1dv,
   [DISPATCH_CMD_TexCoord1f] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord1f,
   [DISPATCH_CMD_TexCoord1fv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord1fv,
   [DISPATCH_CMD_TexCoord1i] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord1i,
   [DISPATCH_CMD_TexCoord1iv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord1iv,
   [DISPATCH_CMD_TexCoord1s] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord1s,
   [DISPATCH_CMD_TexCoord1sv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord1sv,
   [DISPATCH_CMD_TexCoord2d] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord2d,
   [DISPATCH_CMD_TexCoord2dv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord2dv,
   [DISPATCH_CMD_TexCoord2f] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord2f,
   [DISPATCH_CMD_TexCoord2fv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord2fv,
   [DISPATCH_CMD_TexCoord2i] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord2i,
   [DISPATCH_CMD_TexCoord2iv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord2iv,
   [DISPATCH_CMD_TexCoord2s] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord2s,
   [DISPATCH_CMD_TexCoord2sv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord2sv,
   [DISPATCH_CMD_TexCoord3d] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord3d,
   [DISPATCH_CMD_TexCoord3dv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord3dv,
   [DISPATCH_CMD_TexCoord3f] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord3f,
   [DISPATCH_CMD_TexCoord3fv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord3fv,
   [DISPATCH_CMD_TexCoord3i] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord3i,
   [DISPATCH_CMD_TexCoord3iv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord3iv,
   [DISPATCH_CMD_TexCoord3s] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord3s,
   [DISPATCH_CMD_TexCoord3sv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord3sv,
   [DISPATCH_CMD_TexCoord4d] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord4d,
   [DISPATCH_CMD_TexCoord4dv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord4dv,
   [DISPATCH_CMD_TexCoord4f] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord4f,
   [DISPATCH_CMD_TexCoord4fv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord4fv,
   [DISPATCH_CMD_TexCoord4i] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord4i,
   [DISPATCH_CMD_TexCoord4iv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord4iv,
   [DISPATCH_CMD_TexCoord4s] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord4s,
   [DISPATCH_CMD_TexCoord4sv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord4sv,
   [DISPATCH_CMD_Vertex2d] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex2d,
   [DISPATCH_CMD_Vertex2dv] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex2dv,
   [DISPATCH_CMD_Vertex2f] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex2f,
   [DISPATCH_CMD_Vertex2fv] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex2fv,
   [DISPATCH_CMD_Vertex2i] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex2i,
   [DISPATCH_CMD_Vertex2iv] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex2iv,
   [DISPATCH_CMD_Vertex2s] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex2s,
   [DISPATCH_CMD_Vertex2sv] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex2sv,
   [DISPATCH_CMD_Vertex3d] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex3d,
   [DISPATCH_CMD_Vertex3dv] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex3dv,
   [DISPATCH_CMD_Vertex3f] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex3f,
   [DISPATCH_CMD_Vertex3fv] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex3fv,
   [DISPATCH_CMD_Vertex3i] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex3i,
   [DISPATCH_CMD_Vertex3iv] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex3iv,
   [DISPATCH_CMD_Vertex3s] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex3s,
   [DISPATCH_CMD_Vertex3sv] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex3sv,
   [DISPATCH_CMD_Vertex4d] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex4d,
   [DISPATCH_CMD_Vertex4dv] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex4dv,
   [DISPATCH_CMD_Vertex4f] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex4f,
   [DISPATCH_CMD_Vertex4fv] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex4fv,
   [DISPATCH_CMD_Vertex4i] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex4i,
   [DISPATCH_CMD_Vertex4iv] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex4iv,
   [DISPATCH_CMD_Vertex4s] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex4s,
   [DISPATCH_CMD_Vertex4sv] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex4sv,
   [DISPATCH_CMD_ClipPlane] = (_mesa_unmarshal_func)_mesa_unmarshal_ClipPlane,
   [DISPATCH_CMD_ColorMaterial] = (_mesa_unmarshal_func)_mesa_unmarshal_ColorMaterial,
   [DISPATCH_CMD_CullFace] = (_mesa_unmarshal_func)_mesa_unmarshal_CullFace,
   [DISPATCH_CMD_Fogf] = (_mesa_unmarshal_func)_mesa_unmarshal_Fogf,
   [DISPATCH_CMD_Fogfv] = (_mesa_unmarshal_func)_mesa_unmarshal_Fogfv,
   [DISPATCH_CMD_Fogi] = (_mesa_unmarshal_func)_mesa_unmarshal_Fogi,
   [DISPATCH_CMD_Fogiv] = (_mesa_unmarshal_func)_mesa_unmarshal_Fogiv,
   [DISPATCH_CMD_FrontFace] = (_mesa_unmarshal_func)_mesa_unmarshal_FrontFace,
   [DISPATCH_CMD_Hint] = (_mesa_unmarshal_func)_mesa_unmarshal_Hint,
   [DISPATCH_CMD_Lightf] = (_mesa_unmarshal_func)_mesa_unmarshal_Lightf,
   [DISPATCH_CMD_Lightfv] = (_mesa_unmarshal_func)_mesa_unmarshal_Lightfv,
   [DISPATCH_CMD_Lighti] = (_mesa_unmarshal_func)_mesa_unmarshal_Lighti,
   [DISPATCH_CMD_Lightiv] = (_mesa_unmarshal_func)_mesa_unmarshal_Lightiv,
   [DISPATCH_CMD_LightModelf] = (_mesa_unmarshal_func)_mesa_unmarshal_LightModelf,
   [DISPATCH_CMD_LightModelfv] = (_mesa_unmarshal_func)_mesa_unmarshal_LightModelfv,
   [DISPATCH_CMD_LightModeli] = (_mesa_unmarshal_func)_mesa_unmarshal_LightModeli,
   [DISPATCH_CMD_LightModeliv] = (_mesa_unmarshal_func)_mesa_unmarshal_LightModeliv,
   [DISPATCH_CMD_LineStipple] = (_mesa_unmarshal_func)_mesa_unmarshal_LineStipple,
   [DISPATCH_CMD_LineWidth] = (_mesa_unmarshal_func)_mesa_unmarshal_LineWidth,
   [DISPATCH_CMD_Materialf] = (_mesa_unmarshal_func)_mesa_unmarshal_Materialf,
   [DISPATCH_CMD_Materialfv] = (_mesa_unmarshal_func)_mesa_unmarshal_Materialfv,
   [DISPATCH_CMD_Materiali] = (_mesa_unmarshal_func)_mesa_unmarshal_Materiali,
   [DISPATCH_CMD_Materialiv] = (_mesa_unmarshal_func)_mesa_unmarshal_Materialiv,
   [DISPATCH_CMD_PointSize] = (_mesa_unmarshal_func)_mesa_unmarshal_PointSize,
   [DISPATCH_CMD_PolygonMode] = (_mesa_unmarshal_func)_mesa_unmarshal_PolygonMode,
   [DISPATCH_CMD_PolygonStipple] = (_mesa_unmarshal_func)_mesa_unmarshal_PolygonStipple,
   [DISPATCH_CMD_Scissor] = (_mesa_unmarshal_func)_mesa_unmarshal_Scissor,
   [DISPATCH_CMD_ShadeModel] = (_mesa_unmarshal_func)_mesa_unmarshal_ShadeModel,
   [DISPATCH_CMD_TexParameterf] = (_mesa_unmarshal_func)_mesa_unmarshal_TexParameterf,
   [DISPATCH_CMD_TexParameterfv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexParameterfv,
   [DISPATCH_CMD_TexParameteri] = (_mesa_unmarshal_func)_mesa_unmarshal_TexParameteri,
   [DISPATCH_CMD_TexParameteriv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexParameteriv,
   [DISPATCH_CMD_TexImage1D] = (_mesa_unmarshal_func)_mesa_unmarshal_TexImage1D,
   [DISPATCH_CMD_TexImage2D] = (_mesa_unmarshal_func)_mesa_unmarshal_TexImage2D,
   [DISPATCH_CMD_TexEnvf] = (_mesa_unmarshal_func)_mesa_unmarshal_TexEnvf,
   [DISPATCH_CMD_TexEnvfv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexEnvfv,
   [DISPATCH_CMD_TexEnvi] = (_mesa_unmarshal_func)_mesa_unmarshal_TexEnvi,
   [DISPATCH_CMD_TexEnviv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexEnviv,
   [DISPATCH_CMD_TexGend] = (_mesa_unmarshal_func)_mesa_unmarshal_TexGend,
   [DISPATCH_CMD_TexGendv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexGendv,
   [DISPATCH_CMD_TexGenf] = (_mesa_unmarshal_func)_mesa_unmarshal_TexGenf,
   [DISPATCH_CMD_TexGenfv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexGenfv,
   [DISPATCH_CMD_TexGeni] = (_mesa_unmarshal_func)_mesa_unmarshal_TexGeni,
   [DISPATCH_CMD_TexGeniv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexGeniv,
   [DISPATCH_CMD_InitNames] = (_mesa_unmarshal_func)_mesa_unmarshal_InitNames,
   [DISPATCH_CMD_LoadName] = (_mesa_unmarshal_func)_mesa_unmarshal_LoadName,
   [DISPATCH_CMD_PassThrough] = (_mesa_unmarshal_func)_mesa_unmarshal_PassThrough,
   [DISPATCH_CMD_PopName] = (_mesa_unmarshal_func)_mesa_unmarshal_PopName,
   [DISPATCH_CMD_PushName] = (_mesa_unmarshal_func)_mesa_unmarshal_PushName,
   [DISPATCH_CMD_DrawBuffer] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawBuffer,
   [DISPATCH_CMD_Clear] = (_mesa_unmarshal_func)_mesa_unmarshal_Clear,
   [DISPATCH_CMD_ClearAccum] = (_mesa_unmarshal_func)_mesa_unmarshal_ClearAccum,
   [DISPATCH_CMD_ClearIndex] = (_mesa_unmarshal_func)_mesa_unmarshal_ClearIndex,
   [DISPATCH_CMD_ClearColor] = (_mesa_unmarshal_func)_mesa_unmarshal_ClearColor,
   [DISPATCH_CMD_ClearStencil] = (_mesa_unmarshal_func)_mesa_unmarshal_ClearStencil,
   [DISPATCH_CMD_ClearDepth] = (_mesa_unmarshal_func)_mesa_unmarshal_ClearDepth,
   [DISPATCH_CMD_StencilMask] = (_mesa_unmarshal_func)_mesa_unmarshal_StencilMask,
   [DISPATCH_CMD_ColorMask] = (_mesa_unmarshal_func)_mesa_unmarshal_ColorMask,
   [DISPATCH_CMD_DepthMask] = (_mesa_unmarshal_func)_mesa_unmarshal_DepthMask,
   [DISPATCH_CMD_IndexMask] = (_mesa_unmarshal_func)_mesa_unmarshal_IndexMask,
   [DISPATCH_CMD_Accum] = (_mesa_unmarshal_func)_mesa_unmarshal_Accum,
   [DISPATCH_CMD_Disable] = (_mesa_unmarshal_func)_mesa_unmarshal_Disable,
   [DISPATCH_CMD_Enable] = (_mesa_unmarshal_func)_mesa_unmarshal_Enable,
   [DISPATCH_CMD_Flush] = (_mesa_unmarshal_func)_mesa_unmarshal_Flush,
   [DISPATCH_CMD_PopAttrib] = (_mesa_unmarshal_func)_mesa_unmarshal_PopAttrib,
   [DISPATCH_CMD_PushAttrib] = (_mesa_unmarshal_func)_mesa_unmarshal_PushAttrib,
   [DISPATCH_CMD_MapGrid1d] = (_mesa_unmarshal_func)_mesa_unmarshal_MapGrid1d,
   [DISPATCH_CMD_MapGrid1f] = (_mesa_unmarshal_func)_mesa_unmarshal_MapGrid1f,
   [DISPATCH_CMD_MapGrid2d] = (_mesa_unmarshal_func)_mesa_unmarshal_MapGrid2d,
   [DISPATCH_CMD_MapGrid2f] = (_mesa_unmarshal_func)_mesa_unmarshal_MapGrid2f,
   [DISPATCH_CMD_EvalCoord1d] = (_mesa_unmarshal_func)_mesa_unmarshal_EvalCoord1d,
   [DISPATCH_CMD_EvalCoord1dv] = (_mesa_unmarshal_func)_mesa_unmarshal_EvalCoord1dv,
   [DISPATCH_CMD_EvalCoord1f] = (_mesa_unmarshal_func)_mesa_unmarshal_EvalCoord1f,
   [DISPATCH_CMD_EvalCoord1fv] = (_mesa_unmarshal_func)_mesa_unmarshal_EvalCoord1fv,
   [DISPATCH_CMD_EvalCoord2d] = (_mesa_unmarshal_func)_mesa_unmarshal_EvalCoord2d,
   [DISPATCH_CMD_EvalCoord2dv] = (_mesa_unmarshal_func)_mesa_unmarshal_EvalCoord2dv,
   [DISPATCH_CMD_EvalCoord2f] = (_mesa_unmarshal_func)_mesa_unmarshal_EvalCoord2f,
   [DISPATCH_CMD_EvalCoord2fv] = (_mesa_unmarshal_func)_mesa_unmarshal_EvalCoord2fv,
   [DISPATCH_CMD_EvalMesh1] = (_mesa_unmarshal_func)_mesa_unmarshal_EvalMesh1,
   [DISPATCH_CMD_EvalPoint1] = (_mesa_unmarshal_func)_mesa_unmarshal_EvalPoint1,
   [DISPATCH_CMD_EvalMesh2] = (_mesa_unmarshal_func)_mesa_unmarshal_EvalMesh2,
   [DISPATCH_CMD_EvalPoint2] = (_mesa_unmarshal_func)_mesa_unmarshal_EvalPoint2,
   [DISPATCH_CMD_AlphaFunc] = (_mesa_unmarshal_func)_mesa_unmarshal_AlphaFunc,
   [DISPATCH_CMD_BlendFunc] = (_mesa_unmarshal_func)_mesa_unmarshal_BlendFunc,
   [DISPATCH_CMD_LogicOp] = (_mesa_unmarshal_func)_mesa_unmarshal_LogicOp,
   [DISPATCH_CMD_StencilFunc] = (_mesa_unmarshal_func)_mesa_unmarshal_StencilFunc,
   [DISPATCH_CMD_StencilOp] = (_mesa_unmarshal_func)_mesa_unmarshal_StencilOp,
   [DISPATCH_CMD_DepthFunc] = (_mesa_unmarshal_func)_mesa_unmarshal_DepthFunc,
   [DISPATCH_CMD_PixelZoom] = (_mesa_unmarshal_func)_mesa_unmarshal_PixelZoom,
   [DISPATCH_CMD_PixelTransferf] = (_mesa_unmarshal_func)_mesa_unmarshal_PixelTransferf,
   [DISPATCH_CMD_PixelTransferi] = (_mesa_unmarshal_func)_mesa_unmarshal_PixelTransferi,
   [DISPATCH_CMD_PixelStoref] = (_mesa_unmarshal_func)_mesa_unmarshal_PixelStoref,
   [DISPATCH_CMD_PixelStorei] = (_mesa_unmarshal_func)_mesa_unmarshal_PixelStorei,
   [DISPATCH_CMD_PixelMapfv] = (_mesa_unmarshal_func)_mesa_unmarshal_PixelMapfv,
   [DISPATCH_CMD_PixelMapuiv] = (_mesa_unmarshal_func)_mesa_unmarshal_PixelMapuiv,
   [DISPATCH_CMD_PixelMapusv] = (_mesa_unmarshal_func)_mesa_unmarshal_PixelMapusv,
   [DISPATCH_CMD_ReadBuffer] = (_mesa_unmarshal_func)_mesa_unmarshal_ReadBuffer,
   [DISPATCH_CMD_CopyPixels] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyPixels,
   [DISPATCH_CMD_ReadPixels] = (_mesa_unmarshal_func)_mesa_unmarshal_ReadPixels,
   [DISPATCH_CMD_DrawPixels] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawPixels,
   [DISPATCH_CMD_GetIntegerv] = (_mesa_unmarshal_func)_mesa_unmarshal_GetIntegerv,
   [DISPATCH_CMD_GetPixelMapfv] = (_mesa_unmarshal_func)_mesa_unmarshal_GetPixelMapfv,
   [DISPATCH_CMD_GetPixelMapuiv] = (_mesa_unmarshal_func)_mesa_unmarshal_GetPixelMapuiv,
   [DISPATCH_CMD_GetPixelMapusv] = (_mesa_unmarshal_func)_mesa_unmarshal_GetPixelMapusv,
   [DISPATCH_CMD_GetPolygonStipple] = (_mesa_unmarshal_func)_mesa_unmarshal_GetPolygonStipple,
   [DISPATCH_CMD_GetTexImage] = (_mesa_unmarshal_func)_mesa_unmarshal_GetTexImage,
   [DISPATCH_CMD_DepthRange] = (_mesa_unmarshal_func)_mesa_unmarshal_DepthRange,
   [DISPATCH_CMD_Frustum] = (_mesa_unmarshal_func)_mesa_unmarshal_Frustum,
   [DISPATCH_CMD_LoadIdentity] = (_mesa_unmarshal_func)_mesa_unmarshal_LoadIdentity,
   [DISPATCH_CMD_LoadMatrixf] = (_mesa_unmarshal_func)_mesa_unmarshal_LoadMatrixf,
   [DISPATCH_CMD_LoadMatrixd] = (_mesa_unmarshal_func)_mesa_unmarshal_LoadMatrixd,
   [DISPATCH_CMD_MatrixMode] = (_mesa_unmarshal_func)_mesa_unmarshal_MatrixMode,
   [DISPATCH_CMD_MultMatrixf] = (_mesa_unmarshal_func)_mesa_unmarshal_MultMatrixf,
   [DISPATCH_CMD_MultMatrixd] = (_mesa_unmarshal_func)_mesa_unmarshal_MultMatrixd,
   [DISPATCH_CMD_Ortho] = (_mesa_unmarshal_func)_mesa_unmarshal_Ortho,
   [DISPATCH_CMD_PopMatrix] = (_mesa_unmarshal_func)_mesa_unmarshal_PopMatrix,
   [DISPATCH_CMD_PushMatrix] = (_mesa_unmarshal_func)_mesa_unmarshal_PushMatrix,
   [DISPATCH_CMD_Rotated] = (_mesa_unmarshal_func)_mesa_unmarshal_Rotated,
   [DISPATCH_CMD_Rotatef] = (_mesa_unmarshal_func)_mesa_unmarshal_Rotatef,
   [DISPATCH_CMD_Scaled] = (_mesa_unmarshal_func)_mesa_unmarshal_Scaled,
   [DISPATCH_CMD_Scalef] = (_mesa_unmarshal_func)_mesa_unmarshal_Scalef,
   [DISPATCH_CMD_Translated] = (_mesa_unmarshal_func)_mesa_unmarshal_Translated,
   [DISPATCH_CMD_Translatef] = (_mesa_unmarshal_func)_mesa_unmarshal_Translatef,
   [DISPATCH_CMD_Viewport] = (_mesa_unmarshal_func)_mesa_unmarshal_Viewport,
   [DISPATCH_CMD_ColorPointer] = (_mesa_unmarshal_func)_mesa_unmarshal_ColorPointer,
   [DISPATCH_CMD_DisableClientState] = (_mesa_unmarshal_func)_mesa_unmarshal_DisableClientState,
   [DISPATCH_CMD_DrawArrays] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawArrays,
   [DISPATCH_CMD_DrawElements] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawElements,
   [DISPATCH_CMD_EdgeFlagPointer] = (_mesa_unmarshal_func)_mesa_unmarshal_EdgeFlagPointer,
   [DISPATCH_CMD_EnableClientState] = (_mesa_unmarshal_func)_mesa_unmarshal_EnableClientState,
   [DISPATCH_CMD_IndexPointer] = (_mesa_unmarshal_func)_mesa_unmarshal_IndexPointer,
   [DISPATCH_CMD_InterleavedArrays] = (_mesa_unmarshal_func)_mesa_unmarshal_InterleavedArrays,
   [DISPATCH_CMD_NormalPointer] = (_mesa_unmarshal_func)_mesa_unmarshal_NormalPointer,
   [DISPATCH_CMD_TexCoordPointer] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoordPointer,
   [DISPATCH_CMD_VertexPointer] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexPointer,
   [DISPATCH_CMD_PolygonOffset] = (_mesa_unmarshal_func)_mesa_unmarshal_PolygonOffset,
   [DISPATCH_CMD_CopyTexImage1D] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyTexImage1D,
   [DISPATCH_CMD_CopyTexImage2D] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyTexImage2D,
   [DISPATCH_CMD_CopyTexSubImage1D] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyTexSubImage1D,
   [DISPATCH_CMD_CopyTexSubImage2D] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyTexSubImage2D,
   [DISPATCH_CMD_TexSubImage1D] = (_mesa_unmarshal_func)_mesa_unmarshal_TexSubImage1D,
   [DISPATCH_CMD_TexSubImage2D] = (_mesa_unmarshal_func)_mesa_unmarshal_TexSubImage2D,
   [DISPATCH_CMD_BindTexture] = (_mesa_unmarshal_func)_mesa_unmarshal_BindTexture,
   [DISPATCH_CMD_DeleteTextures] = (_mesa_unmarshal_func)_mesa_unmarshal_DeleteTextures,
   [DISPATCH_CMD_PrioritizeTextures] = (_mesa_unmarshal_func)_mesa_unmarshal_PrioritizeTextures,
   [DISPATCH_CMD_Indexub] = (_mesa_unmarshal_func)_mesa_unmarshal_Indexub,
   [DISPATCH_CMD_Indexubv] = (_mesa_unmarshal_func)_mesa_unmarshal_Indexubv,
   [DISPATCH_CMD_PopClientAttrib] = (_mesa_unmarshal_func)_mesa_unmarshal_PopClientAttrib,
   [DISPATCH_CMD_PushClientAttrib] = (_mesa_unmarshal_func)_mesa_unmarshal_PushClientAttrib,
   [DISPATCH_CMD_BlendColor] = (_mesa_unmarshal_func)_mesa_unmarshal_BlendColor,
   [DISPATCH_CMD_BlendEquation] = (_mesa_unmarshal_func)_mesa_unmarshal_BlendEquation,
   [DISPATCH_CMD_DrawRangeElements] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawRangeElements,
   [DISPATCH_CMD_TexImage3D] = (_mesa_unmarshal_func)_mesa_unmarshal_TexImage3D,
   [DISPATCH_CMD_TexSubImage3D] = (_mesa_unmarshal_func)_mesa_unmarshal_TexSubImage3D,
   [DISPATCH_CMD_CopyTexSubImage3D] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyTexSubImage3D,
   [DISPATCH_CMD_ActiveTexture] = (_mesa_unmarshal_func)_mesa_unmarshal_ActiveTexture,
   [DISPATCH_CMD_ClientActiveTexture] = (_mesa_unmarshal_func)_mesa_unmarshal_ClientActiveTexture,
   [DISPATCH_CMD_MultiTexCoord1d] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord1d,
   [DISPATCH_CMD_MultiTexCoord1dv] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord1dv,
   [DISPATCH_CMD_MultiTexCoord1fARB] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord1fARB,
   [DISPATCH_CMD_MultiTexCoord1fvARB] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord1fvARB,
   [DISPATCH_CMD_MultiTexCoord1i] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord1i,
   [DISPATCH_CMD_MultiTexCoord1iv] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord1iv,
   [DISPATCH_CMD_MultiTexCoord1s] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord1s,
   [DISPATCH_CMD_MultiTexCoord1sv] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord1sv,
   [DISPATCH_CMD_MultiTexCoord2d] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord2d,
   [DISPATCH_CMD_MultiTexCoord2dv] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord2dv,
   [DISPATCH_CMD_MultiTexCoord2fARB] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord2fARB,
   [DISPATCH_CMD_MultiTexCoord2fvARB] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord2fvARB,
   [DISPATCH_CMD_MultiTexCoord2i] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord2i,
   [DISPATCH_CMD_MultiTexCoord2iv] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord2iv,
   [DISPATCH_CMD_MultiTexCoord2s] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord2s,
   [DISPATCH_CMD_MultiTexCoord2sv] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord2sv,
   [DISPATCH_CMD_MultiTexCoord3d] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord3d,
   [DISPATCH_CMD_MultiTexCoord3dv] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord3dv,
   [DISPATCH_CMD_MultiTexCoord3fARB] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord3fARB,
   [DISPATCH_CMD_MultiTexCoord3fvARB] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord3fvARB,
   [DISPATCH_CMD_MultiTexCoord3i] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord3i,
   [DISPATCH_CMD_MultiTexCoord3iv] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord3iv,
   [DISPATCH_CMD_MultiTexCoord3s] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord3s,
   [DISPATCH_CMD_MultiTexCoord3sv] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord3sv,
   [DISPATCH_CMD_MultiTexCoord4d] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord4d,
   [DISPATCH_CMD_MultiTexCoord4dv] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord4dv,
   [DISPATCH_CMD_MultiTexCoord4fARB] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord4fARB,
   [DISPATCH_CMD_MultiTexCoord4fvARB] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord4fvARB,
   [DISPATCH_CMD_MultiTexCoord4i] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord4i,
   [DISPATCH_CMD_MultiTexCoord4iv] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord4iv,
   [DISPATCH_CMD_MultiTexCoord4s] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord4s,
   [DISPATCH_CMD_MultiTexCoord4sv] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord4sv,
   [DISPATCH_CMD_LoadTransposeMatrixf] = (_mesa_unmarshal_func)_mesa_unmarshal_LoadTransposeMatrixf,
   [DISPATCH_CMD_LoadTransposeMatrixd] = (_mesa_unmarshal_func)_mesa_unmarshal_LoadTransposeMatrixd,
   [DISPATCH_CMD_MultTransposeMatrixf] = (_mesa_unmarshal_func)_mesa_unmarshal_MultTransposeMatrixf,
   [DISPATCH_CMD_MultTransposeMatrixd] = (_mesa_unmarshal_func)_mesa_unmarshal_MultTransposeMatrixd,
   [DISPATCH_CMD_SampleCoverage] = (_mesa_unmarshal_func)_mesa_unmarshal_SampleCoverage,
   [DISPATCH_CMD_CompressedTexImage3D] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedTexImage3D,
   [DISPATCH_CMD_CompressedTexImage2D] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedTexImage2D,
   [DISPATCH_CMD_CompressedTexImage1D] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedTexImage1D,
   [DISPATCH_CMD_CompressedTexSubImage3D] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedTexSubImage3D,
   [DISPATCH_CMD_CompressedTexSubImage2D] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedTexSubImage2D,
   [DISPATCH_CMD_CompressedTexSubImage1D] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedTexSubImage1D,
   [DISPATCH_CMD_GetCompressedTexImage] = (_mesa_unmarshal_func)_mesa_unmarshal_GetCompressedTexImage,
   [DISPATCH_CMD_BlendFuncSeparate] = (_mesa_unmarshal_func)_mesa_unmarshal_BlendFuncSeparate,
   [DISPATCH_CMD_FogCoordfEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_FogCoordfEXT,
   [DISPATCH_CMD_FogCoordfvEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_FogCoordfvEXT,
   [DISPATCH_CMD_FogCoordd] = (_mesa_unmarshal_func)_mesa_unmarshal_FogCoordd,
   [DISPATCH_CMD_FogCoorddv] = (_mesa_unmarshal_func)_mesa_unmarshal_FogCoorddv,
   [DISPATCH_CMD_FogCoordPointer] = (_mesa_unmarshal_func)_mesa_unmarshal_FogCoordPointer,
   [DISPATCH_CMD_MultiDrawArrays] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiDrawArrays,
   [DISPATCH_CMD_MultiDrawElements] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiDrawElements,
   [DISPATCH_CMD_PointParameterf] = (_mesa_unmarshal_func)_mesa_unmarshal_PointParameterf,
   [DISPATCH_CMD_PointParameterfv] = (_mesa_unmarshal_func)_mesa_unmarshal_PointParameterfv,
   [DISPATCH_CMD_PointParameteri] = (_mesa_unmarshal_func)_mesa_unmarshal_PointParameteri,
   [DISPATCH_CMD_PointParameteriv] = (_mesa_unmarshal_func)_mesa_unmarshal_PointParameteriv,
   [DISPATCH_CMD_SecondaryColor3b] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColor3b,
   [DISPATCH_CMD_SecondaryColor3bv] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColor3bv,
   [DISPATCH_CMD_SecondaryColor3d] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColor3d,
   [DISPATCH_CMD_SecondaryColor3dv] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColor3dv,
   [DISPATCH_CMD_SecondaryColor3fEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColor3fEXT,
   [DISPATCH_CMD_SecondaryColor3fvEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColor3fvEXT,
   [DISPATCH_CMD_SecondaryColor3i] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColor3i,
   [DISPATCH_CMD_SecondaryColor3iv] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColor3iv,
   [DISPATCH_CMD_SecondaryColor3s] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColor3s,
   [DISPATCH_CMD_SecondaryColor3sv] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColor3sv,
   [DISPATCH_CMD_SecondaryColor3ub] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColor3ub,
   [DISPATCH_CMD_SecondaryColor3ubv] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColor3ubv,
   [DISPATCH_CMD_SecondaryColor3ui] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColor3ui,
   [DISPATCH_CMD_SecondaryColor3uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColor3uiv,
   [DISPATCH_CMD_SecondaryColor3us] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColor3us,
   [DISPATCH_CMD_SecondaryColor3usv] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColor3usv,
   [DISPATCH_CMD_SecondaryColorPointer] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColorPointer,
   [DISPATCH_CMD_WindowPos2d] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos2d,
   [DISPATCH_CMD_WindowPos2dv] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos2dv,
   [DISPATCH_CMD_WindowPos2f] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos2f,
   [DISPATCH_CMD_WindowPos2fv] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos2fv,
   [DISPATCH_CMD_WindowPos2i] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos2i,
   [DISPATCH_CMD_WindowPos2iv] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos2iv,
   [DISPATCH_CMD_WindowPos2s] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos2s,
   [DISPATCH_CMD_WindowPos2sv] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos2sv,
   [DISPATCH_CMD_WindowPos3d] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos3d,
   [DISPATCH_CMD_WindowPos3dv] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos3dv,
   [DISPATCH_CMD_WindowPos3f] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos3f,
   [DISPATCH_CMD_WindowPos3fv] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos3fv,
   [DISPATCH_CMD_WindowPos3i] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos3i,
   [DISPATCH_CMD_WindowPos3iv] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos3iv,
   [DISPATCH_CMD_WindowPos3s] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos3s,
   [DISPATCH_CMD_WindowPos3sv] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos3sv,
   [DISPATCH_CMD_BindBuffer] = (_mesa_unmarshal_func)_mesa_unmarshal_BindBuffer,
   [DISPATCH_CMD_BufferData] = (_mesa_unmarshal_func)_mesa_unmarshal_BufferData,
   [DISPATCH_CMD_BufferSubData] = (_mesa_unmarshal_func)_mesa_unmarshal_BufferSubData,
   [DISPATCH_CMD_DeleteBuffers] = (_mesa_unmarshal_func)_mesa_unmarshal_DeleteBuffers,
   [DISPATCH_CMD_UnmapBuffer] = (_mesa_unmarshal_func)_mesa_unmarshal_UnmapBuffer,
   [DISPATCH_CMD_DeleteQueries] = (_mesa_unmarshal_func)_mesa_unmarshal_DeleteQueries,
   [DISPATCH_CMD_BeginQuery] = (_mesa_unmarshal_func)_mesa_unmarshal_BeginQuery,
   [DISPATCH_CMD_EndQuery] = (_mesa_unmarshal_func)_mesa_unmarshal_EndQuery,
   [DISPATCH_CMD_BlendEquationSeparate] = (_mesa_unmarshal_func)_mesa_unmarshal_BlendEquationSeparate,
   [DISPATCH_CMD_DrawBuffers] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawBuffers,
   [DISPATCH_CMD_StencilFuncSeparate] = (_mesa_unmarshal_func)_mesa_unmarshal_StencilFuncSeparate,
   [DISPATCH_CMD_StencilOpSeparate] = (_mesa_unmarshal_func)_mesa_unmarshal_StencilOpSeparate,
   [DISPATCH_CMD_StencilMaskSeparate] = (_mesa_unmarshal_func)_mesa_unmarshal_StencilMaskSeparate,
   [DISPATCH_CMD_AttachShader] = (_mesa_unmarshal_func)_mesa_unmarshal_AttachShader,
   [DISPATCH_CMD_BindAttribLocation] = (_mesa_unmarshal_func)_mesa_unmarshal_BindAttribLocation,
   [DISPATCH_CMD_CompileShader] = (_mesa_unmarshal_func)_mesa_unmarshal_CompileShader,
   [DISPATCH_CMD_DeleteProgram] = (_mesa_unmarshal_func)_mesa_unmarshal_DeleteProgram,
   [DISPATCH_CMD_DeleteShader] = (_mesa_unmarshal_func)_mesa_unmarshal_DeleteShader,
   [DISPATCH_CMD_DetachShader] = (_mesa_unmarshal_func)_mesa_unmarshal_DetachShader,
   [DISPATCH_CMD_DisableVertexAttribArray] = (_mesa_unmarshal_func)_mesa_unmarshal_DisableVertexAttribArray,
   [DISPATCH_CMD_EnableVertexAttribArray] = (_mesa_unmarshal_func)_mesa_unmarshal_EnableVertexAttribArray,
   [DISPATCH_CMD_GetActiveUniform] = (_mesa_unmarshal_func)_mesa_unmarshal_GetActiveUniform,
   [DISPATCH_CMD_GetUniformLocation] = (_mesa_unmarshal_func)_mesa_unmarshal_GetUniformLocation,
   [DISPATCH_CMD_LinkProgram] = (_mesa_unmarshal_func)_mesa_unmarshal_LinkProgram,
   [DISPATCH_CMD_UseProgram] = (_mesa_unmarshal_func)_mesa_unmarshal_UseProgram,
   [DISPATCH_CMD_Uniform1f] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform1f,
   [DISPATCH_CMD_Uniform2f] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform2f,
   [DISPATCH_CMD_Uniform3f] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform3f,
   [DISPATCH_CMD_Uniform4f] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform4f,
   [DISPATCH_CMD_Uniform1i] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform1i,
   [DISPATCH_CMD_Uniform2i] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform2i,
   [DISPATCH_CMD_Uniform3i] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform3i,
   [DISPATCH_CMD_Uniform4i] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform4i,
   [DISPATCH_CMD_Uniform1fv] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform1fv,
   [DISPATCH_CMD_Uniform2fv] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform2fv,
   [DISPATCH_CMD_Uniform3fv] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform3fv,
   [DISPATCH_CMD_Uniform4fv] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform4fv,
   [DISPATCH_CMD_Uniform1iv] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform1iv,
   [DISPATCH_CMD_Uniform2iv] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform2iv,
   [DISPATCH_CMD_Uniform3iv] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform3iv,
   [DISPATCH_CMD_Uniform4iv] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform4iv,
   [DISPATCH_CMD_UniformMatrix2fv] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformMatrix2fv,
   [DISPATCH_CMD_UniformMatrix3fv] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformMatrix3fv,
   [DISPATCH_CMD_UniformMatrix4fv] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformMatrix4fv,
   [DISPATCH_CMD_ValidateProgram] = (_mesa_unmarshal_func)_mesa_unmarshal_ValidateProgram,
   [DISPATCH_CMD_VertexAttrib1d] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib1d,
   [DISPATCH_CMD_VertexAttrib1dv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib1dv,
   [DISPATCH_CMD_VertexAttrib1fARB] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib1fARB,
   [DISPATCH_CMD_VertexAttrib1fvARB] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib1fvARB,
   [DISPATCH_CMD_VertexAttrib1s] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib1s,
   [DISPATCH_CMD_VertexAttrib1sv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib1sv,
   [DISPATCH_CMD_VertexAttrib2d] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib2d,
   [DISPATCH_CMD_VertexAttrib2dv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib2dv,
   [DISPATCH_CMD_VertexAttrib2fARB] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib2fARB,
   [DISPATCH_CMD_VertexAttrib2fvARB] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib2fvARB,
   [DISPATCH_CMD_VertexAttrib2s] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib2s,
   [DISPATCH_CMD_VertexAttrib2sv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib2sv,
   [DISPATCH_CMD_VertexAttrib3d] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib3d,
   [DISPATCH_CMD_VertexAttrib3dv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib3dv,
   [DISPATCH_CMD_VertexAttrib3fARB] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib3fARB,
   [DISPATCH_CMD_VertexAttrib3fvARB] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib3fvARB,
   [DISPATCH_CMD_VertexAttrib3s] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib3s,
   [DISPATCH_CMD_VertexAttrib3sv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib3sv,
   [DISPATCH_CMD_VertexAttrib4Nbv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4Nbv,
   [DISPATCH_CMD_VertexAttrib4Niv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4Niv,
   [DISPATCH_CMD_VertexAttrib4Nsv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4Nsv,
   [DISPATCH_CMD_VertexAttrib4Nub] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4Nub,
   [DISPATCH_CMD_VertexAttrib4Nubv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4Nubv,
   [DISPATCH_CMD_VertexAttrib4Nuiv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4Nuiv,
   [DISPATCH_CMD_VertexAttrib4Nusv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4Nusv,
   [DISPATCH_CMD_VertexAttrib4bv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4bv,
   [DISPATCH_CMD_VertexAttrib4d] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4d,
   [DISPATCH_CMD_VertexAttrib4dv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4dv,
   [DISPATCH_CMD_VertexAttrib4fARB] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4fARB,
   [DISPATCH_CMD_VertexAttrib4fvARB] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4fvARB,
   [DISPATCH_CMD_VertexAttrib4iv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4iv,
   [DISPATCH_CMD_VertexAttrib4s] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4s,
   [DISPATCH_CMD_VertexAttrib4sv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4sv,
   [DISPATCH_CMD_VertexAttrib4ubv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4ubv,
   [DISPATCH_CMD_VertexAttrib4uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4uiv,
   [DISPATCH_CMD_VertexAttrib4usv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4usv,
   [DISPATCH_CMD_VertexAttribPointer] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribPointer,
   [DISPATCH_CMD_UniformMatrix2x3fv] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformMatrix2x3fv,
   [DISPATCH_CMD_UniformMatrix3x2fv] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformMatrix3x2fv,
   [DISPATCH_CMD_UniformMatrix2x4fv] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformMatrix2x4fv,
   [DISPATCH_CMD_UniformMatrix4x2fv] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformMatrix4x2fv,
   [DISPATCH_CMD_UniformMatrix3x4fv] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformMatrix3x4fv,
   [DISPATCH_CMD_UniformMatrix4x3fv] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformMatrix4x3fv,
   [DISPATCH_CMD_ProgramStringARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramStringARB,
   [DISPATCH_CMD_BindProgramARB] = (_mesa_unmarshal_func)_mesa_unmarshal_BindProgramARB,
   [DISPATCH_CMD_DeleteProgramsARB] = (_mesa_unmarshal_func)_mesa_unmarshal_DeleteProgramsARB,
   [DISPATCH_CMD_ProgramEnvParameter4dARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramEnvParameter4dARB,
   [DISPATCH_CMD_ProgramEnvParameter4dvARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramEnvParameter4dvARB,
   [DISPATCH_CMD_ProgramEnvParameter4fARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramEnvParameter4fARB,
   [DISPATCH_CMD_ProgramEnvParameter4fvARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramEnvParameter4fvARB,
   [DISPATCH_CMD_ProgramLocalParameter4dARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramLocalParameter4dARB,
   [DISPATCH_CMD_ProgramLocalParameter4dvARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramLocalParameter4dvARB,
   [DISPATCH_CMD_ProgramLocalParameter4fARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramLocalParameter4fARB,
   [DISPATCH_CMD_ProgramLocalParameter4fvARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramLocalParameter4fvARB,
   [DISPATCH_CMD_DeleteObjectARB] = (_mesa_unmarshal_func)_mesa_unmarshal_DeleteObjectARB,
   [DISPATCH_CMD_DetachObjectARB] = (_mesa_unmarshal_func)_mesa_unmarshal_DetachObjectARB,
   [DISPATCH_CMD_AttachObjectARB] = (_mesa_unmarshal_func)_mesa_unmarshal_AttachObjectARB,
   [DISPATCH_CMD_ClampColor] = (_mesa_unmarshal_func)_mesa_unmarshal_ClampColor,
   [DISPATCH_CMD_DrawArraysInstanced] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawArraysInstanced,
   [DISPATCH_CMD_DrawElementsInstanced] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawElementsInstanced,
   [DISPATCH_CMD_BindRenderbuffer] = (_mesa_unmarshal_func)_mesa_unmarshal_BindRenderbuffer,
   [DISPATCH_CMD_DeleteRenderbuffers] = (_mesa_unmarshal_func)_mesa_unmarshal_DeleteRenderbuffers,
   [DISPATCH_CMD_RenderbufferStorage] = (_mesa_unmarshal_func)_mesa_unmarshal_RenderbufferStorage,
   [DISPATCH_CMD_RenderbufferStorageMultisample] = (_mesa_unmarshal_func)_mesa_unmarshal_RenderbufferStorageMultisample,
   [DISPATCH_CMD_BindFramebuffer] = (_mesa_unmarshal_func)_mesa_unmarshal_BindFramebuffer,
   [DISPATCH_CMD_DeleteFramebuffers] = (_mesa_unmarshal_func)_mesa_unmarshal_DeleteFramebuffers,
   [DISPATCH_CMD_FramebufferTexture1D] = (_mesa_unmarshal_func)_mesa_unmarshal_FramebufferTexture1D,
   [DISPATCH_CMD_FramebufferTexture2D] = (_mesa_unmarshal_func)_mesa_unmarshal_FramebufferTexture2D,
   [DISPATCH_CMD_FramebufferTexture3D] = (_mesa_unmarshal_func)_mesa_unmarshal_FramebufferTexture3D,
   [DISPATCH_CMD_FramebufferTextureLayer] = (_mesa_unmarshal_func)_mesa_unmarshal_FramebufferTextureLayer,
   [DISPATCH_CMD_FramebufferRenderbuffer] = (_mesa_unmarshal_func)_mesa_unmarshal_FramebufferRenderbuffer,
   [DISPATCH_CMD_BlitFramebuffer] = (_mesa_unmarshal_func)_mesa_unmarshal_BlitFramebuffer,
   [DISPATCH_CMD_GenerateMipmap] = (_mesa_unmarshal_func)_mesa_unmarshal_GenerateMipmap,
   [DISPATCH_CMD_FramebufferTextureMultiviewOVR] = (_mesa_unmarshal_func)_mesa_unmarshal_FramebufferTextureMultiviewOVR,
   [DISPATCH_CMD_NamedFramebufferTextureMultiviewOVR] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedFramebufferTextureMultiviewOVR,
   [DISPATCH_CMD_FramebufferTextureMultisampleMultiviewOVR] = (_mesa_unmarshal_func)_mesa_unmarshal_FramebufferTextureMultisampleMultiviewOVR,
   [DISPATCH_CMD_VertexAttribDivisor] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribDivisor,
   [DISPATCH_CMD_VertexArrayVertexAttribDivisorEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayVertexAttribDivisorEXT,
   [DISPATCH_CMD_FlushMappedBufferRange] = (_mesa_unmarshal_func)_mesa_unmarshal_FlushMappedBufferRange,
   [DISPATCH_CMD_TexBuffer] = (_mesa_unmarshal_func)_mesa_unmarshal_TexBuffer,
   [DISPATCH_CMD_BindVertexArray] = (_mesa_unmarshal_func)_mesa_unmarshal_BindVertexArray,
   [DISPATCH_CMD_DeleteVertexArrays] = (_mesa_unmarshal_func)_mesa_unmarshal_DeleteVertexArrays,
   [DISPATCH_CMD_UniformBlockBinding] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformBlockBinding,
   [DISPATCH_CMD_CopyBufferSubData] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyBufferSubData,
   [DISPATCH_CMD_DrawElementsBaseVertex] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawElementsBaseVertex,
   [DISPATCH_CMD_DrawRangeElementsBaseVertex] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawRangeElementsBaseVertex,
   [DISPATCH_CMD_MultiDrawElementsBaseVertex] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiDrawElementsBaseVertex,
   [DISPATCH_CMD_DrawElementsInstancedBaseVertex] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawElementsInstancedBaseVertex,
   [DISPATCH_CMD_DeleteSync] = (_mesa_unmarshal_func)_mesa_unmarshal_DeleteSync,
   [DISPATCH_CMD_WaitSync] = (_mesa_unmarshal_func)_mesa_unmarshal_WaitSync,
   [DISPATCH_CMD_TexImage2DMultisample] = (_mesa_unmarshal_func)_mesa_unmarshal_TexImage2DMultisample,
   [DISPATCH_CMD_TexImage3DMultisample] = (_mesa_unmarshal_func)_mesa_unmarshal_TexImage3DMultisample,
   [DISPATCH_CMD_SampleMaski] = (_mesa_unmarshal_func)_mesa_unmarshal_SampleMaski,
   [DISPATCH_CMD_BlendEquationiARB] = (_mesa_unmarshal_func)_mesa_unmarshal_BlendEquationiARB,
   [DISPATCH_CMD_BlendEquationSeparateiARB] = (_mesa_unmarshal_func)_mesa_unmarshal_BlendEquationSeparateiARB,
   [DISPATCH_CMD_BlendFunciARB] = (_mesa_unmarshal_func)_mesa_unmarshal_BlendFunciARB,
   [DISPATCH_CMD_BlendFuncSeparateiARB] = (_mesa_unmarshal_func)_mesa_unmarshal_BlendFuncSeparateiARB,
   [DISPATCH_CMD_MinSampleShading] = (_mesa_unmarshal_func)_mesa_unmarshal_MinSampleShading,
   [DISPATCH_CMD_NamedStringARB] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedStringARB,
   [DISPATCH_CMD_DeleteNamedStringARB] = (_mesa_unmarshal_func)_mesa_unmarshal_DeleteNamedStringARB,
   [DISPATCH_CMD_BindFragDataLocationIndexed] = (_mesa_unmarshal_func)_mesa_unmarshal_BindFragDataLocationIndexed,
   [DISPATCH_CMD_DeleteSamplers] = (_mesa_unmarshal_func)_mesa_unmarshal_DeleteSamplers,
   [DISPATCH_CMD_BindSampler] = (_mesa_unmarshal_func)_mesa_unmarshal_BindSampler,
   [DISPATCH_CMD_SamplerParameteri] = (_mesa_unmarshal_func)_mesa_unmarshal_SamplerParameteri,
   [DISPATCH_CMD_SamplerParameterf] = (_mesa_unmarshal_func)_mesa_unmarshal_SamplerParameterf,
   [DISPATCH_CMD_SamplerParameteriv] = (_mesa_unmarshal_func)_mesa_unmarshal_SamplerParameteriv,
   [DISPATCH_CMD_SamplerParameterfv] = (_mesa_unmarshal_func)_mesa_unmarshal_SamplerParameterfv,
   [DISPATCH_CMD_SamplerParameterIiv] = (_mesa_unmarshal_func)_mesa_unmarshal_SamplerParameterIiv,
   [DISPATCH_CMD_SamplerParameterIuiv] = (_mesa_unmarshal_func)_mesa_unmarshal_SamplerParameterIuiv,
   [DISPATCH_CMD_QueryCounter] = (_mesa_unmarshal_func)_mesa_unmarshal_QueryCounter,
   [DISPATCH_CMD_VertexP2ui] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexP2ui,
   [DISPATCH_CMD_VertexP3ui] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexP3ui,
   [DISPATCH_CMD_VertexP4ui] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexP4ui,
   [DISPATCH_CMD_VertexP2uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexP2uiv,
   [DISPATCH_CMD_VertexP3uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexP3uiv,
   [DISPATCH_CMD_VertexP4uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexP4uiv,
   [DISPATCH_CMD_TexCoordP1ui] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoordP1ui,
   [DISPATCH_CMD_TexCoordP2ui] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoordP2ui,
   [DISPATCH_CMD_TexCoordP3ui] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoordP3ui,
   [DISPATCH_CMD_TexCoordP4ui] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoordP4ui,
   [DISPATCH_CMD_TexCoordP1uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoordP1uiv,
   [DISPATCH_CMD_TexCoordP2uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoordP2uiv,
   [DISPATCH_CMD_TexCoordP3uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoordP3uiv,
   [DISPATCH_CMD_TexCoordP4uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoordP4uiv,
   [DISPATCH_CMD_MultiTexCoordP1ui] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoordP1ui,
   [DISPATCH_CMD_MultiTexCoordP2ui] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoordP2ui,
   [DISPATCH_CMD_MultiTexCoordP3ui] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoordP3ui,
   [DISPATCH_CMD_MultiTexCoordP4ui] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoordP4ui,
   [DISPATCH_CMD_MultiTexCoordP1uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoordP1uiv,
   [DISPATCH_CMD_MultiTexCoordP2uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoordP2uiv,
   [DISPATCH_CMD_MultiTexCoordP3uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoordP3uiv,
   [DISPATCH_CMD_MultiTexCoordP4uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoordP4uiv,
   [DISPATCH_CMD_NormalP3ui] = (_mesa_unmarshal_func)_mesa_unmarshal_NormalP3ui,
   [DISPATCH_CMD_NormalP3uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_NormalP3uiv,
   [DISPATCH_CMD_ColorP3ui] = (_mesa_unmarshal_func)_mesa_unmarshal_ColorP3ui,
   [DISPATCH_CMD_ColorP4ui] = (_mesa_unmarshal_func)_mesa_unmarshal_ColorP4ui,
   [DISPATCH_CMD_ColorP3uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_ColorP3uiv,
   [DISPATCH_CMD_ColorP4uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_ColorP4uiv,
   [DISPATCH_CMD_SecondaryColorP3ui] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColorP3ui,
   [DISPATCH_CMD_SecondaryColorP3uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColorP3uiv,
   [DISPATCH_CMD_VertexAttribP1ui] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribP1ui,
   [DISPATCH_CMD_VertexAttribP2ui] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribP2ui,
   [DISPATCH_CMD_VertexAttribP3ui] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribP3ui,
   [DISPATCH_CMD_VertexAttribP4ui] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribP4ui,
   [DISPATCH_CMD_VertexAttribP1uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribP1uiv,
   [DISPATCH_CMD_VertexAttribP2uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribP2uiv,
   [DISPATCH_CMD_VertexAttribP3uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribP3uiv,
   [DISPATCH_CMD_VertexAttribP4uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribP4uiv,
   [DISPATCH_CMD_UniformSubroutinesuiv] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformSubroutinesuiv,
   [DISPATCH_CMD_PatchParameteri] = (_mesa_unmarshal_func)_mesa_unmarshal_PatchParameteri,
   [DISPATCH_CMD_PatchParameterfv] = (_mesa_unmarshal_func)_mesa_unmarshal_PatchParameterfv,
   [DISPATCH_CMD_DrawArraysIndirect] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawArraysIndirect,
   [DISPATCH_CMD_DrawElementsIndirect] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawElementsIndirect,
   [DISPATCH_CMD_MultiDrawArraysIndirect] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiDrawArraysIndirect,
   [DISPATCH_CMD_MultiDrawElementsIndirect] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiDrawElementsIndirect,
   [DISPATCH_CMD_Uniform1d] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform1d,
   [DISPATCH_CMD_Uniform2d] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform2d,
   [DISPATCH_CMD_Uniform3d] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform3d,
   [DISPATCH_CMD_Uniform4d] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform4d,
   [DISPATCH_CMD_Uniform1dv] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform1dv,
   [DISPATCH_CMD_Uniform2dv] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform2dv,
   [DISPATCH_CMD_Uniform3dv] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform3dv,
   [DISPATCH_CMD_Uniform4dv] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform4dv,
   [DISPATCH_CMD_UniformMatrix2dv] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformMatrix2dv,
   [DISPATCH_CMD_UniformMatrix3dv] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformMatrix3dv,
   [DISPATCH_CMD_UniformMatrix4dv] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformMatrix4dv,
   [DISPATCH_CMD_UniformMatrix2x3dv] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformMatrix2x3dv,
   [DISPATCH_CMD_UniformMatrix2x4dv] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformMatrix2x4dv,
   [DISPATCH_CMD_UniformMatrix3x2dv] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformMatrix3x2dv,
   [DISPATCH_CMD_UniformMatrix3x4dv] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformMatrix3x4dv,
   [DISPATCH_CMD_UniformMatrix4x2dv] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformMatrix4x2dv,
   [DISPATCH_CMD_UniformMatrix4x3dv] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformMatrix4x3dv,
   [DISPATCH_CMD_ProgramUniform1d] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform1d,
   [DISPATCH_CMD_ProgramUniform2d] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform2d,
   [DISPATCH_CMD_ProgramUniform3d] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform3d,
   [DISPATCH_CMD_ProgramUniform4d] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform4d,
   [DISPATCH_CMD_ProgramUniform1dv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform1dv,
   [DISPATCH_CMD_ProgramUniform2dv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform2dv,
   [DISPATCH_CMD_ProgramUniform3dv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform3dv,
   [DISPATCH_CMD_ProgramUniform4dv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform4dv,
   [DISPATCH_CMD_ProgramUniformMatrix2dv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniformMatrix2dv,
   [DISPATCH_CMD_ProgramUniformMatrix3dv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniformMatrix3dv,
   [DISPATCH_CMD_ProgramUniformMatrix4dv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniformMatrix4dv,
   [DISPATCH_CMD_ProgramUniformMatrix2x3dv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniformMatrix2x3dv,
   [DISPATCH_CMD_ProgramUniformMatrix2x4dv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniformMatrix2x4dv,
   [DISPATCH_CMD_ProgramUniformMatrix3x2dv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniformMatrix3x2dv,
   [DISPATCH_CMD_ProgramUniformMatrix3x4dv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniformMatrix3x4dv,
   [DISPATCH_CMD_ProgramUniformMatrix4x2dv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniformMatrix4x2dv,
   [DISPATCH_CMD_ProgramUniformMatrix4x3dv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniformMatrix4x3dv,
   [DISPATCH_CMD_DrawTransformFeedbackStream] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawTransformFeedbackStream,
   [DISPATCH_CMD_BeginQueryIndexed] = (_mesa_unmarshal_func)_mesa_unmarshal_BeginQueryIndexed,
   [DISPATCH_CMD_EndQueryIndexed] = (_mesa_unmarshal_func)_mesa_unmarshal_EndQueryIndexed,
   [DISPATCH_CMD_UseProgramStages] = (_mesa_unmarshal_func)_mesa_unmarshal_UseProgramStages,
   [DISPATCH_CMD_ActiveShaderProgram] = (_mesa_unmarshal_func)_mesa_unmarshal_ActiveShaderProgram,
   [DISPATCH_CMD_BindProgramPipeline] = (_mesa_unmarshal_func)_mesa_unmarshal_BindProgramPipeline,
   [DISPATCH_CMD_DeleteProgramPipelines] = (_mesa_unmarshal_func)_mesa_unmarshal_DeleteProgramPipelines,
   [DISPATCH_CMD_ProgramUniform1i] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform1i,
   [DISPATCH_CMD_ProgramUniform2i] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform2i,
   [DISPATCH_CMD_ProgramUniform3i] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform3i,
   [DISPATCH_CMD_ProgramUniform4i] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform4i,
   [DISPATCH_CMD_ProgramUniform1ui] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform1ui,
   [DISPATCH_CMD_ProgramUniform2ui] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform2ui,
   [DISPATCH_CMD_ProgramUniform3ui] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform3ui,
   [DISPATCH_CMD_ProgramUniform4ui] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform4ui,
   [DISPATCH_CMD_ProgramUniform1f] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform1f,
   [DISPATCH_CMD_ProgramUniform2f] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform2f,
   [DISPATCH_CMD_ProgramUniform3f] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform3f,
   [DISPATCH_CMD_ProgramUniform4f] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform4f,
   [DISPATCH_CMD_ProgramUniform1iv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform1iv,
   [DISPATCH_CMD_ProgramUniform2iv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform2iv,
   [DISPATCH_CMD_ProgramUniform3iv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform3iv,
   [DISPATCH_CMD_ProgramUniform4iv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform4iv,
   [DISPATCH_CMD_ProgramUniform1uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform1uiv,
   [DISPATCH_CMD_ProgramUniform2uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform2uiv,
   [DISPATCH_CMD_ProgramUniform3uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform3uiv,
   [DISPATCH_CMD_ProgramUniform4uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform4uiv,
   [DISPATCH_CMD_ProgramUniform1fv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform1fv,
   [DISPATCH_CMD_ProgramUniform2fv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform2fv,
   [DISPATCH_CMD_ProgramUniform3fv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform3fv,
   [DISPATCH_CMD_ProgramUniform4fv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform4fv,
   [DISPATCH_CMD_ProgramUniformMatrix2fv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniformMatrix2fv,
   [DISPATCH_CMD_ProgramUniformMatrix3fv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniformMatrix3fv,
   [DISPATCH_CMD_ProgramUniformMatrix4fv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniformMatrix4fv,
   [DISPATCH_CMD_ProgramUniformMatrix2x3fv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniformMatrix2x3fv,
   [DISPATCH_CMD_ProgramUniformMatrix3x2fv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniformMatrix3x2fv,
   [DISPATCH_CMD_ProgramUniformMatrix2x4fv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniformMatrix2x4fv,
   [DISPATCH_CMD_ProgramUniformMatrix4x2fv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniformMatrix4x2fv,
   [DISPATCH_CMD_ProgramUniformMatrix3x4fv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniformMatrix3x4fv,
   [DISPATCH_CMD_ProgramUniformMatrix4x3fv] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniformMatrix4x3fv,
   [DISPATCH_CMD_ValidateProgramPipeline] = (_mesa_unmarshal_func)_mesa_unmarshal_ValidateProgramPipeline,
   [DISPATCH_CMD_VertexAttribL1d] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribL1d,
   [DISPATCH_CMD_VertexAttribL2d] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribL2d,
   [DISPATCH_CMD_VertexAttribL3d] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribL3d,
   [DISPATCH_CMD_VertexAttribL4d] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribL4d,
   [DISPATCH_CMD_VertexAttribL1dv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribL1dv,
   [DISPATCH_CMD_VertexAttribL2dv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribL2dv,
   [DISPATCH_CMD_VertexAttribL3dv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribL3dv,
   [DISPATCH_CMD_VertexAttribL4dv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribL4dv,
   [DISPATCH_CMD_VertexAttribLPointer] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribLPointer,
   [DISPATCH_CMD_VertexArrayVertexAttribLOffsetEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayVertexAttribLOffsetEXT,
   [DISPATCH_CMD_ReleaseShaderCompiler] = (_mesa_unmarshal_func)_mesa_unmarshal_ReleaseShaderCompiler,
   [DISPATCH_CMD_ShaderBinary] = (_mesa_unmarshal_func)_mesa_unmarshal_ShaderBinary,
   [DISPATCH_CMD_ClearDepthf] = (_mesa_unmarshal_func)_mesa_unmarshal_ClearDepthf,
   [DISPATCH_CMD_DepthRangef] = (_mesa_unmarshal_func)_mesa_unmarshal_DepthRangef,
   [DISPATCH_CMD_ProgramBinary] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramBinary,
   [DISPATCH_CMD_ProgramParameteri] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramParameteri,
   [DISPATCH_CMD_DebugMessageControl] = (_mesa_unmarshal_func)_mesa_unmarshal_DebugMessageControl,
   [DISPATCH_CMD_DebugMessageInsert] = (_mesa_unmarshal_func)_mesa_unmarshal_DebugMessageInsert,
   [DISPATCH_CMD_GetnPolygonStippleARB] = (_mesa_unmarshal_func)_mesa_unmarshal_GetnPolygonStippleARB,
   [DISPATCH_CMD_GetnTexImageARB] = (_mesa_unmarshal_func)_mesa_unmarshal_GetnTexImageARB,
   [DISPATCH_CMD_ReadnPixelsARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ReadnPixelsARB,
   [DISPATCH_CMD_GetnCompressedTexImageARB] = (_mesa_unmarshal_func)_mesa_unmarshal_GetnCompressedTexImageARB,
   [DISPATCH_CMD_DrawArraysInstancedBaseInstance] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawArraysInstancedBaseInstance,
   [DISPATCH_CMD_DrawElementsInstancedBaseInstance] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawElementsInstancedBaseInstance,
   [DISPATCH_CMD_DrawElementsInstancedBaseVertexBaseInstance] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawElementsInstancedBaseVertexBaseInstance,
   [DISPATCH_CMD_DrawTransformFeedbackInstanced] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawTransformFeedbackInstanced,
   [DISPATCH_CMD_DrawTransformFeedbackStreamInstanced] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawTransformFeedbackStreamInstanced,
   [DISPATCH_CMD_BindImageTexture] = (_mesa_unmarshal_func)_mesa_unmarshal_BindImageTexture,
   [DISPATCH_CMD_MemoryBarrier] = (_mesa_unmarshal_func)_mesa_unmarshal_MemoryBarrier,
   [DISPATCH_CMD_TexStorage1D] = (_mesa_unmarshal_func)_mesa_unmarshal_TexStorage1D,
   [DISPATCH_CMD_TexStorage2D] = (_mesa_unmarshal_func)_mesa_unmarshal_TexStorage2D,
   [DISPATCH_CMD_TexStorage3D] = (_mesa_unmarshal_func)_mesa_unmarshal_TexStorage3D,
   [DISPATCH_CMD_PushDebugGroup] = (_mesa_unmarshal_func)_mesa_unmarshal_PushDebugGroup,
   [DISPATCH_CMD_PopDebugGroup] = (_mesa_unmarshal_func)_mesa_unmarshal_PopDebugGroup,
   [DISPATCH_CMD_ObjectLabel] = (_mesa_unmarshal_func)_mesa_unmarshal_ObjectLabel,
   [DISPATCH_CMD_DispatchCompute] = (_mesa_unmarshal_func)_mesa_unmarshal_DispatchCompute,
   [DISPATCH_CMD_DispatchComputeIndirect] = (_mesa_unmarshal_func)_mesa_unmarshal_DispatchComputeIndirect,
   [DISPATCH_CMD_CopyImageSubData] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyImageSubData,
   [DISPATCH_CMD_TextureView] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureView,
   [DISPATCH_CMD_BindVertexBuffer] = (_mesa_unmarshal_func)_mesa_unmarshal_BindVertexBuffer,
   [DISPATCH_CMD_VertexAttribFormat] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribFormat,
   [DISPATCH_CMD_VertexAttribIFormat] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribIFormat,
   [DISPATCH_CMD_VertexAttribLFormat] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribLFormat,
   [DISPATCH_CMD_VertexAttribBinding] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribBinding,
   [DISPATCH_CMD_VertexBindingDivisor] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexBindingDivisor,
   [DISPATCH_CMD_VertexArrayBindVertexBufferEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayBindVertexBufferEXT,
   [DISPATCH_CMD_VertexArrayBindVertexBufferEXT_packed] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayBindVertexBufferEXT_packed,
   [DISPATCH_CMD_VertexArrayVertexAttribFormatEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayVertexAttribFormatEXT,
   [DISPATCH_CMD_VertexArrayVertexAttribIFormatEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayVertexAttribIFormatEXT,
   [DISPATCH_CMD_VertexArrayVertexAttribLFormatEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayVertexAttribLFormatEXT,
   [DISPATCH_CMD_VertexArrayVertexAttribBindingEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayVertexAttribBindingEXT,
   [DISPATCH_CMD_VertexArrayVertexBindingDivisorEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayVertexBindingDivisorEXT,
   [DISPATCH_CMD_FramebufferParameteri] = (_mesa_unmarshal_func)_mesa_unmarshal_FramebufferParameteri,
   [DISPATCH_CMD_NamedFramebufferParameteriEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedFramebufferParameteriEXT,
   [DISPATCH_CMD_InvalidateTexSubImage] = (_mesa_unmarshal_func)_mesa_unmarshal_InvalidateTexSubImage,
   [DISPATCH_CMD_InvalidateTexImage] = (_mesa_unmarshal_func)_mesa_unmarshal_InvalidateTexImage,
   [DISPATCH_CMD_InvalidateBufferSubData] = (_mesa_unmarshal_func)_mesa_unmarshal_InvalidateBufferSubData,
   [DISPATCH_CMD_InvalidateBufferData] = (_mesa_unmarshal_func)_mesa_unmarshal_InvalidateBufferData,
   [DISPATCH_CMD_InvalidateSubFramebuffer] = (_mesa_unmarshal_func)_mesa_unmarshal_InvalidateSubFramebuffer,
   [DISPATCH_CMD_InvalidateFramebuffer] = (_mesa_unmarshal_func)_mesa_unmarshal_InvalidateFramebuffer,
   [DISPATCH_CMD_ShaderStorageBlockBinding] = (_mesa_unmarshal_func)_mesa_unmarshal_ShaderStorageBlockBinding,
   [DISPATCH_CMD_TexBufferRange] = (_mesa_unmarshal_func)_mesa_unmarshal_TexBufferRange,
   [DISPATCH_CMD_TextureBufferRangeEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureBufferRangeEXT,
   [DISPATCH_CMD_TexStorage2DMultisample] = (_mesa_unmarshal_func)_mesa_unmarshal_TexStorage2DMultisample,
   [DISPATCH_CMD_TexStorage3DMultisample] = (_mesa_unmarshal_func)_mesa_unmarshal_TexStorage3DMultisample,
   [DISPATCH_CMD_TextureStorage2DMultisampleEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureStorage2DMultisampleEXT,
   [DISPATCH_CMD_TextureStorage3DMultisampleEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureStorage3DMultisampleEXT,
   [DISPATCH_CMD_BindBuffersBase] = (_mesa_unmarshal_func)_mesa_unmarshal_BindBuffersBase,
   [DISPATCH_CMD_BindBuffersRange] = (_mesa_unmarshal_func)_mesa_unmarshal_BindBuffersRange,
   [DISPATCH_CMD_BindTextures] = (_mesa_unmarshal_func)_mesa_unmarshal_BindTextures,
   [DISPATCH_CMD_BindSamplers] = (_mesa_unmarshal_func)_mesa_unmarshal_BindSamplers,
   [DISPATCH_CMD_BindImageTextures] = (_mesa_unmarshal_func)_mesa_unmarshal_BindImageTextures,
   [DISPATCH_CMD_BindVertexBuffers] = (_mesa_unmarshal_func)_mesa_unmarshal_BindVertexBuffers,
   [DISPATCH_CMD_MakeTextureHandleResidentARB] = (_mesa_unmarshal_func)_mesa_unmarshal_MakeTextureHandleResidentARB,
   [DISPATCH_CMD_MakeTextureHandleNonResidentARB] = (_mesa_unmarshal_func)_mesa_unmarshal_MakeTextureHandleNonResidentARB,
   [DISPATCH_CMD_MakeImageHandleResidentARB] = (_mesa_unmarshal_func)_mesa_unmarshal_MakeImageHandleResidentARB,
   [DISPATCH_CMD_MakeImageHandleNonResidentARB] = (_mesa_unmarshal_func)_mesa_unmarshal_MakeImageHandleNonResidentARB,
   [DISPATCH_CMD_UniformHandleui64ARB] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformHandleui64ARB,
   [DISPATCH_CMD_UniformHandleui64vARB] = (_mesa_unmarshal_func)_mesa_unmarshal_UniformHandleui64vARB,
   [DISPATCH_CMD_ProgramUniformHandleui64ARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniformHandleui64ARB,
   [DISPATCH_CMD_ProgramUniformHandleui64vARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniformHandleui64vARB,
   [DISPATCH_CMD_VertexAttribL1ui64ARB] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribL1ui64ARB,
   [DISPATCH_CMD_VertexAttribL1ui64vARB] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribL1ui64vARB,
   [DISPATCH_CMD_DispatchComputeGroupSizeARB] = (_mesa_unmarshal_func)_mesa_unmarshal_DispatchComputeGroupSizeARB,
   [DISPATCH_CMD_MultiDrawArraysIndirectCountARB] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiDrawArraysIndirectCountARB,
   [DISPATCH_CMD_MultiDrawElementsIndirectCountARB] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiDrawElementsIndirectCountARB,
   [DISPATCH_CMD_TexPageCommitmentARB] = (_mesa_unmarshal_func)_mesa_unmarshal_TexPageCommitmentARB,
   [DISPATCH_CMD_TexturePageCommitmentEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TexturePageCommitmentEXT,
   [DISPATCH_CMD_ClipControl] = (_mesa_unmarshal_func)_mesa_unmarshal_ClipControl,
   [DISPATCH_CMD_TransformFeedbackBufferBase] = (_mesa_unmarshal_func)_mesa_unmarshal_TransformFeedbackBufferBase,
   [DISPATCH_CMD_TransformFeedbackBufferRange] = (_mesa_unmarshal_func)_mesa_unmarshal_TransformFeedbackBufferRange,
   [DISPATCH_CMD_NamedBufferData] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedBufferData,
   [DISPATCH_CMD_NamedBufferSubData] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedBufferSubData,
   [DISPATCH_CMD_CopyNamedBufferSubData] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyNamedBufferSubData,
   [DISPATCH_CMD_UnmapNamedBufferEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_UnmapNamedBufferEXT,
   [DISPATCH_CMD_FlushMappedNamedBufferRange] = (_mesa_unmarshal_func)_mesa_unmarshal_FlushMappedNamedBufferRange,
   [DISPATCH_CMD_NamedFramebufferRenderbuffer] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedFramebufferRenderbuffer,
   [DISPATCH_CMD_NamedFramebufferParameteri] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedFramebufferParameteri,
   [DISPATCH_CMD_NamedFramebufferTexture] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedFramebufferTexture,
   [DISPATCH_CMD_NamedFramebufferTextureLayer] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedFramebufferTextureLayer,
   [DISPATCH_CMD_NamedFramebufferDrawBuffer] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedFramebufferDrawBuffer,
   [DISPATCH_CMD_NamedFramebufferDrawBuffers] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedFramebufferDrawBuffers,
   [DISPATCH_CMD_NamedFramebufferReadBuffer] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedFramebufferReadBuffer,
   [DISPATCH_CMD_InvalidateNamedFramebufferData] = (_mesa_unmarshal_func)_mesa_unmarshal_InvalidateNamedFramebufferData,
   [DISPATCH_CMD_InvalidateNamedFramebufferSubData] = (_mesa_unmarshal_func)_mesa_unmarshal_InvalidateNamedFramebufferSubData,
   [DISPATCH_CMD_ClearNamedFramebufferiv] = (_mesa_unmarshal_func)_mesa_unmarshal_ClearNamedFramebufferiv,
   [DISPATCH_CMD_ClearNamedFramebufferuiv] = (_mesa_unmarshal_func)_mesa_unmarshal_ClearNamedFramebufferuiv,
   [DISPATCH_CMD_ClearNamedFramebufferfv] = (_mesa_unmarshal_func)_mesa_unmarshal_ClearNamedFramebufferfv,
   [DISPATCH_CMD_ClearNamedFramebufferfi] = (_mesa_unmarshal_func)_mesa_unmarshal_ClearNamedFramebufferfi,
   [DISPATCH_CMD_BlitNamedFramebuffer] = (_mesa_unmarshal_func)_mesa_unmarshal_BlitNamedFramebuffer,
   [DISPATCH_CMD_NamedRenderbufferStorage] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedRenderbufferStorage,
   [DISPATCH_CMD_NamedRenderbufferStorageMultisample] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedRenderbufferStorageMultisample,
   [DISPATCH_CMD_TextureBuffer] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureBuffer,
   [DISPATCH_CMD_TextureBufferRange] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureBufferRange,
   [DISPATCH_CMD_TextureStorage1D] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureStorage1D,
   [DISPATCH_CMD_TextureStorage2D] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureStorage2D,
   [DISPATCH_CMD_TextureStorage3D] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureStorage3D,
   [DISPATCH_CMD_TextureStorage2DMultisample] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureStorage2DMultisample,
   [DISPATCH_CMD_TextureStorage3DMultisample] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureStorage3DMultisample,
   [DISPATCH_CMD_TextureSubImage1D] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureSubImage1D,
   [DISPATCH_CMD_TextureSubImage2D] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureSubImage2D,
   [DISPATCH_CMD_TextureSubImage3D] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureSubImage3D,
   [DISPATCH_CMD_CompressedTextureSubImage1D] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedTextureSubImage1D,
   [DISPATCH_CMD_CompressedTextureSubImage2D] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedTextureSubImage2D,
   [DISPATCH_CMD_CompressedTextureSubImage3D] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedTextureSubImage3D,
   [DISPATCH_CMD_CopyTextureSubImage1D] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyTextureSubImage1D,
   [DISPATCH_CMD_CopyTextureSubImage2D] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyTextureSubImage2D,
   [DISPATCH_CMD_CopyTextureSubImage3D] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyTextureSubImage3D,
   [DISPATCH_CMD_TextureParameterf] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureParameterf,
   [DISPATCH_CMD_TextureParameterfv] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureParameterfv,
   [DISPATCH_CMD_TextureParameteri] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureParameteri,
   [DISPATCH_CMD_TextureParameterIiv] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureParameterIiv,
   [DISPATCH_CMD_TextureParameterIuiv] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureParameterIuiv,
   [DISPATCH_CMD_TextureParameteriv] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureParameteriv,
   [DISPATCH_CMD_GenerateTextureMipmap] = (_mesa_unmarshal_func)_mesa_unmarshal_GenerateTextureMipmap,
   [DISPATCH_CMD_BindTextureUnit] = (_mesa_unmarshal_func)_mesa_unmarshal_BindTextureUnit,
   [DISPATCH_CMD_GetTextureImage] = (_mesa_unmarshal_func)_mesa_unmarshal_GetTextureImage,
   [DISPATCH_CMD_GetCompressedTextureImage] = (_mesa_unmarshal_func)_mesa_unmarshal_GetCompressedTextureImage,
   [DISPATCH_CMD_DisableVertexArrayAttrib] = (_mesa_unmarshal_func)_mesa_unmarshal_DisableVertexArrayAttrib,
   [DISPATCH_CMD_EnableVertexArrayAttrib] = (_mesa_unmarshal_func)_mesa_unmarshal_EnableVertexArrayAttrib,
   [DISPATCH_CMD_VertexArrayElementBuffer] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayElementBuffer,
   [DISPATCH_CMD_VertexArrayVertexBuffer] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayVertexBuffer,
   [DISPATCH_CMD_VertexArrayVertexBuffer_packed] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayVertexBuffer_packed,
   [DISPATCH_CMD_VertexArrayVertexBuffers] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayVertexBuffers,
   [DISPATCH_CMD_VertexArrayAttribFormat] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayAttribFormat,
   [DISPATCH_CMD_VertexArrayAttribIFormat] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayAttribIFormat,
   [DISPATCH_CMD_VertexArrayAttribLFormat] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayAttribLFormat,
   [DISPATCH_CMD_VertexArrayAttribBinding] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayAttribBinding,
   [DISPATCH_CMD_VertexArrayBindingDivisor] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayBindingDivisor,
   [DISPATCH_CMD_GetQueryBufferObjectiv] = (_mesa_unmarshal_func)_mesa_unmarshal_GetQueryBufferObjectiv,
   [DISPATCH_CMD_GetQueryBufferObjectuiv] = (_mesa_unmarshal_func)_mesa_unmarshal_GetQueryBufferObjectuiv,
   [DISPATCH_CMD_GetQueryBufferObjecti64v] = (_mesa_unmarshal_func)_mesa_unmarshal_GetQueryBufferObjecti64v,
   [DISPATCH_CMD_GetQueryBufferObjectui64v] = (_mesa_unmarshal_func)_mesa_unmarshal_GetQueryBufferObjectui64v,
   [DISPATCH_CMD_GetTextureSubImage] = (_mesa_unmarshal_func)_mesa_unmarshal_GetTextureSubImage,
   [DISPATCH_CMD_GetCompressedTextureSubImage] = (_mesa_unmarshal_func)_mesa_unmarshal_GetCompressedTextureSubImage,
   [DISPATCH_CMD_TextureBarrierNV] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureBarrierNV,
   [DISPATCH_CMD_BufferPageCommitmentARB] = (_mesa_unmarshal_func)_mesa_unmarshal_BufferPageCommitmentARB,
   [DISPATCH_CMD_NamedBufferPageCommitmentEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedBufferPageCommitmentEXT,
   [DISPATCH_CMD_NamedBufferPageCommitmentARB] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedBufferPageCommitmentARB,
   [DISPATCH_CMD_PrimitiveBoundingBox] = (_mesa_unmarshal_func)_mesa_unmarshal_PrimitiveBoundingBox,
   [DISPATCH_CMD_BlendBarrier] = (_mesa_unmarshal_func)_mesa_unmarshal_BlendBarrier,
   [DISPATCH_CMD_Uniform1i64ARB] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform1i64ARB,
   [DISPATCH_CMD_Uniform2i64ARB] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform2i64ARB,
   [DISPATCH_CMD_Uniform3i64ARB] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform3i64ARB,
   [DISPATCH_CMD_Uniform4i64ARB] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform4i64ARB,
   [DISPATCH_CMD_Uniform1i64vARB] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform1i64vARB,
   [DISPATCH_CMD_Uniform2i64vARB] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform2i64vARB,
   [DISPATCH_CMD_Uniform3i64vARB] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform3i64vARB,
   [DISPATCH_CMD_Uniform4i64vARB] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform4i64vARB,
   [DISPATCH_CMD_Uniform1ui64ARB] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform1ui64ARB,
   [DISPATCH_CMD_Uniform2ui64ARB] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform2ui64ARB,
   [DISPATCH_CMD_Uniform3ui64ARB] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform3ui64ARB,
   [DISPATCH_CMD_Uniform4ui64ARB] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform4ui64ARB,
   [DISPATCH_CMD_Uniform1ui64vARB] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform1ui64vARB,
   [DISPATCH_CMD_Uniform2ui64vARB] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform2ui64vARB,
   [DISPATCH_CMD_Uniform3ui64vARB] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform3ui64vARB,
   [DISPATCH_CMD_Uniform4ui64vARB] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform4ui64vARB,
   [DISPATCH_CMD_ProgramUniform1i64ARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform1i64ARB,
   [DISPATCH_CMD_ProgramUniform2i64ARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform2i64ARB,
   [DISPATCH_CMD_ProgramUniform3i64ARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform3i64ARB,
   [DISPATCH_CMD_ProgramUniform4i64ARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform4i64ARB,
   [DISPATCH_CMD_ProgramUniform1i64vARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform1i64vARB,
   [DISPATCH_CMD_ProgramUniform2i64vARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform2i64vARB,
   [DISPATCH_CMD_ProgramUniform3i64vARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform3i64vARB,
   [DISPATCH_CMD_ProgramUniform4i64vARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform4i64vARB,
   [DISPATCH_CMD_ProgramUniform1ui64ARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform1ui64ARB,
   [DISPATCH_CMD_ProgramUniform2ui64ARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform2ui64ARB,
   [DISPATCH_CMD_ProgramUniform3ui64ARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform3ui64ARB,
   [DISPATCH_CMD_ProgramUniform4ui64ARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform4ui64ARB,
   [DISPATCH_CMD_ProgramUniform1ui64vARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform1ui64vARB,
   [DISPATCH_CMD_ProgramUniform2ui64vARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform2ui64vARB,
   [DISPATCH_CMD_ProgramUniform3ui64vARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform3ui64vARB,
   [DISPATCH_CMD_ProgramUniform4ui64vARB] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramUniform4ui64vARB,
   [DISPATCH_CMD_MaxShaderCompilerThreadsKHR] = (_mesa_unmarshal_func)_mesa_unmarshal_MaxShaderCompilerThreadsKHR,
   [DISPATCH_CMD_SpecializeShaderARB] = (_mesa_unmarshal_func)_mesa_unmarshal_SpecializeShaderARB,
   [DISPATCH_CMD_ColorPointerEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_ColorPointerEXT,
   [DISPATCH_CMD_EdgeFlagPointerEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_EdgeFlagPointerEXT,
   [DISPATCH_CMD_IndexPointerEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_IndexPointerEXT,
   [DISPATCH_CMD_NormalPointerEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_NormalPointerEXT,
   [DISPATCH_CMD_TexCoordPointerEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoordPointerEXT,
   [DISPATCH_CMD_VertexPointerEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexPointerEXT,
   [DISPATCH_CMD_LockArraysEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_LockArraysEXT,
   [DISPATCH_CMD_UnlockArraysEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_UnlockArraysEXT,
   [DISPATCH_CMD_ViewportArrayv] = (_mesa_unmarshal_func)_mesa_unmarshal_ViewportArrayv,
   [DISPATCH_CMD_ViewportIndexedf] = (_mesa_unmarshal_func)_mesa_unmarshal_ViewportIndexedf,
   [DISPATCH_CMD_ViewportIndexedfv] = (_mesa_unmarshal_func)_mesa_unmarshal_ViewportIndexedfv,
   [DISPATCH_CMD_ScissorArrayv] = (_mesa_unmarshal_func)_mesa_unmarshal_ScissorArrayv,
   [DISPATCH_CMD_ScissorIndexed] = (_mesa_unmarshal_func)_mesa_unmarshal_ScissorIndexed,
   [DISPATCH_CMD_ScissorIndexedv] = (_mesa_unmarshal_func)_mesa_unmarshal_ScissorIndexedv,
   [DISPATCH_CMD_DepthRangeArrayv] = (_mesa_unmarshal_func)_mesa_unmarshal_DepthRangeArrayv,
   [DISPATCH_CMD_DepthRangeIndexed] = (_mesa_unmarshal_func)_mesa_unmarshal_DepthRangeIndexed,
   [DISPATCH_CMD_FramebufferSampleLocationsfvARB] = (_mesa_unmarshal_func)_mesa_unmarshal_FramebufferSampleLocationsfvARB,
   [DISPATCH_CMD_NamedFramebufferSampleLocationsfvARB] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedFramebufferSampleLocationsfvARB,
   [DISPATCH_CMD_EvaluateDepthValuesARB] = (_mesa_unmarshal_func)_mesa_unmarshal_EvaluateDepthValuesARB,
   [DISPATCH_CMD_WindowPos4dMESA] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos4dMESA,
   [DISPATCH_CMD_WindowPos4dvMESA] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos4dvMESA,
   [DISPATCH_CMD_WindowPos4fMESA] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos4fMESA,
   [DISPATCH_CMD_WindowPos4fvMESA] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos4fvMESA,
   [DISPATCH_CMD_WindowPos4iMESA] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos4iMESA,
   [DISPATCH_CMD_WindowPos4ivMESA] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos4ivMESA,
   [DISPATCH_CMD_WindowPos4sMESA] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos4sMESA,
   [DISPATCH_CMD_WindowPos4svMESA] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowPos4svMESA,
   [DISPATCH_CMD_MultiModeDrawArraysIBM] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiModeDrawArraysIBM,
   [DISPATCH_CMD_MultiModeDrawElementsIBM] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiModeDrawElementsIBM,
   [DISPATCH_CMD_VertexAttrib1sNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib1sNV,
   [DISPATCH_CMD_VertexAttrib1svNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib1svNV,
   [DISPATCH_CMD_VertexAttrib2sNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib2sNV,
   [DISPATCH_CMD_VertexAttrib2svNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib2svNV,
   [DISPATCH_CMD_VertexAttrib3sNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib3sNV,
   [DISPATCH_CMD_VertexAttrib3svNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib3svNV,
   [DISPATCH_CMD_VertexAttrib4sNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4sNV,
   [DISPATCH_CMD_VertexAttrib4svNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4svNV,
   [DISPATCH_CMD_VertexAttrib1fNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib1fNV,
   [DISPATCH_CMD_VertexAttrib1fvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib1fvNV,
   [DISPATCH_CMD_VertexAttrib2fNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib2fNV,
   [DISPATCH_CMD_VertexAttrib2fvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib2fvNV,
   [DISPATCH_CMD_VertexAttrib3fNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib3fNV,
   [DISPATCH_CMD_VertexAttrib3fvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib3fvNV,
   [DISPATCH_CMD_VertexAttrib4fNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4fNV,
   [DISPATCH_CMD_VertexAttrib4fvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4fvNV,
   [DISPATCH_CMD_VertexAttrib1dNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib1dNV,
   [DISPATCH_CMD_VertexAttrib1dvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib1dvNV,
   [DISPATCH_CMD_VertexAttrib2dNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib2dNV,
   [DISPATCH_CMD_VertexAttrib2dvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib2dvNV,
   [DISPATCH_CMD_VertexAttrib3dNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib3dNV,
   [DISPATCH_CMD_VertexAttrib3dvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib3dvNV,
   [DISPATCH_CMD_VertexAttrib4dNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4dNV,
   [DISPATCH_CMD_VertexAttrib4dvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4dvNV,
   [DISPATCH_CMD_VertexAttrib4ubNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4ubNV,
   [DISPATCH_CMD_VertexAttrib4ubvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4ubvNV,
   [DISPATCH_CMD_VertexAttribs1svNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribs1svNV,
   [DISPATCH_CMD_VertexAttribs2svNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribs2svNV,
   [DISPATCH_CMD_VertexAttribs3svNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribs3svNV,
   [DISPATCH_CMD_VertexAttribs4svNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribs4svNV,
   [DISPATCH_CMD_VertexAttribs1fvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribs1fvNV,
   [DISPATCH_CMD_VertexAttribs2fvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribs2fvNV,
   [DISPATCH_CMD_VertexAttribs3fvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribs3fvNV,
   [DISPATCH_CMD_VertexAttribs4fvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribs4fvNV,
   [DISPATCH_CMD_VertexAttribs1dvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribs1dvNV,
   [DISPATCH_CMD_VertexAttribs2dvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribs2dvNV,
   [DISPATCH_CMD_VertexAttribs3dvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribs3dvNV,
   [DISPATCH_CMD_VertexAttribs4dvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribs4dvNV,
   [DISPATCH_CMD_VertexAttribs4ubvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribs4ubvNV,
   [DISPATCH_CMD_BindFragmentShaderATI] = (_mesa_unmarshal_func)_mesa_unmarshal_BindFragmentShaderATI,
   [DISPATCH_CMD_DeleteFragmentShaderATI] = (_mesa_unmarshal_func)_mesa_unmarshal_DeleteFragmentShaderATI,
   [DISPATCH_CMD_BeginFragmentShaderATI] = (_mesa_unmarshal_func)_mesa_unmarshal_BeginFragmentShaderATI,
   [DISPATCH_CMD_EndFragmentShaderATI] = (_mesa_unmarshal_func)_mesa_unmarshal_EndFragmentShaderATI,
   [DISPATCH_CMD_PassTexCoordATI] = (_mesa_unmarshal_func)_mesa_unmarshal_PassTexCoordATI,
   [DISPATCH_CMD_SampleMapATI] = (_mesa_unmarshal_func)_mesa_unmarshal_SampleMapATI,
   [DISPATCH_CMD_ColorFragmentOp1ATI] = (_mesa_unmarshal_func)_mesa_unmarshal_ColorFragmentOp1ATI,
   [DISPATCH_CMD_ColorFragmentOp2ATI] = (_mesa_unmarshal_func)_mesa_unmarshal_ColorFragmentOp2ATI,
   [DISPATCH_CMD_ColorFragmentOp3ATI] = (_mesa_unmarshal_func)_mesa_unmarshal_ColorFragmentOp3ATI,
   [DISPATCH_CMD_AlphaFragmentOp1ATI] = (_mesa_unmarshal_func)_mesa_unmarshal_AlphaFragmentOp1ATI,
   [DISPATCH_CMD_AlphaFragmentOp2ATI] = (_mesa_unmarshal_func)_mesa_unmarshal_AlphaFragmentOp2ATI,
   [DISPATCH_CMD_AlphaFragmentOp3ATI] = (_mesa_unmarshal_func)_mesa_unmarshal_AlphaFragmentOp3ATI,
   [DISPATCH_CMD_SetFragmentShaderConstantATI] = (_mesa_unmarshal_func)_mesa_unmarshal_SetFragmentShaderConstantATI,
   [DISPATCH_CMD_ActiveStencilFaceEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_ActiveStencilFaceEXT,
   [DISPATCH_CMD_DepthBoundsEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_DepthBoundsEXT,
   [DISPATCH_CMD_BindRenderbufferEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_BindRenderbufferEXT,
   [DISPATCH_CMD_BindFramebufferEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_BindFramebufferEXT,
   [DISPATCH_CMD_ProvokingVertex] = (_mesa_unmarshal_func)_mesa_unmarshal_ProvokingVertex,
   [DISPATCH_CMD_ColorMaski] = (_mesa_unmarshal_func)_mesa_unmarshal_ColorMaski,
   [DISPATCH_CMD_Enablei] = (_mesa_unmarshal_func)_mesa_unmarshal_Enablei,
   [DISPATCH_CMD_Disablei] = (_mesa_unmarshal_func)_mesa_unmarshal_Disablei,
   [DISPATCH_CMD_DeletePerfMonitorsAMD] = (_mesa_unmarshal_func)_mesa_unmarshal_DeletePerfMonitorsAMD,
   [DISPATCH_CMD_SelectPerfMonitorCountersAMD] = (_mesa_unmarshal_func)_mesa_unmarshal_SelectPerfMonitorCountersAMD,
   [DISPATCH_CMD_BeginPerfMonitorAMD] = (_mesa_unmarshal_func)_mesa_unmarshal_BeginPerfMonitorAMD,
   [DISPATCH_CMD_EndPerfMonitorAMD] = (_mesa_unmarshal_func)_mesa_unmarshal_EndPerfMonitorAMD,
   [DISPATCH_CMD_CopyImageSubDataNV] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyImageSubDataNV,
   [DISPATCH_CMD_MatrixLoadfEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MatrixLoadfEXT,
   [DISPATCH_CMD_MatrixLoaddEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MatrixLoaddEXT,
   [DISPATCH_CMD_MatrixMultfEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MatrixMultfEXT,
   [DISPATCH_CMD_MatrixMultdEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MatrixMultdEXT,
   [DISPATCH_CMD_MatrixLoadIdentityEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MatrixLoadIdentityEXT,
   [DISPATCH_CMD_MatrixRotatefEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MatrixRotatefEXT,
   [DISPATCH_CMD_MatrixRotatedEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MatrixRotatedEXT,
   [DISPATCH_CMD_MatrixScalefEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MatrixScalefEXT,
   [DISPATCH_CMD_MatrixScaledEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MatrixScaledEXT,
   [DISPATCH_CMD_MatrixTranslatefEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MatrixTranslatefEXT,
   [DISPATCH_CMD_MatrixTranslatedEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MatrixTranslatedEXT,
   [DISPATCH_CMD_MatrixOrthoEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MatrixOrthoEXT,
   [DISPATCH_CMD_MatrixFrustumEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MatrixFrustumEXT,
   [DISPATCH_CMD_MatrixPushEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MatrixPushEXT,
   [DISPATCH_CMD_MatrixPopEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MatrixPopEXT,
   [DISPATCH_CMD_ClientAttribDefaultEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_ClientAttribDefaultEXT,
   [DISPATCH_CMD_PushClientAttribDefaultEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_PushClientAttribDefaultEXT,
   [DISPATCH_CMD_TextureParameteriEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureParameteriEXT,
   [DISPATCH_CMD_TextureParameterivEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureParameterivEXT,
   [DISPATCH_CMD_TextureParameterfEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureParameterfEXT,
   [DISPATCH_CMD_TextureParameterfvEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureParameterfvEXT,
   [DISPATCH_CMD_TextureImage1DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureImage1DEXT,
   [DISPATCH_CMD_TextureImage2DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureImage2DEXT,
   [DISPATCH_CMD_TextureImage3DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureImage3DEXT,
   [DISPATCH_CMD_TextureSubImage1DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureSubImage1DEXT,
   [DISPATCH_CMD_TextureSubImage2DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureSubImage2DEXT,
   [DISPATCH_CMD_TextureSubImage3DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureSubImage3DEXT,
   [DISPATCH_CMD_CopyTextureImage1DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyTextureImage1DEXT,
   [DISPATCH_CMD_CopyTextureImage2DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyTextureImage2DEXT,
   [DISPATCH_CMD_CopyTextureSubImage1DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyTextureSubImage1DEXT,
   [DISPATCH_CMD_CopyTextureSubImage2DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyTextureSubImage2DEXT,
   [DISPATCH_CMD_CopyTextureSubImage3DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyTextureSubImage3DEXT,
   [DISPATCH_CMD_GetTextureImageEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_GetTextureImageEXT,
   [DISPATCH_CMD_BindMultiTextureEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_BindMultiTextureEXT,
   [DISPATCH_CMD_EnableClientStateiEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_EnableClientStateiEXT,
   [DISPATCH_CMD_DisableClientStateiEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_DisableClientStateiEXT,
   [DISPATCH_CMD_MultiTexEnviEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexEnviEXT,
   [DISPATCH_CMD_MultiTexEnvivEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexEnvivEXT,
   [DISPATCH_CMD_MultiTexEnvfEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexEnvfEXT,
   [DISPATCH_CMD_MultiTexEnvfvEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexEnvfvEXT,
   [DISPATCH_CMD_MultiTexParameteriEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexParameteriEXT,
   [DISPATCH_CMD_MultiTexParameterivEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexParameterivEXT,
   [DISPATCH_CMD_MultiTexParameterfEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexParameterfEXT,
   [DISPATCH_CMD_MultiTexParameterfvEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexParameterfvEXT,
   [DISPATCH_CMD_GetMultiTexImageEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_GetMultiTexImageEXT,
   [DISPATCH_CMD_MultiTexImage1DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexImage1DEXT,
   [DISPATCH_CMD_MultiTexImage2DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexImage2DEXT,
   [DISPATCH_CMD_MultiTexImage3DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexImage3DEXT,
   [DISPATCH_CMD_MultiTexSubImage1DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexSubImage1DEXT,
   [DISPATCH_CMD_MultiTexSubImage2DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexSubImage2DEXT,
   [DISPATCH_CMD_MultiTexSubImage3DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexSubImage3DEXT,
   [DISPATCH_CMD_CopyMultiTexImage1DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyMultiTexImage1DEXT,
   [DISPATCH_CMD_CopyMultiTexImage2DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyMultiTexImage2DEXT,
   [DISPATCH_CMD_CopyMultiTexSubImage1DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyMultiTexSubImage1DEXT,
   [DISPATCH_CMD_CopyMultiTexSubImage2DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyMultiTexSubImage2DEXT,
   [DISPATCH_CMD_CopyMultiTexSubImage3DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CopyMultiTexSubImage3DEXT,
   [DISPATCH_CMD_MultiTexGendEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexGendEXT,
   [DISPATCH_CMD_MultiTexGendvEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexGendvEXT,
   [DISPATCH_CMD_MultiTexGenfEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexGenfEXT,
   [DISPATCH_CMD_MultiTexGenfvEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexGenfvEXT,
   [DISPATCH_CMD_MultiTexGeniEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexGeniEXT,
   [DISPATCH_CMD_MultiTexGenivEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexGenivEXT,
   [DISPATCH_CMD_MultiTexCoordPointerEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoordPointerEXT,
   [DISPATCH_CMD_MatrixLoadTransposefEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MatrixLoadTransposefEXT,
   [DISPATCH_CMD_MatrixLoadTransposedEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MatrixLoadTransposedEXT,
   [DISPATCH_CMD_MatrixMultTransposefEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MatrixMultTransposefEXT,
   [DISPATCH_CMD_MatrixMultTransposedEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MatrixMultTransposedEXT,
   [DISPATCH_CMD_CompressedTextureImage1DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedTextureImage1DEXT,
   [DISPATCH_CMD_CompressedTextureImage2DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedTextureImage2DEXT,
   [DISPATCH_CMD_CompressedTextureImage3DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedTextureImage3DEXT,
   [DISPATCH_CMD_CompressedTextureSubImage1DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedTextureSubImage1DEXT,
   [DISPATCH_CMD_CompressedTextureSubImage2DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedTextureSubImage2DEXT,
   [DISPATCH_CMD_CompressedTextureSubImage3DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedTextureSubImage3DEXT,
   [DISPATCH_CMD_GetCompressedTextureImageEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_GetCompressedTextureImageEXT,
   [DISPATCH_CMD_CompressedMultiTexImage1DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedMultiTexImage1DEXT,
   [DISPATCH_CMD_CompressedMultiTexImage2DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedMultiTexImage2DEXT,
   [DISPATCH_CMD_CompressedMultiTexImage3DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedMultiTexImage3DEXT,
   [DISPATCH_CMD_CompressedMultiTexSubImage1DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedMultiTexSubImage1DEXT,
   [DISPATCH_CMD_CompressedMultiTexSubImage2DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedMultiTexSubImage2DEXT,
   [DISPATCH_CMD_CompressedMultiTexSubImage3DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_CompressedMultiTexSubImage3DEXT,
   [DISPATCH_CMD_GetCompressedMultiTexImageEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_GetCompressedMultiTexImageEXT,
   [DISPATCH_CMD_NamedBufferDataEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedBufferDataEXT,
   [DISPATCH_CMD_NamedBufferSubDataEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedBufferSubDataEXT,
   [DISPATCH_CMD_FlushMappedNamedBufferRangeEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_FlushMappedNamedBufferRangeEXT,
   [DISPATCH_CMD_FramebufferDrawBufferEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_FramebufferDrawBufferEXT,
   [DISPATCH_CMD_FramebufferDrawBuffersEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_FramebufferDrawBuffersEXT,
   [DISPATCH_CMD_FramebufferReadBufferEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_FramebufferReadBufferEXT,
   [DISPATCH_CMD_NamedFramebufferTexture1DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedFramebufferTexture1DEXT,
   [DISPATCH_CMD_NamedFramebufferTexture2DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedFramebufferTexture2DEXT,
   [DISPATCH_CMD_NamedFramebufferTexture3DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedFramebufferTexture3DEXT,
   [DISPATCH_CMD_NamedFramebufferRenderbufferEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedFramebufferRenderbufferEXT,
   [DISPATCH_CMD_NamedRenderbufferStorageEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedRenderbufferStorageEXT,
   [DISPATCH_CMD_GenerateTextureMipmapEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_GenerateTextureMipmapEXT,
   [DISPATCH_CMD_GenerateMultiTexMipmapEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_GenerateMultiTexMipmapEXT,
   [DISPATCH_CMD_NamedRenderbufferStorageMultisampleEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedRenderbufferStorageMultisampleEXT,
   [DISPATCH_CMD_NamedCopyBufferSubDataEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedCopyBufferSubDataEXT,
   [DISPATCH_CMD_VertexArrayVertexOffsetEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayVertexOffsetEXT,
   [DISPATCH_CMD_VertexArrayVertexOffsetEXT_packed] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayVertexOffsetEXT_packed,
   [DISPATCH_CMD_VertexArrayColorOffsetEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayColorOffsetEXT,
   [DISPATCH_CMD_VertexArrayColorOffsetEXT_packed] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayColorOffsetEXT_packed,
   [DISPATCH_CMD_VertexArrayEdgeFlagOffsetEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayEdgeFlagOffsetEXT,
   [DISPATCH_CMD_VertexArrayIndexOffsetEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayIndexOffsetEXT,
   [DISPATCH_CMD_VertexArrayIndexOffsetEXT_packed] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayIndexOffsetEXT_packed,
   [DISPATCH_CMD_VertexArrayNormalOffsetEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayNormalOffsetEXT,
   [DISPATCH_CMD_VertexArrayNormalOffsetEXT_packed] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayNormalOffsetEXT_packed,
   [DISPATCH_CMD_VertexArrayTexCoordOffsetEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayTexCoordOffsetEXT,
   [DISPATCH_CMD_VertexArrayTexCoordOffsetEXT_packed] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayTexCoordOffsetEXT_packed,
   [DISPATCH_CMD_VertexArrayMultiTexCoordOffsetEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayMultiTexCoordOffsetEXT,
   [DISPATCH_CMD_VertexArrayFogCoordOffsetEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayFogCoordOffsetEXT,
   [DISPATCH_CMD_VertexArrayFogCoordOffsetEXT_packed] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayFogCoordOffsetEXT_packed,
   [DISPATCH_CMD_VertexArraySecondaryColorOffsetEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArraySecondaryColorOffsetEXT,
   [DISPATCH_CMD_VertexArraySecondaryColorOffsetEXT_packed] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArraySecondaryColorOffsetEXT_packed,
   [DISPATCH_CMD_VertexArrayVertexAttribOffsetEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayVertexAttribOffsetEXT,
   [DISPATCH_CMD_VertexArrayVertexAttribIOffsetEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexArrayVertexAttribIOffsetEXT,
   [DISPATCH_CMD_EnableVertexArrayEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_EnableVertexArrayEXT,
   [DISPATCH_CMD_DisableVertexArrayEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_DisableVertexArrayEXT,
   [DISPATCH_CMD_EnableVertexArrayAttribEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_EnableVertexArrayAttribEXT,
   [DISPATCH_CMD_DisableVertexArrayAttribEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_DisableVertexArrayAttribEXT,
   [DISPATCH_CMD_NamedProgramStringEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedProgramStringEXT,
   [DISPATCH_CMD_NamedProgramLocalParameter4fEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedProgramLocalParameter4fEXT,
   [DISPATCH_CMD_NamedProgramLocalParameter4fvEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedProgramLocalParameter4fvEXT,
   [DISPATCH_CMD_NamedProgramLocalParameter4dEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedProgramLocalParameter4dEXT,
   [DISPATCH_CMD_NamedProgramLocalParameter4dvEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedProgramLocalParameter4dvEXT,
   [DISPATCH_CMD_TextureBufferEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureBufferEXT,
   [DISPATCH_CMD_MultiTexBufferEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexBufferEXT,
   [DISPATCH_CMD_TextureParameterIivEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureParameterIivEXT,
   [DISPATCH_CMD_TextureParameterIuivEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureParameterIuivEXT,
   [DISPATCH_CMD_MultiTexParameterIivEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexParameterIivEXT,
   [DISPATCH_CMD_MultiTexParameterIuivEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexParameterIuivEXT,
   [DISPATCH_CMD_NamedProgramLocalParameters4fvEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedProgramLocalParameters4fvEXT,
   [DISPATCH_CMD_BindImageTextureEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_BindImageTextureEXT,
   [DISPATCH_CMD_SubpixelPrecisionBiasNV] = (_mesa_unmarshal_func)_mesa_unmarshal_SubpixelPrecisionBiasNV,
   [DISPATCH_CMD_ConservativeRasterParameterfNV] = (_mesa_unmarshal_func)_mesa_unmarshal_ConservativeRasterParameterfNV,
   [DISPATCH_CMD_ConservativeRasterParameteriNV] = (_mesa_unmarshal_func)_mesa_unmarshal_ConservativeRasterParameteriNV,
   [DISPATCH_CMD_DeletePerfQueryINTEL] = (_mesa_unmarshal_func)_mesa_unmarshal_DeletePerfQueryINTEL,
   [DISPATCH_CMD_BeginPerfQueryINTEL] = (_mesa_unmarshal_func)_mesa_unmarshal_BeginPerfQueryINTEL,
   [DISPATCH_CMD_EndPerfQueryINTEL] = (_mesa_unmarshal_func)_mesa_unmarshal_EndPerfQueryINTEL,
   [DISPATCH_CMD_AlphaToCoverageDitherControlNV] = (_mesa_unmarshal_func)_mesa_unmarshal_AlphaToCoverageDitherControlNV,
   [DISPATCH_CMD_PolygonOffsetClampEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_PolygonOffsetClampEXT,
   [DISPATCH_CMD_WindowRectanglesEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_WindowRectanglesEXT,
   [DISPATCH_CMD_FramebufferFetchBarrierEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_FramebufferFetchBarrierEXT,
   [DISPATCH_CMD_TextureStorage1DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureStorage1DEXT,
   [DISPATCH_CMD_TextureStorage2DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureStorage2DEXT,
   [DISPATCH_CMD_TextureStorage3DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureStorage3DEXT,
   [DISPATCH_CMD_RenderbufferStorageMultisampleAdvancedAMD] = (_mesa_unmarshal_func)_mesa_unmarshal_RenderbufferStorageMultisampleAdvancedAMD,
   [DISPATCH_CMD_NamedRenderbufferStorageMultisampleAdvancedAMD] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedRenderbufferStorageMultisampleAdvancedAMD,
   [DISPATCH_CMD_StencilFuncSeparateATI] = (_mesa_unmarshal_func)_mesa_unmarshal_StencilFuncSeparateATI,
   [DISPATCH_CMD_ProgramEnvParameters4fvEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramEnvParameters4fvEXT,
   [DISPATCH_CMD_ProgramLocalParameters4fvEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_ProgramLocalParameters4fvEXT,
   [DISPATCH_CMD_InternalBufferSubDataCopyMESA] = (_mesa_unmarshal_func)_mesa_unmarshal_InternalBufferSubDataCopyMESA,
   [DISPATCH_CMD_InternalSetError] = (_mesa_unmarshal_func)_mesa_unmarshal_InternalSetError,
   [DISPATCH_CMD_DrawArraysUserBuf] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawArraysUserBuf,
   [DISPATCH_CMD_DrawElementsUserBuf] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawElementsUserBuf,
   [DISPATCH_CMD_DrawElementsUserBufPacked] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawElementsUserBufPacked,
   [DISPATCH_CMD_MultiDrawArraysUserBuf] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiDrawArraysUserBuf,
   [DISPATCH_CMD_MultiDrawElementsUserBuf] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiDrawElementsUserBuf,
   [DISPATCH_CMD_DrawArraysInstancedBaseInstanceDrawID] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawArraysInstancedBaseInstanceDrawID,
   [DISPATCH_CMD_DrawElementsInstancedBaseVertexBaseInstanceDrawID] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawElementsInstancedBaseVertexBaseInstanceDrawID,
   [DISPATCH_CMD_DrawElementsPacked] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawElementsPacked,
   [DISPATCH_CMD_InternalInvalidateFramebufferAncillaryMESA] = (_mesa_unmarshal_func)_mesa_unmarshal_InternalInvalidateFramebufferAncillaryMESA,
   [DISPATCH_CMD_InternalReleaseBufferMESA] = (_mesa_unmarshal_func)_mesa_unmarshal_InternalReleaseBufferMESA,
   [DISPATCH_CMD_ClearColorIiEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_ClearColorIiEXT,
   [DISPATCH_CMD_ClearColorIuiEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_ClearColorIuiEXT,
   [DISPATCH_CMD_TexParameterIiv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexParameterIiv,
   [DISPATCH_CMD_TexParameterIuiv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexParameterIuiv,
   [DISPATCH_CMD_VertexAttribI1iEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribI1iEXT,
   [DISPATCH_CMD_VertexAttribI2iEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribI2iEXT,
   [DISPATCH_CMD_VertexAttribI3iEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribI3iEXT,
   [DISPATCH_CMD_VertexAttribI4iEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribI4iEXT,
   [DISPATCH_CMD_VertexAttribI1uiEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribI1uiEXT,
   [DISPATCH_CMD_VertexAttribI2uiEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribI2uiEXT,
   [DISPATCH_CMD_VertexAttribI3uiEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribI3uiEXT,
   [DISPATCH_CMD_VertexAttribI4uiEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribI4uiEXT,
   [DISPATCH_CMD_VertexAttribI1iv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribI1iv,
   [DISPATCH_CMD_VertexAttribI2ivEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribI2ivEXT,
   [DISPATCH_CMD_VertexAttribI3ivEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribI3ivEXT,
   [DISPATCH_CMD_VertexAttribI4ivEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribI4ivEXT,
   [DISPATCH_CMD_VertexAttribI1uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribI1uiv,
   [DISPATCH_CMD_VertexAttribI2uivEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribI2uivEXT,
   [DISPATCH_CMD_VertexAttribI3uivEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribI3uivEXT,
   [DISPATCH_CMD_VertexAttribI4uivEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribI4uivEXT,
   [DISPATCH_CMD_VertexAttribI4bv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribI4bv,
   [DISPATCH_CMD_VertexAttribI4sv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribI4sv,
   [DISPATCH_CMD_VertexAttribI4ubv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribI4ubv,
   [DISPATCH_CMD_VertexAttribI4usv] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribI4usv,
   [DISPATCH_CMD_VertexAttribIPointer] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribIPointer,
   [DISPATCH_CMD_Uniform1ui] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform1ui,
   [DISPATCH_CMD_Uniform2ui] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform2ui,
   [DISPATCH_CMD_Uniform3ui] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform3ui,
   [DISPATCH_CMD_Uniform4ui] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform4ui,
   [DISPATCH_CMD_Uniform1uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform1uiv,
   [DISPATCH_CMD_Uniform2uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform2uiv,
   [DISPATCH_CMD_Uniform3uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform3uiv,
   [DISPATCH_CMD_Uniform4uiv] = (_mesa_unmarshal_func)_mesa_unmarshal_Uniform4uiv,
   [DISPATCH_CMD_BindFragDataLocation] = (_mesa_unmarshal_func)_mesa_unmarshal_BindFragDataLocation,
   [DISPATCH_CMD_ClearBufferiv] = (_mesa_unmarshal_func)_mesa_unmarshal_ClearBufferiv,
   [DISPATCH_CMD_ClearBufferuiv] = (_mesa_unmarshal_func)_mesa_unmarshal_ClearBufferuiv,
   [DISPATCH_CMD_ClearBufferfv] = (_mesa_unmarshal_func)_mesa_unmarshal_ClearBufferfv,
   [DISPATCH_CMD_ClearBufferfi] = (_mesa_unmarshal_func)_mesa_unmarshal_ClearBufferfi,
   [DISPATCH_CMD_BeginTransformFeedback] = (_mesa_unmarshal_func)_mesa_unmarshal_BeginTransformFeedback,
   [DISPATCH_CMD_EndTransformFeedback] = (_mesa_unmarshal_func)_mesa_unmarshal_EndTransformFeedback,
   [DISPATCH_CMD_BindBufferRange] = (_mesa_unmarshal_func)_mesa_unmarshal_BindBufferRange,
   [DISPATCH_CMD_BindBufferBase] = (_mesa_unmarshal_func)_mesa_unmarshal_BindBufferBase,
   [DISPATCH_CMD_BeginConditionalRender] = (_mesa_unmarshal_func)_mesa_unmarshal_BeginConditionalRender,
   [DISPATCH_CMD_EndConditionalRender] = (_mesa_unmarshal_func)_mesa_unmarshal_EndConditionalRender,
   [DISPATCH_CMD_PrimitiveRestartIndex] = (_mesa_unmarshal_func)_mesa_unmarshal_PrimitiveRestartIndex,
   [DISPATCH_CMD_FramebufferTexture] = (_mesa_unmarshal_func)_mesa_unmarshal_FramebufferTexture,
   [DISPATCH_CMD_PrimitiveRestartNV] = (_mesa_unmarshal_func)_mesa_unmarshal_PrimitiveRestartNV,
   [DISPATCH_CMD_BindBufferOffsetEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_BindBufferOffsetEXT,
   [DISPATCH_CMD_BindTransformFeedback] = (_mesa_unmarshal_func)_mesa_unmarshal_BindTransformFeedback,
   [DISPATCH_CMD_DeleteTransformFeedbacks] = (_mesa_unmarshal_func)_mesa_unmarshal_DeleteTransformFeedbacks,
   [DISPATCH_CMD_PauseTransformFeedback] = (_mesa_unmarshal_func)_mesa_unmarshal_PauseTransformFeedback,
   [DISPATCH_CMD_ResumeTransformFeedback] = (_mesa_unmarshal_func)_mesa_unmarshal_ResumeTransformFeedback,
   [DISPATCH_CMD_DrawTransformFeedback] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawTransformFeedback,
   [DISPATCH_CMD_DeleteMemoryObjectsEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_DeleteMemoryObjectsEXT,
   [DISPATCH_CMD_MemoryObjectParameterivEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MemoryObjectParameterivEXT,
   [DISPATCH_CMD_TexStorageMem2DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TexStorageMem2DEXT,
   [DISPATCH_CMD_TexStorageMem2DMultisampleEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TexStorageMem2DMultisampleEXT,
   [DISPATCH_CMD_TexStorageMem3DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TexStorageMem3DEXT,
   [DISPATCH_CMD_TexStorageMem3DMultisampleEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TexStorageMem3DMultisampleEXT,
   [DISPATCH_CMD_BufferStorageMemEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_BufferStorageMemEXT,
   [DISPATCH_CMD_TextureStorageMem2DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureStorageMem2DEXT,
   [DISPATCH_CMD_TextureStorageMem2DMultisampleEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureStorageMem2DMultisampleEXT,
   [DISPATCH_CMD_TextureStorageMem3DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureStorageMem3DEXT,
   [DISPATCH_CMD_TextureStorageMem3DMultisampleEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureStorageMem3DMultisampleEXT,
   [DISPATCH_CMD_NamedBufferStorageMemEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_NamedBufferStorageMemEXT,
   [DISPATCH_CMD_TexStorageMem1DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TexStorageMem1DEXT,
   [DISPATCH_CMD_TextureStorageMem1DEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_TextureStorageMem1DEXT,
   [DISPATCH_CMD_DeleteSemaphoresEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_DeleteSemaphoresEXT,
   [DISPATCH_CMD_SemaphoreParameterui64vEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_SemaphoreParameterui64vEXT,
   [DISPATCH_CMD_WaitSemaphoreEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_WaitSemaphoreEXT,
   [DISPATCH_CMD_ImportMemoryFdEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_ImportMemoryFdEXT,
   [DISPATCH_CMD_ImportSemaphoreFdEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_ImportSemaphoreFdEXT,
   [DISPATCH_CMD_ViewportSwizzleNV] = (_mesa_unmarshal_func)_mesa_unmarshal_ViewportSwizzleNV,
   [DISPATCH_CMD_Vertex2hNV] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex2hNV,
   [DISPATCH_CMD_Vertex2hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex2hvNV,
   [DISPATCH_CMD_Vertex3hNV] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex3hNV,
   [DISPATCH_CMD_Vertex3hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex3hvNV,
   [DISPATCH_CMD_Vertex4hNV] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex4hNV,
   [DISPATCH_CMD_Vertex4hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_Vertex4hvNV,
   [DISPATCH_CMD_Normal3hNV] = (_mesa_unmarshal_func)_mesa_unmarshal_Normal3hNV,
   [DISPATCH_CMD_Normal3hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_Normal3hvNV,
   [DISPATCH_CMD_Color3hNV] = (_mesa_unmarshal_func)_mesa_unmarshal_Color3hNV,
   [DISPATCH_CMD_Color3hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_Color3hvNV,
   [DISPATCH_CMD_Color4hNV] = (_mesa_unmarshal_func)_mesa_unmarshal_Color4hNV,
   [DISPATCH_CMD_Color4hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_Color4hvNV,
   [DISPATCH_CMD_TexCoord1hNV] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord1hNV,
   [DISPATCH_CMD_TexCoord1hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord1hvNV,
   [DISPATCH_CMD_TexCoord2hNV] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord2hNV,
   [DISPATCH_CMD_TexCoord2hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord2hvNV,
   [DISPATCH_CMD_TexCoord3hNV] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord3hNV,
   [DISPATCH_CMD_TexCoord3hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord3hvNV,
   [DISPATCH_CMD_TexCoord4hNV] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord4hNV,
   [DISPATCH_CMD_TexCoord4hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_TexCoord4hvNV,
   [DISPATCH_CMD_MultiTexCoord1hNV] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord1hNV,
   [DISPATCH_CMD_MultiTexCoord1hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord1hvNV,
   [DISPATCH_CMD_MultiTexCoord2hNV] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord2hNV,
   [DISPATCH_CMD_MultiTexCoord2hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord2hvNV,
   [DISPATCH_CMD_MultiTexCoord3hNV] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord3hNV,
   [DISPATCH_CMD_MultiTexCoord3hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord3hvNV,
   [DISPATCH_CMD_MultiTexCoord4hNV] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord4hNV,
   [DISPATCH_CMD_MultiTexCoord4hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord4hvNV,
   [DISPATCH_CMD_VertexAttrib1hNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib1hNV,
   [DISPATCH_CMD_VertexAttrib1hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib1hvNV,
   [DISPATCH_CMD_VertexAttrib2hNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib2hNV,
   [DISPATCH_CMD_VertexAttrib2hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib2hvNV,
   [DISPATCH_CMD_VertexAttrib3hNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib3hNV,
   [DISPATCH_CMD_VertexAttrib3hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib3hvNV,
   [DISPATCH_CMD_VertexAttrib4hNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4hNV,
   [DISPATCH_CMD_VertexAttrib4hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttrib4hvNV,
   [DISPATCH_CMD_VertexAttribs1hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribs1hvNV,
   [DISPATCH_CMD_VertexAttribs2hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribs2hvNV,
   [DISPATCH_CMD_VertexAttribs3hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribs3hvNV,
   [DISPATCH_CMD_VertexAttribs4hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_VertexAttribs4hvNV,
   [DISPATCH_CMD_FogCoordhNV] = (_mesa_unmarshal_func)_mesa_unmarshal_FogCoordhNV,
   [DISPATCH_CMD_FogCoordhvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_FogCoordhvNV,
   [DISPATCH_CMD_SecondaryColor3hNV] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColor3hNV,
   [DISPATCH_CMD_SecondaryColor3hvNV] = (_mesa_unmarshal_func)_mesa_unmarshal_SecondaryColor3hvNV,
   [DISPATCH_CMD_MemoryBarrierByRegion] = (_mesa_unmarshal_func)_mesa_unmarshal_MemoryBarrierByRegion,
   [DISPATCH_CMD_DrawMeshTasksEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawMeshTasksEXT,
   [DISPATCH_CMD_DrawMeshTasksIndirectEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawMeshTasksIndirectEXT,
   [DISPATCH_CMD_MultiDrawMeshTasksIndirectEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiDrawMeshTasksIndirectEXT,
   [DISPATCH_CMD_MultiDrawMeshTasksIndirectCountEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiDrawMeshTasksIndirectCountEXT,
   [DISPATCH_CMD_AlphaFuncx] = (_mesa_unmarshal_func)_mesa_unmarshal_AlphaFuncx,
   [DISPATCH_CMD_ClearColorx] = (_mesa_unmarshal_func)_mesa_unmarshal_ClearColorx,
   [DISPATCH_CMD_ClearDepthx] = (_mesa_unmarshal_func)_mesa_unmarshal_ClearDepthx,
   [DISPATCH_CMD_Color4x] = (_mesa_unmarshal_func)_mesa_unmarshal_Color4x,
   [DISPATCH_CMD_DepthRangex] = (_mesa_unmarshal_func)_mesa_unmarshal_DepthRangex,
   [DISPATCH_CMD_Fogx] = (_mesa_unmarshal_func)_mesa_unmarshal_Fogx,
   [DISPATCH_CMD_Fogxv] = (_mesa_unmarshal_func)_mesa_unmarshal_Fogxv,
   [DISPATCH_CMD_Frustumx] = (_mesa_unmarshal_func)_mesa_unmarshal_Frustumx,
   [DISPATCH_CMD_LightModelx] = (_mesa_unmarshal_func)_mesa_unmarshal_LightModelx,
   [DISPATCH_CMD_LightModelxv] = (_mesa_unmarshal_func)_mesa_unmarshal_LightModelxv,
   [DISPATCH_CMD_Lightx] = (_mesa_unmarshal_func)_mesa_unmarshal_Lightx,
   [DISPATCH_CMD_Lightxv] = (_mesa_unmarshal_func)_mesa_unmarshal_Lightxv,
   [DISPATCH_CMD_LineWidthx] = (_mesa_unmarshal_func)_mesa_unmarshal_LineWidthx,
   [DISPATCH_CMD_LoadMatrixx] = (_mesa_unmarshal_func)_mesa_unmarshal_LoadMatrixx,
   [DISPATCH_CMD_Materialx] = (_mesa_unmarshal_func)_mesa_unmarshal_Materialx,
   [DISPATCH_CMD_Materialxv] = (_mesa_unmarshal_func)_mesa_unmarshal_Materialxv,
   [DISPATCH_CMD_MultMatrixx] = (_mesa_unmarshal_func)_mesa_unmarshal_MultMatrixx,
   [DISPATCH_CMD_MultiTexCoord4x] = (_mesa_unmarshal_func)_mesa_unmarshal_MultiTexCoord4x,
   [DISPATCH_CMD_Normal3x] = (_mesa_unmarshal_func)_mesa_unmarshal_Normal3x,
   [DISPATCH_CMD_Orthox] = (_mesa_unmarshal_func)_mesa_unmarshal_Orthox,
   [DISPATCH_CMD_PointSizex] = (_mesa_unmarshal_func)_mesa_unmarshal_PointSizex,
   [DISPATCH_CMD_PolygonOffsetx] = (_mesa_unmarshal_func)_mesa_unmarshal_PolygonOffsetx,
   [DISPATCH_CMD_Rotatex] = (_mesa_unmarshal_func)_mesa_unmarshal_Rotatex,
   [DISPATCH_CMD_SampleCoveragex] = (_mesa_unmarshal_func)_mesa_unmarshal_SampleCoveragex,
   [DISPATCH_CMD_Scalex] = (_mesa_unmarshal_func)_mesa_unmarshal_Scalex,
   [DISPATCH_CMD_TexEnvx] = (_mesa_unmarshal_func)_mesa_unmarshal_TexEnvx,
   [DISPATCH_CMD_TexEnvxv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexEnvxv,
   [DISPATCH_CMD_TexParameterx] = (_mesa_unmarshal_func)_mesa_unmarshal_TexParameterx,
   [DISPATCH_CMD_Translatex] = (_mesa_unmarshal_func)_mesa_unmarshal_Translatex,
   [DISPATCH_CMD_ClipPlanex] = (_mesa_unmarshal_func)_mesa_unmarshal_ClipPlanex,
   [DISPATCH_CMD_PointParameterx] = (_mesa_unmarshal_func)_mesa_unmarshal_PointParameterx,
   [DISPATCH_CMD_PointParameterxv] = (_mesa_unmarshal_func)_mesa_unmarshal_PointParameterxv,
   [DISPATCH_CMD_TexParameterxv] = (_mesa_unmarshal_func)_mesa_unmarshal_TexParameterxv,
   [DISPATCH_CMD_TexGenxOES] = (_mesa_unmarshal_func)_mesa_unmarshal_TexGenxOES,
   [DISPATCH_CMD_TexGenxvOES] = (_mesa_unmarshal_func)_mesa_unmarshal_TexGenxvOES,
   [DISPATCH_CMD_ClipPlanef] = (_mesa_unmarshal_func)_mesa_unmarshal_ClipPlanef,
   [DISPATCH_CMD_Frustumf] = (_mesa_unmarshal_func)_mesa_unmarshal_Frustumf,
   [DISPATCH_CMD_Orthof] = (_mesa_unmarshal_func)_mesa_unmarshal_Orthof,
   [DISPATCH_CMD_DrawTexiOES] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawTexiOES,
   [DISPATCH_CMD_DrawTexivOES] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawTexivOES,
   [DISPATCH_CMD_DrawTexfOES] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawTexfOES,
   [DISPATCH_CMD_DrawTexfvOES] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawTexfvOES,
   [DISPATCH_CMD_DrawTexsOES] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawTexsOES,
   [DISPATCH_CMD_DrawTexsvOES] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawTexsvOES,
   [DISPATCH_CMD_DrawTexxOES] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawTexxOES,
   [DISPATCH_CMD_DrawTexxvOES] = (_mesa_unmarshal_func)_mesa_unmarshal_DrawTexxvOES,
   [DISPATCH_CMD_PointSizePointerOES] = (_mesa_unmarshal_func)_mesa_unmarshal_PointSizePointerOES,
   [DISPATCH_CMD_DiscardFramebufferEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_DiscardFramebufferEXT,
   [DISPATCH_CMD_FramebufferTexture2DMultisampleEXT] = (_mesa_unmarshal_func)_mesa_unmarshal_FramebufferTexture2DMultisampleEXT,
   [DISPATCH_CMD_DepthRangeArrayfvOES] = (_mesa_unmarshal_func)_mesa_unmarshal_DepthRangeArrayfvOES,
   [DISPATCH_CMD_DepthRangeIndexedfOES] = (_mesa_unmarshal_func)_mesa_unmarshal_DepthRangeIndexedfOES,
   [DISPATCH_CMD_FramebufferParameteriMESA] = (_mesa_unmarshal_func)_mesa_unmarshal_FramebufferParameteriMESA,
};

const char *_mesa_unmarshal_func_name[NUM_DISPATCH_CMD] = {
   [DISPATCH_CMD_NewList] = "NewList",
   [DISPATCH_CMD_EndList] = "EndList",
   [DISPATCH_CMD_CallList] = "CallList",
   [DISPATCH_CMD_CallLists] = "CallLists",
   [DISPATCH_CMD_DeleteLists] = "DeleteLists",
   [DISPATCH_CMD_ListBase] = "ListBase",
   [DISPATCH_CMD_Begin] = "Begin",
   [DISPATCH_CMD_Bitmap] = "Bitmap",
   [DISPATCH_CMD_Color3b] = "Color3b",
   [DISPATCH_CMD_Color3bv] = "Color3bv",
   [DISPATCH_CMD_Color3d] = "Color3d",
   [DISPATCH_CMD_Color3dv] = "Color3dv",
   [DISPATCH_CMD_Color3f] = "Color3f",
   [DISPATCH_CMD_Color3fv] = "Color3fv",
   [DISPATCH_CMD_Color3i] = "Color3i",
   [DISPATCH_CMD_Color3iv] = "Color3iv",
   [DISPATCH_CMD_Color3s] = "Color3s",
   [DISPATCH_CMD_Color3sv] = "Color3sv",
   [DISPATCH_CMD_Color3ub] = "Color3ub",
   [DISPATCH_CMD_Color3ubv] = "Color3ubv",
   [DISPATCH_CMD_Color3ui] = "Color3ui",
   [DISPATCH_CMD_Color3uiv] = "Color3uiv",
   [DISPATCH_CMD_Color3us] = "Color3us",
   [DISPATCH_CMD_Color3usv] = "Color3usv",
   [DISPATCH_CMD_Color4b] = "Color4b",
   [DISPATCH_CMD_Color4bv] = "Color4bv",
   [DISPATCH_CMD_Color4d] = "Color4d",
   [DISPATCH_CMD_Color4dv] = "Color4dv",
   [DISPATCH_CMD_Color4f] = "Color4f",
   [DISPATCH_CMD_Color4fv] = "Color4fv",
   [DISPATCH_CMD_Color4i] = "Color4i",
   [DISPATCH_CMD_Color4iv] = "Color4iv",
   [DISPATCH_CMD_Color4s] = "Color4s",
   [DISPATCH_CMD_Color4sv] = "Color4sv",
   [DISPATCH_CMD_Color4ub] = "Color4ub",
   [DISPATCH_CMD_Color4ubv] = "Color4ubv",
   [DISPATCH_CMD_Color4ui] = "Color4ui",
   [DISPATCH_CMD_Color4uiv] = "Color4uiv",
   [DISPATCH_CMD_Color4us] = "Color4us",
   [DISPATCH_CMD_Color4usv] = "Color4usv",
   [DISPATCH_CMD_EdgeFlag] = "EdgeFlag",
   [DISPATCH_CMD_EdgeFlagv] = "EdgeFlagv",
   [DISPATCH_CMD_End] = "End",
   [DISPATCH_CMD_Indexd] = "Indexd",
   [DISPATCH_CMD_Indexdv] = "Indexdv",
   [DISPATCH_CMD_Indexf] = "Indexf",
   [DISPATCH_CMD_Indexfv] = "Indexfv",
   [DISPATCH_CMD_Indexi] = "Indexi",
   [DISPATCH_CMD_Indexiv] = "Indexiv",
   [DISPATCH_CMD_Indexs] = "Indexs",
   [DISPATCH_CMD_Indexsv] = "Indexsv",
   [DISPATCH_CMD_Normal3b] = "Normal3b",
   [DISPATCH_CMD_Normal3bv] = "Normal3bv",
   [DISPATCH_CMD_Normal3d] = "Normal3d",
   [DISPATCH_CMD_Normal3dv] = "Normal3dv",
   [DISPATCH_CMD_Normal3f] = "Normal3f",
   [DISPATCH_CMD_Normal3fv] = "Normal3fv",
   [DISPATCH_CMD_Normal3i] = "Normal3i",
   [DISPATCH_CMD_Normal3iv] = "Normal3iv",
   [DISPATCH_CMD_Normal3s] = "Normal3s",
   [DISPATCH_CMD_Normal3sv] = "Normal3sv",
   [DISPATCH_CMD_RasterPos2d] = "RasterPos2d",
   [DISPATCH_CMD_RasterPos2dv] = "RasterPos2dv",
   [DISPATCH_CMD_RasterPos2f] = "RasterPos2f",
   [DISPATCH_CMD_RasterPos2fv] = "RasterPos2fv",
   [DISPATCH_CMD_RasterPos2i] = "RasterPos2i",
   [DISPATCH_CMD_RasterPos2iv] = "RasterPos2iv",
   [DISPATCH_CMD_RasterPos2s] = "RasterPos2s",
   [DISPATCH_CMD_RasterPos2sv] = "RasterPos2sv",
   [DISPATCH_CMD_RasterPos3d] = "RasterPos3d",
   [DISPATCH_CMD_RasterPos3dv] = "RasterPos3dv",
   [DISPATCH_CMD_RasterPos3f] = "RasterPos3f",
   [DISPATCH_CMD_RasterPos3fv] = "RasterPos3fv",
   [DISPATCH_CMD_RasterPos3i] = "RasterPos3i",
   [DISPATCH_CMD_RasterPos3iv] = "RasterPos3iv",
   [DISPATCH_CMD_RasterPos3s] = "RasterPos3s",
   [DISPATCH_CMD_RasterPos3sv] = "RasterPos3sv",
   [DISPATCH_CMD_RasterPos4d] = "RasterPos4d",
   [DISPATCH_CMD_RasterPos4dv] = "RasterPos4dv",
   [DISPATCH_CMD_RasterPos4f] = "RasterPos4f",
   [DISPATCH_CMD_RasterPos4fv] = "RasterPos4fv",
   [DISPATCH_CMD_RasterPos4i] = "RasterPos4i",
   [DISPATCH_CMD_RasterPos4iv] = "RasterPos4iv",
   [DISPATCH_CMD_RasterPos4s] = "RasterPos4s",
   [DISPATCH_CMD_RasterPos4sv] = "RasterPos4sv",
   [DISPATCH_CMD_Rectd] = "Rectd",
   [DISPATCH_CMD_Rectdv] = "Rectdv",
   [DISPATCH_CMD_Rectf] = "Rectf",
   [DISPATCH_CMD_Rectfv] = "Rectfv",
   [DISPATCH_CMD_Recti] = "Recti",
   [DISPATCH_CMD_Rectiv] = "Rectiv",
   [DISPATCH_CMD_Rects] = "Rects",
   [DISPATCH_CMD_Rectsv] = "Rectsv",
   [DISPATCH_CMD_TexCoord1d] = "TexCoord1d",
   [DISPATCH_CMD_TexCoord1dv] = "TexCoord1dv",
   [DISPATCH_CMD_TexCoord1f] = "TexCoord1f",
   [DISPATCH_CMD_TexCoord1fv] = "TexCoord1fv",
   [DISPATCH_CMD_TexCoord1i] = "TexCoord1i",
   [DISPATCH_CMD_TexCoord1iv] = "TexCoord1iv",
   [DISPATCH_CMD_TexCoord1s] = "TexCoord1s",
   [DISPATCH_CMD_TexCoord1sv] = "TexCoord1sv",
   [DISPATCH_CMD_TexCoord2d] = "TexCoord2d",
   [DISPATCH_CMD_TexCoord2dv] = "TexCoord2dv",
   [DISPATCH_CMD_TexCoord2f] = "TexCoord2f",
   [DISPATCH_CMD_TexCoord2fv] = "TexCoord2fv",
   [DISPATCH_CMD_TexCoord2i] = "TexCoord2i",
   [DISPATCH_CMD_TexCoord2iv] = "TexCoord2iv",
   [DISPATCH_CMD_TexCoord2s] = "TexCoord2s",
   [DISPATCH_CMD_TexCoord2sv] = "TexCoord2sv",
   [DISPATCH_CMD_TexCoord3d] = "TexCoord3d",
   [DISPATCH_CMD_TexCoord3dv] = "TexCoord3dv",
   [DISPATCH_CMD_TexCoord3f] = "TexCoord3f",
   [DISPATCH_CMD_TexCoord3fv] = "TexCoord3fv",
   [DISPATCH_CMD_TexCoord3i] = "TexCoord3i",
   [DISPATCH_CMD_TexCoord3iv] = "TexCoord3iv",
   [DISPATCH_CMD_TexCoord3s] = "TexCoord3s",
   [DISPATCH_CMD_TexCoord3sv] = "TexCoord3sv",
   [DISPATCH_CMD_TexCoord4d] = "TexCoord4d",
   [DISPATCH_CMD_TexCoord4dv] = "TexCoord4dv",
   [DISPATCH_CMD_TexCoord4f] = "TexCoord4f",
   [DISPATCH_CMD_TexCoord4fv] = "TexCoord4fv",
   [DISPATCH_CMD_TexCoord4i] = "TexCoord4i",
   [DISPATCH_CMD_TexCoord4iv] = "TexCoord4iv",
   [DISPATCH_CMD_TexCoord4s] = "TexCoord4s",
   [DISPATCH_CMD_TexCoord4sv] = "TexCoord4sv",
   [DISPATCH_CMD_Vertex2d] = "Vertex2d",
   [DISPATCH_CMD_Vertex2dv] = "Vertex2dv",
   [DISPATCH_CMD_Vertex2f] = "Vertex2f",
   [DISPATCH_CMD_Vertex2fv] = "Vertex2fv",
   [DISPATCH_CMD_Vertex2i] = "Vertex2i",
   [DISPATCH_CMD_Vertex2iv] = "Vertex2iv",
   [DISPATCH_CMD_Vertex2s] = "Vertex2s",
   [DISPATCH_CMD_Vertex2sv] = "Vertex2sv",
   [DISPATCH_CMD_Vertex3d] = "Vertex3d",
   [DISPATCH_CMD_Vertex3dv] = "Vertex3dv",
   [DISPATCH_CMD_Vertex3f] = "Vertex3f",
   [DISPATCH_CMD_Vertex3fv] = "Vertex3fv",
   [DISPATCH_CMD_Vertex3i] = "Vertex3i",
   [DISPATCH_CMD_Vertex3iv] = "Vertex3iv",
   [DISPATCH_CMD_Vertex3s] = "Vertex3s",
   [DISPATCH_CMD_Vertex3sv] = "Vertex3sv",
   [DISPATCH_CMD_Vertex4d] = "Vertex4d",
   [DISPATCH_CMD_Vertex4dv] = "Vertex4dv",
   [DISPATCH_CMD_Vertex4f] = "Vertex4f",
   [DISPATCH_CMD_Vertex4fv] = "Vertex4fv",
   [DISPATCH_CMD_Vertex4i] = "Vertex4i",
   [DISPATCH_CMD_Vertex4iv] = "Vertex4iv",
   [DISPATCH_CMD_Vertex4s] = "Vertex4s",
   [DISPATCH_CMD_Vertex4sv] = "Vertex4sv",
   [DISPATCH_CMD_ClipPlane] = "ClipPlane",
   [DISPATCH_CMD_ColorMaterial] = "ColorMaterial",
   [DISPATCH_CMD_CullFace] = "CullFace",
   [DISPATCH_CMD_Fogf] = "Fogf",
   [DISPATCH_CMD_Fogfv] = "Fogfv",
   [DISPATCH_CMD_Fogi] = "Fogi",
   [DISPATCH_CMD_Fogiv] = "Fogiv",
   [DISPATCH_CMD_FrontFace] = "FrontFace",
   [DISPATCH_CMD_Hint] = "Hint",
   [DISPATCH_CMD_Lightf] = "Lightf",
   [DISPATCH_CMD_Lightfv] = "Lightfv",
   [DISPATCH_CMD_Lighti] = "Lighti",
   [DISPATCH_CMD_Lightiv] = "Lightiv",
   [DISPATCH_CMD_LightModelf] = "LightModelf",
   [DISPATCH_CMD_LightModelfv] = "LightModelfv",
   [DISPATCH_CMD_LightModeli] = "LightModeli",
   [DISPATCH_CMD_LightModeliv] = "LightModeliv",
   [DISPATCH_CMD_LineStipple] = "LineStipple",
   [DISPATCH_CMD_LineWidth] = "LineWidth",
   [DISPATCH_CMD_Materialf] = "Materialf",
   [DISPATCH_CMD_Materialfv] = "Materialfv",
   [DISPATCH_CMD_Materiali] = "Materiali",
   [DISPATCH_CMD_Materialiv] = "Materialiv",
   [DISPATCH_CMD_PointSize] = "PointSize",
   [DISPATCH_CMD_PolygonMode] = "PolygonMode",
   [DISPATCH_CMD_PolygonStipple] = "PolygonStipple",
   [DISPATCH_CMD_Scissor] = "Scissor",
   [DISPATCH_CMD_ShadeModel] = "ShadeModel",
   [DISPATCH_CMD_TexParameterf] = "TexParameterf",
   [DISPATCH_CMD_TexParameterfv] = "TexParameterfv",
   [DISPATCH_CMD_TexParameteri] = "TexParameteri",
   [DISPATCH_CMD_TexParameteriv] = "TexParameteriv",
   [DISPATCH_CMD_TexImage1D] = "TexImage1D",
   [DISPATCH_CMD_TexImage2D] = "TexImage2D",
   [DISPATCH_CMD_TexEnvf] = "TexEnvf",
   [DISPATCH_CMD_TexEnvfv] = "TexEnvfv",
   [DISPATCH_CMD_TexEnvi] = "TexEnvi",
   [DISPATCH_CMD_TexEnviv] = "TexEnviv",
   [DISPATCH_CMD_TexGend] = "TexGend",
   [DISPATCH_CMD_TexGendv] = "TexGendv",
   [DISPATCH_CMD_TexGenf] = "TexGenf",
   [DISPATCH_CMD_TexGenfv] = "TexGenfv",
   [DISPATCH_CMD_TexGeni] = "TexGeni",
   [DISPATCH_CMD_TexGeniv] = "TexGeniv",
   [DISPATCH_CMD_InitNames] = "InitNames",
   [DISPATCH_CMD_LoadName] = "LoadName",
   [DISPATCH_CMD_PassThrough] = "PassThrough",
   [DISPATCH_CMD_PopName] = "PopName",
   [DISPATCH_CMD_PushName] = "PushName",
   [DISPATCH_CMD_DrawBuffer] = "DrawBuffer",
   [DISPATCH_CMD_Clear] = "Clear",
   [DISPATCH_CMD_ClearAccum] = "ClearAccum",
   [DISPATCH_CMD_ClearIndex] = "ClearIndex",
   [DISPATCH_CMD_ClearColor] = "ClearColor",
   [DISPATCH_CMD_ClearStencil] = "ClearStencil",
   [DISPATCH_CMD_ClearDepth] = "ClearDepth",
   [DISPATCH_CMD_StencilMask] = "StencilMask",
   [DISPATCH_CMD_ColorMask] = "ColorMask",
   [DISPATCH_CMD_DepthMask] = "DepthMask",
   [DISPATCH_CMD_IndexMask] = "IndexMask",
   [DISPATCH_CMD_Accum] = "Accum",
   [DISPATCH_CMD_Disable] = "Disable",
   [DISPATCH_CMD_Enable] = "Enable",
   [DISPATCH_CMD_Flush] = "Flush",
   [DISPATCH_CMD_PopAttrib] = "PopAttrib",
   [DISPATCH_CMD_PushAttrib] = "PushAttrib",
   [DISPATCH_CMD_MapGrid1d] = "MapGrid1d",
   [DISPATCH_CMD_MapGrid1f] = "MapGrid1f",
   [DISPATCH_CMD_MapGrid2d] = "MapGrid2d",
   [DISPATCH_CMD_MapGrid2f] = "MapGrid2f",
   [DISPATCH_CMD_EvalCoord1d] = "EvalCoord1d",
   [DISPATCH_CMD_EvalCoord1dv] = "EvalCoord1dv",
   [DISPATCH_CMD_EvalCoord1f] = "EvalCoord1f",
   [DISPATCH_CMD_EvalCoord1fv] = "EvalCoord1fv",
   [DISPATCH_CMD_EvalCoord2d] = "EvalCoord2d",
   [DISPATCH_CMD_EvalCoord2dv] = "EvalCoord2dv",
   [DISPATCH_CMD_EvalCoord2f] = "EvalCoord2f",
   [DISPATCH_CMD_EvalCoord2fv] = "EvalCoord2fv",
   [DISPATCH_CMD_EvalMesh1] = "EvalMesh1",
   [DISPATCH_CMD_EvalPoint1] = "EvalPoint1",
   [DISPATCH_CMD_EvalMesh2] = "EvalMesh2",
   [DISPATCH_CMD_EvalPoint2] = "EvalPoint2",
   [DISPATCH_CMD_AlphaFunc] = "AlphaFunc",
   [DISPATCH_CMD_BlendFunc] = "BlendFunc",
   [DISPATCH_CMD_LogicOp] = "LogicOp",
   [DISPATCH_CMD_StencilFunc] = "StencilFunc",
   [DISPATCH_CMD_StencilOp] = "StencilOp",
   [DISPATCH_CMD_DepthFunc] = "DepthFunc",
   [DISPATCH_CMD_PixelZoom] = "PixelZoom",
   [DISPATCH_CMD_PixelTransferf] = "PixelTransferf",
   [DISPATCH_CMD_PixelTransferi] = "PixelTransferi",
   [DISPATCH_CMD_PixelStoref] = "PixelStoref",
   [DISPATCH_CMD_PixelStorei] = "PixelStorei",
   [DISPATCH_CMD_PixelMapfv] = "PixelMapfv",
   [DISPATCH_CMD_PixelMapuiv] = "PixelMapuiv",
   [DISPATCH_CMD_PixelMapusv] = "PixelMapusv",
   [DISPATCH_CMD_ReadBuffer] = "ReadBuffer",
   [DISPATCH_CMD_CopyPixels] = "CopyPixels",
   [DISPATCH_CMD_ReadPixels] = "ReadPixels",
   [DISPATCH_CMD_DrawPixels] = "DrawPixels",
   [DISPATCH_CMD_GetIntegerv] = "GetIntegerv",
   [DISPATCH_CMD_GetPixelMapfv] = "GetPixelMapfv",
   [DISPATCH_CMD_GetPixelMapuiv] = "GetPixelMapuiv",
   [DISPATCH_CMD_GetPixelMapusv] = "GetPixelMapusv",
   [DISPATCH_CMD_GetPolygonStipple] = "GetPolygonStipple",
   [DISPATCH_CMD_GetTexImage] = "GetTexImage",
   [DISPATCH_CMD_DepthRange] = "DepthRange",
   [DISPATCH_CMD_Frustum] = "Frustum",
   [DISPATCH_CMD_LoadIdentity] = "LoadIdentity",
   [DISPATCH_CMD_LoadMatrixf] = "LoadMatrixf",
   [DISPATCH_CMD_LoadMatrixd] = "LoadMatrixd",
   [DISPATCH_CMD_MatrixMode] = "MatrixMode",
   [DISPATCH_CMD_MultMatrixf] = "MultMatrixf",
   [DISPATCH_CMD_MultMatrixd] = "MultMatrixd",
   [DISPATCH_CMD_Ortho] = "Ortho",
   [DISPATCH_CMD_PopMatrix] = "PopMatrix",
   [DISPATCH_CMD_PushMatrix] = "PushMatrix",
   [DISPATCH_CMD_Rotated] = "Rotated",
   [DISPATCH_CMD_Rotatef] = "Rotatef",
   [DISPATCH_CMD_Scaled] = "Scaled",
   [DISPATCH_CMD_Scalef] = "Scalef",
   [DISPATCH_CMD_Translated] = "Translated",
   [DISPATCH_CMD_Translatef] = "Translatef",
   [DISPATCH_CMD_Viewport] = "Viewport",
   [DISPATCH_CMD_ColorPointer] = "ColorPointer",
   [DISPATCH_CMD_DisableClientState] = "DisableClientState",
   [DISPATCH_CMD_DrawArrays] = "DrawArrays",
   [DISPATCH_CMD_DrawElements] = "DrawElements",
   [DISPATCH_CMD_EdgeFlagPointer] = "EdgeFlagPointer",
   [DISPATCH_CMD_EnableClientState] = "EnableClientState",
   [DISPATCH_CMD_IndexPointer] = "IndexPointer",
   [DISPATCH_CMD_InterleavedArrays] = "InterleavedArrays",
   [DISPATCH_CMD_NormalPointer] = "NormalPointer",
   [DISPATCH_CMD_TexCoordPointer] = "TexCoordPointer",
   [DISPATCH_CMD_VertexPointer] = "VertexPointer",
   [DISPATCH_CMD_PolygonOffset] = "PolygonOffset",
   [DISPATCH_CMD_CopyTexImage1D] = "CopyTexImage1D",
   [DISPATCH_CMD_CopyTexImage2D] = "CopyTexImage2D",
   [DISPATCH_CMD_CopyTexSubImage1D] = "CopyTexSubImage1D",
   [DISPATCH_CMD_CopyTexSubImage2D] = "CopyTexSubImage2D",
   [DISPATCH_CMD_TexSubImage1D] = "TexSubImage1D",
   [DISPATCH_CMD_TexSubImage2D] = "TexSubImage2D",
   [DISPATCH_CMD_BindTexture] = "BindTexture",
   [DISPATCH_CMD_DeleteTextures] = "DeleteTextures",
   [DISPATCH_CMD_PrioritizeTextures] = "PrioritizeTextures",
   [DISPATCH_CMD_Indexub] = "Indexub",
   [DISPATCH_CMD_Indexubv] = "Indexubv",
   [DISPATCH_CMD_PopClientAttrib] = "PopClientAttrib",
   [DISPATCH_CMD_PushClientAttrib] = "PushClientAttrib",
   [DISPATCH_CMD_BlendColor] = "BlendColor",
   [DISPATCH_CMD_BlendEquation] = "BlendEquation",
   [DISPATCH_CMD_DrawRangeElements] = "DrawRangeElements",
   [DISPATCH_CMD_TexImage3D] = "TexImage3D",
   [DISPATCH_CMD_TexSubImage3D] = "TexSubImage3D",
   [DISPATCH_CMD_CopyTexSubImage3D] = "CopyTexSubImage3D",
   [DISPATCH_CMD_ActiveTexture] = "ActiveTexture",
   [DISPATCH_CMD_ClientActiveTexture] = "ClientActiveTexture",
   [DISPATCH_CMD_MultiTexCoord1d] = "MultiTexCoord1d",
   [DISPATCH_CMD_MultiTexCoord1dv] = "MultiTexCoord1dv",
   [DISPATCH_CMD_MultiTexCoord1fARB] = "MultiTexCoord1fARB",
   [DISPATCH_CMD_MultiTexCoord1fvARB] = "MultiTexCoord1fvARB",
   [DISPATCH_CMD_MultiTexCoord1i] = "MultiTexCoord1i",
   [DISPATCH_CMD_MultiTexCoord1iv] = "MultiTexCoord1iv",
   [DISPATCH_CMD_MultiTexCoord1s] = "MultiTexCoord1s",
   [DISPATCH_CMD_MultiTexCoord1sv] = "MultiTexCoord1sv",
   [DISPATCH_CMD_MultiTexCoord2d] = "MultiTexCoord2d",
   [DISPATCH_CMD_MultiTexCoord2dv] = "MultiTexCoord2dv",
   [DISPATCH_CMD_MultiTexCoord2fARB] = "MultiTexCoord2fARB",
   [DISPATCH_CMD_MultiTexCoord2fvARB] = "MultiTexCoord2fvARB",
   [DISPATCH_CMD_MultiTexCoord2i] = "MultiTexCoord2i",
   [DISPATCH_CMD_MultiTexCoord2iv] = "MultiTexCoord2iv",
   [DISPATCH_CMD_MultiTexCoord2s] = "MultiTexCoord2s",
   [DISPATCH_CMD_MultiTexCoord2sv] = "MultiTexCoord2sv",
   [DISPATCH_CMD_MultiTexCoord3d] = "MultiTexCoord3d",
   [DISPATCH_CMD_MultiTexCoord3dv] = "MultiTexCoord3dv",
   [DISPATCH_CMD_MultiTexCoord3fARB] = "MultiTexCoord3fARB",
   [DISPATCH_CMD_MultiTexCoord3fvARB] = "MultiTexCoord3fvARB",
   [DISPATCH_CMD_MultiTexCoord3i] = "MultiTexCoord3i",
   [DISPATCH_CMD_MultiTexCoord3iv] = "MultiTexCoord3iv",
   [DISPATCH_CMD_MultiTexCoord3s] = "MultiTexCoord3s",
   [DISPATCH_CMD_MultiTexCoord3sv] = "MultiTexCoord3sv",
   [DISPATCH_CMD_MultiTexCoord4d] = "MultiTexCoord4d",
   [DISPATCH_CMD_MultiTexCoord4dv] = "MultiTexCoord4dv",
   [DISPATCH_CMD_MultiTexCoord4fARB] = "MultiTexCoord4fARB",
   [DISPATCH_CMD_MultiTexCoord4fvARB] = "MultiTexCoord4fvARB",
   [DISPATCH_CMD_MultiTexCoord4i] = "MultiTexCoord4i",
   [DISPATCH_CMD_MultiTexCoord4iv] = "MultiTexCoord4iv",
   [DISPATCH_CMD_MultiTexCoord4s] = "MultiTexCoord4s",
   [DISPATCH_CMD_MultiTexCoord4sv] = "MultiTexCoord4sv",
   [DISPATCH_CMD_LoadTransposeMatrixf] = "LoadTransposeMatrixf",
   [DISPATCH_CMD_LoadTransposeMatrixd] = "LoadTransposeMatrixd",
   [DISPATCH_CMD_MultTransposeMatrixf] = "MultTransposeMatrixf",
   [DISPATCH_CMD_MultTransposeMatrixd] = "MultTransposeMatrixd",
   [DISPATCH_CMD_SampleCoverage] = "SampleCoverage",
   [DISPATCH_CMD_CompressedTexImage3D] = "CompressedTexImage3D",
   [DISPATCH_CMD_CompressedTexImage2D] = "CompressedTexImage2D",
   [DISPATCH_CMD_CompressedTexImage1D] = "CompressedTexImage1D",
   [DISPATCH_CMD_CompressedTexSubImage3D] = "CompressedTexSubImage3D",
   [DISPATCH_CMD_CompressedTexSubImage2D] = "CompressedTexSubImage2D",
   [DISPATCH_CMD_CompressedTexSubImage1D] = "CompressedTexSubImage1D",
   [DISPATCH_CMD_GetCompressedTexImage] = "GetCompressedTexImage",
   [DISPATCH_CMD_BlendFuncSeparate] = "BlendFuncSeparate",
   [DISPATCH_CMD_FogCoordfEXT] = "FogCoordfEXT",
   [DISPATCH_CMD_FogCoordfvEXT] = "FogCoordfvEXT",
   [DISPATCH_CMD_FogCoordd] = "FogCoordd",
   [DISPATCH_CMD_FogCoorddv] = "FogCoorddv",
   [DISPATCH_CMD_FogCoordPointer] = "FogCoordPointer",
   [DISPATCH_CMD_MultiDrawArrays] = "MultiDrawArrays",
   [DISPATCH_CMD_MultiDrawElements] = "MultiDrawElements",
   [DISPATCH_CMD_PointParameterf] = "PointParameterf",
   [DISPATCH_CMD_PointParameterfv] = "PointParameterfv",
   [DISPATCH_CMD_PointParameteri] = "PointParameteri",
   [DISPATCH_CMD_PointParameteriv] = "PointParameteriv",
   [DISPATCH_CMD_SecondaryColor3b] = "SecondaryColor3b",
   [DISPATCH_CMD_SecondaryColor3bv] = "SecondaryColor3bv",
   [DISPATCH_CMD_SecondaryColor3d] = "SecondaryColor3d",
   [DISPATCH_CMD_SecondaryColor3dv] = "SecondaryColor3dv",
   [DISPATCH_CMD_SecondaryColor3fEXT] = "SecondaryColor3fEXT",
   [DISPATCH_CMD_SecondaryColor3fvEXT] = "SecondaryColor3fvEXT",
   [DISPATCH_CMD_SecondaryColor3i] = "SecondaryColor3i",
   [DISPATCH_CMD_SecondaryColor3iv] = "SecondaryColor3iv",
   [DISPATCH_CMD_SecondaryColor3s] = "SecondaryColor3s",
   [DISPATCH_CMD_SecondaryColor3sv] = "SecondaryColor3sv",
   [DISPATCH_CMD_SecondaryColor3ub] = "SecondaryColor3ub",
   [DISPATCH_CMD_SecondaryColor3ubv] = "SecondaryColor3ubv",
   [DISPATCH_CMD_SecondaryColor3ui] = "SecondaryColor3ui",
   [DISPATCH_CMD_SecondaryColor3uiv] = "SecondaryColor3uiv",
   [DISPATCH_CMD_SecondaryColor3us] = "SecondaryColor3us",
   [DISPATCH_CMD_SecondaryColor3usv] = "SecondaryColor3usv",
   [DISPATCH_CMD_SecondaryColorPointer] = "SecondaryColorPointer",
   [DISPATCH_CMD_WindowPos2d] = "WindowPos2d",
   [DISPATCH_CMD_WindowPos2dv] = "WindowPos2dv",
   [DISPATCH_CMD_WindowPos2f] = "WindowPos2f",
   [DISPATCH_CMD_WindowPos2fv] = "WindowPos2fv",
   [DISPATCH_CMD_WindowPos2i] = "WindowPos2i",
   [DISPATCH_CMD_WindowPos2iv] = "WindowPos2iv",
   [DISPATCH_CMD_WindowPos2s] = "WindowPos2s",
   [DISPATCH_CMD_WindowPos2sv] = "WindowPos2sv",
   [DISPATCH_CMD_WindowPos3d] = "WindowPos3d",
   [DISPATCH_CMD_WindowPos3dv] = "WindowPos3dv",
   [DISPATCH_CMD_WindowPos3f] = "WindowPos3f",
   [DISPATCH_CMD_WindowPos3fv] = "WindowPos3fv",
   [DISPATCH_CMD_WindowPos3i] = "WindowPos3i",
   [DISPATCH_CMD_WindowPos3iv] = "WindowPos3iv",
   [DISPATCH_CMD_WindowPos3s] = "WindowPos3s",
   [DISPATCH_CMD_WindowPos3sv] = "WindowPos3sv",
   [DISPATCH_CMD_BindBuffer] = "BindBuffer",
   [DISPATCH_CMD_BufferData] = "BufferData",
   [DISPATCH_CMD_BufferSubData] = "BufferSubData",
   [DISPATCH_CMD_DeleteBuffers] = "DeleteBuffers",
   [DISPATCH_CMD_UnmapBuffer] = "UnmapBuffer",
   [DISPATCH_CMD_DeleteQueries] = "DeleteQueries",
   [DISPATCH_CMD_BeginQuery] = "BeginQuery",
   [DISPATCH_CMD_EndQuery] = "EndQuery",
   [DISPATCH_CMD_BlendEquationSeparate] = "BlendEquationSeparate",
   [DISPATCH_CMD_DrawBuffers] = "DrawBuffers",
   [DISPATCH_CMD_StencilFuncSeparate] = "StencilFuncSeparate",
   [DISPATCH_CMD_StencilOpSeparate] = "StencilOpSeparate",
   [DISPATCH_CMD_StencilMaskSeparate] = "StencilMaskSeparate",
   [DISPATCH_CMD_AttachShader] = "AttachShader",
   [DISPATCH_CMD_BindAttribLocation] = "BindAttribLocation",
   [DISPATCH_CMD_CompileShader] = "CompileShader",
   [DISPATCH_CMD_DeleteProgram] = "DeleteProgram",
   [DISPATCH_CMD_DeleteShader] = "DeleteShader",
   [DISPATCH_CMD_DetachShader] = "DetachShader",
   [DISPATCH_CMD_DisableVertexAttribArray] = "DisableVertexAttribArray",
   [DISPATCH_CMD_EnableVertexAttribArray] = "EnableVertexAttribArray",
   [DISPATCH_CMD_GetActiveUniform] = "GetActiveUniform",
   [DISPATCH_CMD_GetUniformLocation] = "GetUniformLocation",
   [DISPATCH_CMD_LinkProgram] = "LinkProgram",
   [DISPATCH_CMD_UseProgram] = "UseProgram",
   [DISPATCH_CMD_Uniform1f] = "Uniform1f",
   [DISPATCH_CMD_Uniform2f] = "Uniform2f",
   [DISPATCH_CMD_Uniform3f] = "Uniform3f",
   [DISPATCH_CMD_Uniform4f] = "Uniform4f",
   [DISPATCH_CMD_Uniform1i] = "Uniform1i",
   [DISPATCH_CMD_Uniform2i] = "Uniform2i",
   [DISPATCH_CMD_Uniform3i] = "Uniform3i",
   [DISPATCH_CMD_Uniform4i] = "Uniform4i",
   [DISPATCH_CMD_Uniform1fv] = "Uniform1fv",
   [DISPATCH_CMD_Uniform2fv] = "Uniform2fv",
   [DISPATCH_CMD_Uniform3fv] = "Uniform3fv",
   [DISPATCH_CMD_Uniform4fv] = "Uniform4fv",
   [DISPATCH_CMD_Uniform1iv] = "Uniform1iv",
   [DISPATCH_CMD_Uniform2iv] = "Uniform2iv",
   [DISPATCH_CMD_Uniform3iv] = "Uniform3iv",
   [DISPATCH_CMD_Uniform4iv] = "Uniform4iv",
   [DISPATCH_CMD_UniformMatrix2fv] = "UniformMatrix2fv",
   [DISPATCH_CMD_UniformMatrix3fv] = "UniformMatrix3fv",
   [DISPATCH_CMD_UniformMatrix4fv] = "UniformMatrix4fv",
   [DISPATCH_CMD_ValidateProgram] = "ValidateProgram",
   [DISPATCH_CMD_VertexAttrib1d] = "VertexAttrib1d",
   [DISPATCH_CMD_VertexAttrib1dv] = "VertexAttrib1dv",
   [DISPATCH_CMD_VertexAttrib1fARB] = "VertexAttrib1fARB",
   [DISPATCH_CMD_VertexAttrib1fvARB] = "VertexAttrib1fvARB",
   [DISPATCH_CMD_VertexAttrib1s] = "VertexAttrib1s",
   [DISPATCH_CMD_VertexAttrib1sv] = "VertexAttrib1sv",
   [DISPATCH_CMD_VertexAttrib2d] = "VertexAttrib2d",
   [DISPATCH_CMD_VertexAttrib2dv] = "VertexAttrib2dv",
   [DISPATCH_CMD_VertexAttrib2fARB] = "VertexAttrib2fARB",
   [DISPATCH_CMD_VertexAttrib2fvARB] = "VertexAttrib2fvARB",
   [DISPATCH_CMD_VertexAttrib2s] = "VertexAttrib2s",
   [DISPATCH_CMD_VertexAttrib2sv] = "VertexAttrib2sv",
   [DISPATCH_CMD_VertexAttrib3d] = "VertexAttrib3d",
   [DISPATCH_CMD_VertexAttrib3dv] = "VertexAttrib3dv",
   [DISPATCH_CMD_VertexAttrib3fARB] = "VertexAttrib3fARB",
   [DISPATCH_CMD_VertexAttrib3fvARB] = "VertexAttrib3fvARB",
   [DISPATCH_CMD_VertexAttrib3s] = "VertexAttrib3s",
   [DISPATCH_CMD_VertexAttrib3sv] = "VertexAttrib3sv",
   [DISPATCH_CMD_VertexAttrib4Nbv] = "VertexAttrib4Nbv",
   [DISPATCH_CMD_VertexAttrib4Niv] = "VertexAttrib4Niv",
   [DISPATCH_CMD_VertexAttrib4Nsv] = "VertexAttrib4Nsv",
   [DISPATCH_CMD_VertexAttrib4Nub] = "VertexAttrib4Nub",
   [DISPATCH_CMD_VertexAttrib4Nubv] = "VertexAttrib4Nubv",
   [DISPATCH_CMD_VertexAttrib4Nuiv] = "VertexAttrib4Nuiv",
   [DISPATCH_CMD_VertexAttrib4Nusv] = "VertexAttrib4Nusv",
   [DISPATCH_CMD_VertexAttrib4bv] = "VertexAttrib4bv",
   [DISPATCH_CMD_VertexAttrib4d] = "VertexAttrib4d",
   [DISPATCH_CMD_VertexAttrib4dv] = "VertexAttrib4dv",
   [DISPATCH_CMD_VertexAttrib4fARB] = "VertexAttrib4fARB",
   [DISPATCH_CMD_VertexAttrib4fvARB] = "VertexAttrib4fvARB",
   [DISPATCH_CMD_VertexAttrib4iv] = "VertexAttrib4iv",
   [DISPATCH_CMD_VertexAttrib4s] = "VertexAttrib4s",
   [DISPATCH_CMD_VertexAttrib4sv] = "VertexAttrib4sv",
   [DISPATCH_CMD_VertexAttrib4ubv] = "VertexAttrib4ubv",
   [DISPATCH_CMD_VertexAttrib4uiv] = "VertexAttrib4uiv",
   [DISPATCH_CMD_VertexAttrib4usv] = "VertexAttrib4usv",
   [DISPATCH_CMD_VertexAttribPointer] = "VertexAttribPointer",
   [DISPATCH_CMD_UniformMatrix2x3fv] = "UniformMatrix2x3fv",
   [DISPATCH_CMD_UniformMatrix3x2fv] = "UniformMatrix3x2fv",
   [DISPATCH_CMD_UniformMatrix2x4fv] = "UniformMatrix2x4fv",
   [DISPATCH_CMD_UniformMatrix4x2fv] = "UniformMatrix4x2fv",
   [DISPATCH_CMD_UniformMatrix3x4fv] = "UniformMatrix3x4fv",
   [DISPATCH_CMD_UniformMatrix4x3fv] = "UniformMatrix4x3fv",
   [DISPATCH_CMD_ProgramStringARB] = "ProgramStringARB",
   [DISPATCH_CMD_BindProgramARB] = "BindProgramARB",
   [DISPATCH_CMD_DeleteProgramsARB] = "DeleteProgramsARB",
   [DISPATCH_CMD_ProgramEnvParameter4dARB] = "ProgramEnvParameter4dARB",
   [DISPATCH_CMD_ProgramEnvParameter4dvARB] = "ProgramEnvParameter4dvARB",
   [DISPATCH_CMD_ProgramEnvParameter4fARB] = "ProgramEnvParameter4fARB",
   [DISPATCH_CMD_ProgramEnvParameter4fvARB] = "ProgramEnvParameter4fvARB",
   [DISPATCH_CMD_ProgramLocalParameter4dARB] = "ProgramLocalParameter4dARB",
   [DISPATCH_CMD_ProgramLocalParameter4dvARB] = "ProgramLocalParameter4dvARB",
   [DISPATCH_CMD_ProgramLocalParameter4fARB] = "ProgramLocalParameter4fARB",
   [DISPATCH_CMD_ProgramLocalParameter4fvARB] = "ProgramLocalParameter4fvARB",
   [DISPATCH_CMD_DeleteObjectARB] = "DeleteObjectARB",
   [DISPATCH_CMD_DetachObjectARB] = "DetachObjectARB",
   [DISPATCH_CMD_AttachObjectARB] = "AttachObjectARB",
   [DISPATCH_CMD_ClampColor] = "ClampColor",
   [DISPATCH_CMD_DrawArraysInstanced] = "DrawArraysInstanced",
   [DISPATCH_CMD_DrawElementsInstanced] = "DrawElementsInstanced",
   [DISPATCH_CMD_BindRenderbuffer] = "BindRenderbuffer",
   [DISPATCH_CMD_DeleteRenderbuffers] = "DeleteRenderbuffers",
   [DISPATCH_CMD_RenderbufferStorage] = "RenderbufferStorage",
   [DISPATCH_CMD_RenderbufferStorageMultisample] = "RenderbufferStorageMultisample",
   [DISPATCH_CMD_BindFramebuffer] = "BindFramebuffer",
   [DISPATCH_CMD_DeleteFramebuffers] = "DeleteFramebuffers",
   [DISPATCH_CMD_FramebufferTexture1D] = "FramebufferTexture1D",
   [DISPATCH_CMD_FramebufferTexture2D] = "FramebufferTexture2D",
   [DISPATCH_CMD_FramebufferTexture3D] = "FramebufferTexture3D",
   [DISPATCH_CMD_FramebufferTextureLayer] = "FramebufferTextureLayer",
   [DISPATCH_CMD_FramebufferRenderbuffer] = "FramebufferRenderbuffer",
   [DISPATCH_CMD_BlitFramebuffer] = "BlitFramebuffer",
   [DISPATCH_CMD_GenerateMipmap] = "GenerateMipmap",
   [DISPATCH_CMD_FramebufferTextureMultiviewOVR] = "FramebufferTextureMultiviewOVR",
   [DISPATCH_CMD_NamedFramebufferTextureMultiviewOVR] = "NamedFramebufferTextureMultiviewOVR",
   [DISPATCH_CMD_FramebufferTextureMultisampleMultiviewOVR] = "FramebufferTextureMultisampleMultiviewOVR",
   [DISPATCH_CMD_VertexAttribDivisor] = "VertexAttribDivisor",
   [DISPATCH_CMD_VertexArrayVertexAttribDivisorEXT] = "VertexArrayVertexAttribDivisorEXT",
   [DISPATCH_CMD_FlushMappedBufferRange] = "FlushMappedBufferRange",
   [DISPATCH_CMD_TexBuffer] = "TexBuffer",
   [DISPATCH_CMD_BindVertexArray] = "BindVertexArray",
   [DISPATCH_CMD_DeleteVertexArrays] = "DeleteVertexArrays",
   [DISPATCH_CMD_UniformBlockBinding] = "UniformBlockBinding",
   [DISPATCH_CMD_CopyBufferSubData] = "CopyBufferSubData",
   [DISPATCH_CMD_DrawElementsBaseVertex] = "DrawElementsBaseVertex",
   [DISPATCH_CMD_DrawRangeElementsBaseVertex] = "DrawRangeElementsBaseVertex",
   [DISPATCH_CMD_MultiDrawElementsBaseVertex] = "MultiDrawElementsBaseVertex",
   [DISPATCH_CMD_DrawElementsInstancedBaseVertex] = "DrawElementsInstancedBaseVertex",
   [DISPATCH_CMD_DeleteSync] = "DeleteSync",
   [DISPATCH_CMD_WaitSync] = "WaitSync",
   [DISPATCH_CMD_TexImage2DMultisample] = "TexImage2DMultisample",
   [DISPATCH_CMD_TexImage3DMultisample] = "TexImage3DMultisample",
   [DISPATCH_CMD_SampleMaski] = "SampleMaski",
   [DISPATCH_CMD_BlendEquationiARB] = "BlendEquationiARB",
   [DISPATCH_CMD_BlendEquationSeparateiARB] = "BlendEquationSeparateiARB",
   [DISPATCH_CMD_BlendFunciARB] = "BlendFunciARB",
   [DISPATCH_CMD_BlendFuncSeparateiARB] = "BlendFuncSeparateiARB",
   [DISPATCH_CMD_MinSampleShading] = "MinSampleShading",
   [DISPATCH_CMD_NamedStringARB] = "NamedStringARB",
   [DISPATCH_CMD_DeleteNamedStringARB] = "DeleteNamedStringARB",
   [DISPATCH_CMD_BindFragDataLocationIndexed] = "BindFragDataLocationIndexed",
   [DISPATCH_CMD_DeleteSamplers] = "DeleteSamplers",
   [DISPATCH_CMD_BindSampler] = "BindSampler",
   [DISPATCH_CMD_SamplerParameteri] = "SamplerParameteri",
   [DISPATCH_CMD_SamplerParameterf] = "SamplerParameterf",
   [DISPATCH_CMD_SamplerParameteriv] = "SamplerParameteriv",
   [DISPATCH_CMD_SamplerParameterfv] = "SamplerParameterfv",
   [DISPATCH_CMD_SamplerParameterIiv] = "SamplerParameterIiv",
   [DISPATCH_CMD_SamplerParameterIuiv] = "SamplerParameterIuiv",
   [DISPATCH_CMD_QueryCounter] = "QueryCounter",
   [DISPATCH_CMD_VertexP2ui] = "VertexP2ui",
   [DISPATCH_CMD_VertexP3ui] = "VertexP3ui",
   [DISPATCH_CMD_VertexP4ui] = "VertexP4ui",
   [DISPATCH_CMD_VertexP2uiv] = "VertexP2uiv",
   [DISPATCH_CMD_VertexP3uiv] = "VertexP3uiv",
   [DISPATCH_CMD_VertexP4uiv] = "VertexP4uiv",
   [DISPATCH_CMD_TexCoordP1ui] = "TexCoordP1ui",
   [DISPATCH_CMD_TexCoordP2ui] = "TexCoordP2ui",
   [DISPATCH_CMD_TexCoordP3ui] = "TexCoordP3ui",
   [DISPATCH_CMD_TexCoordP4ui] = "TexCoordP4ui",
   [DISPATCH_CMD_TexCoordP1uiv] = "TexCoordP1uiv",
   [DISPATCH_CMD_TexCoordP2uiv] = "TexCoordP2uiv",
   [DISPATCH_CMD_TexCoordP3uiv] = "TexCoordP3uiv",
   [DISPATCH_CMD_TexCoordP4uiv] = "TexCoordP4uiv",
   [DISPATCH_CMD_MultiTexCoordP1ui] = "MultiTexCoordP1ui",
   [DISPATCH_CMD_MultiTexCoordP2ui] = "MultiTexCoordP2ui",
   [DISPATCH_CMD_MultiTexCoordP3ui] = "MultiTexCoordP3ui",
   [DISPATCH_CMD_MultiTexCoordP4ui] = "MultiTexCoordP4ui",
   [DISPATCH_CMD_MultiTexCoordP1uiv] = "MultiTexCoordP1uiv",
   [DISPATCH_CMD_MultiTexCoordP2uiv] = "MultiTexCoordP2uiv",
   [DISPATCH_CMD_MultiTexCoordP3uiv] = "MultiTexCoordP3uiv",
   [DISPATCH_CMD_MultiTexCoordP4uiv] = "MultiTexCoordP4uiv",
   [DISPATCH_CMD_NormalP3ui] = "NormalP3ui",
   [DISPATCH_CMD_NormalP3uiv] = "NormalP3uiv",
   [DISPATCH_CMD_ColorP3ui] = "ColorP3ui",
   [DISPATCH_CMD_ColorP4ui] = "ColorP4ui",
   [DISPATCH_CMD_ColorP3uiv] = "ColorP3uiv",
   [DISPATCH_CMD_ColorP4uiv] = "ColorP4uiv",
   [DISPATCH_CMD_SecondaryColorP3ui] = "SecondaryColorP3ui",
   [DISPATCH_CMD_SecondaryColorP3uiv] = "SecondaryColorP3uiv",
   [DISPATCH_CMD_VertexAttribP1ui] = "VertexAttribP1ui",
   [DISPATCH_CMD_VertexAttribP2ui] = "VertexAttribP2ui",
   [DISPATCH_CMD_VertexAttribP3ui] = "VertexAttribP3ui",
   [DISPATCH_CMD_VertexAttribP4ui] = "VertexAttribP4ui",
   [DISPATCH_CMD_VertexAttribP1uiv] = "VertexAttribP1uiv",
   [DISPATCH_CMD_VertexAttribP2uiv] = "VertexAttribP2uiv",
   [DISPATCH_CMD_VertexAttribP3uiv] = "VertexAttribP3uiv",
   [DISPATCH_CMD_VertexAttribP4uiv] = "VertexAttribP4uiv",
   [DISPATCH_CMD_UniformSubroutinesuiv] = "UniformSubroutinesuiv",
   [DISPATCH_CMD_PatchParameteri] = "PatchParameteri",
   [DISPATCH_CMD_PatchParameterfv] = "PatchParameterfv",
   [DISPATCH_CMD_DrawArraysIndirect] = "DrawArraysIndirect",
   [DISPATCH_CMD_DrawElementsIndirect] = "DrawElementsIndirect",
   [DISPATCH_CMD_MultiDrawArraysIndirect] = "MultiDrawArraysIndirect",
   [DISPATCH_CMD_MultiDrawElementsIndirect] = "MultiDrawElementsIndirect",
   [DISPATCH_CMD_Uniform1d] = "Uniform1d",
   [DISPATCH_CMD_Uniform2d] = "Uniform2d",
   [DISPATCH_CMD_Uniform3d] = "Uniform3d",
   [DISPATCH_CMD_Uniform4d] = "Uniform4d",
   [DISPATCH_CMD_Uniform1dv] = "Uniform1dv",
   [DISPATCH_CMD_Uniform2dv] = "Uniform2dv",
   [DISPATCH_CMD_Uniform3dv] = "Uniform3dv",
   [DISPATCH_CMD_Uniform4dv] = "Uniform4dv",
   [DISPATCH_CMD_UniformMatrix2dv] = "UniformMatrix2dv",
   [DISPATCH_CMD_UniformMatrix3dv] = "UniformMatrix3dv",
   [DISPATCH_CMD_UniformMatrix4dv] = "UniformMatrix4dv",
   [DISPATCH_CMD_UniformMatrix2x3dv] = "UniformMatrix2x3dv",
   [DISPATCH_CMD_UniformMatrix2x4dv] = "UniformMatrix2x4dv",
   [DISPATCH_CMD_UniformMatrix3x2dv] = "UniformMatrix3x2dv",
   [DISPATCH_CMD_UniformMatrix3x4dv] = "UniformMatrix3x4dv",
   [DISPATCH_CMD_UniformMatrix4x2dv] = "UniformMatrix4x2dv",
   [DISPATCH_CMD_UniformMatrix4x3dv] = "UniformMatrix4x3dv",
   [DISPATCH_CMD_ProgramUniform1d] = "ProgramUniform1d",
   [DISPATCH_CMD_ProgramUniform2d] = "ProgramUniform2d",
   [DISPATCH_CMD_ProgramUniform3d] = "ProgramUniform3d",
   [DISPATCH_CMD_ProgramUniform4d] = "ProgramUniform4d",
   [DISPATCH_CMD_ProgramUniform1dv] = "ProgramUniform1dv",
   [DISPATCH_CMD_ProgramUniform2dv] = "ProgramUniform2dv",
   [DISPATCH_CMD_ProgramUniform3dv] = "ProgramUniform3dv",
   [DISPATCH_CMD_ProgramUniform4dv] = "ProgramUniform4dv",
   [DISPATCH_CMD_ProgramUniformMatrix2dv] = "ProgramUniformMatrix2dv",
   [DISPATCH_CMD_ProgramUniformMatrix3dv] = "ProgramUniformMatrix3dv",
   [DISPATCH_CMD_ProgramUniformMatrix4dv] = "ProgramUniformMatrix4dv",
   [DISPATCH_CMD_ProgramUniformMatrix2x3dv] = "ProgramUniformMatrix2x3dv",
   [DISPATCH_CMD_ProgramUniformMatrix2x4dv] = "ProgramUniformMatrix2x4dv",
   [DISPATCH_CMD_ProgramUniformMatrix3x2dv] = "ProgramUniformMatrix3x2dv",
   [DISPATCH_CMD_ProgramUniformMatrix3x4dv] = "ProgramUniformMatrix3x4dv",
   [DISPATCH_CMD_ProgramUniformMatrix4x2dv] = "ProgramUniformMatrix4x2dv",
   [DISPATCH_CMD_ProgramUniformMatrix4x3dv] = "ProgramUniformMatrix4x3dv",
   [DISPATCH_CMD_DrawTransformFeedbackStream] = "DrawTransformFeedbackStream",
   [DISPATCH_CMD_BeginQueryIndexed] = "BeginQueryIndexed",
   [DISPATCH_CMD_EndQueryIndexed] = "EndQueryIndexed",
   [DISPATCH_CMD_UseProgramStages] = "UseProgramStages",
   [DISPATCH_CMD_ActiveShaderProgram] = "ActiveShaderProgram",
   [DISPATCH_CMD_BindProgramPipeline] = "BindProgramPipeline",
   [DISPATCH_CMD_DeleteProgramPipelines] = "DeleteProgramPipelines",
   [DISPATCH_CMD_ProgramUniform1i] = "ProgramUniform1i",
   [DISPATCH_CMD_ProgramUniform2i] = "ProgramUniform2i",
   [DISPATCH_CMD_ProgramUniform3i] = "ProgramUniform3i",
   [DISPATCH_CMD_ProgramUniform4i] = "ProgramUniform4i",
   [DISPATCH_CMD_ProgramUniform1ui] = "ProgramUniform1ui",
   [DISPATCH_CMD_ProgramUniform2ui] = "ProgramUniform2ui",
   [DISPATCH_CMD_ProgramUniform3ui] = "ProgramUniform3ui",
   [DISPATCH_CMD_ProgramUniform4ui] = "ProgramUniform4ui",
   [DISPATCH_CMD_ProgramUniform1f] = "ProgramUniform1f",
   [DISPATCH_CMD_ProgramUniform2f] = "ProgramUniform2f",
   [DISPATCH_CMD_ProgramUniform3f] = "ProgramUniform3f",
   [DISPATCH_CMD_ProgramUniform4f] = "ProgramUniform4f",
   [DISPATCH_CMD_ProgramUniform1iv] = "ProgramUniform1iv",
   [DISPATCH_CMD_ProgramUniform2iv] = "ProgramUniform2iv",
   [DISPATCH_CMD_ProgramUniform3iv] = "ProgramUniform3iv",
   [DISPATCH_CMD_ProgramUniform4iv] = "ProgramUniform4iv",
   [DISPATCH_CMD_ProgramUniform1uiv] = "ProgramUniform1uiv",
   [DISPATCH_CMD_ProgramUniform2uiv] = "ProgramUniform2uiv",
   [DISPATCH_CMD_ProgramUniform3uiv] = "ProgramUniform3uiv",
   [DISPATCH_CMD_ProgramUniform4uiv] = "ProgramUniform4uiv",
   [DISPATCH_CMD_ProgramUniform1fv] = "ProgramUniform1fv",
   [DISPATCH_CMD_ProgramUniform2fv] = "ProgramUniform2fv",
   [DISPATCH_CMD_ProgramUniform3fv] = "ProgramUniform3fv",
   [DISPATCH_CMD_ProgramUniform4fv] = "ProgramUniform4fv",
   [DISPATCH_CMD_ProgramUniformMatrix2fv] = "ProgramUniformMatrix2fv",
   [DISPATCH_CMD_ProgramUniformMatrix3fv] = "ProgramUniformMatrix3fv",
   [DISPATCH_CMD_ProgramUniformMatrix4fv] = "ProgramUniformMatrix4fv",
   [DISPATCH_CMD_ProgramUniformMatrix2x3fv] = "ProgramUniformMatrix2x3fv",
   [DISPATCH_CMD_ProgramUniformMatrix3x2fv] = "ProgramUniformMatrix3x2fv",
   [DISPATCH_CMD_ProgramUniformMatrix2x4fv] = "ProgramUniformMatrix2x4fv",
   [DISPATCH_CMD_ProgramUniformMatrix4x2fv] = "ProgramUniformMatrix4x2fv",
   [DISPATCH_CMD_ProgramUniformMatrix3x4fv] = "ProgramUniformMatrix3x4fv",
   [DISPATCH_CMD_ProgramUniformMatrix4x3fv] = "ProgramUniformMatrix4x3fv",
   [DISPATCH_CMD_ValidateProgramPipeline] = "ValidateProgramPipeline",
   [DISPATCH_CMD_VertexAttribL1d] = "VertexAttribL1d",
   [DISPATCH_CMD_VertexAttribL2d] = "VertexAttribL2d",
   [DISPATCH_CMD_VertexAttribL3d] = "VertexAttribL3d",
   [DISPATCH_CMD_VertexAttribL4d] = "VertexAttribL4d",
   [DISPATCH_CMD_VertexAttribL1dv] = "VertexAttribL1dv",
   [DISPATCH_CMD_VertexAttribL2dv] = "VertexAttribL2dv",
   [DISPATCH_CMD_VertexAttribL3dv] = "VertexAttribL3dv",
   [DISPATCH_CMD_VertexAttribL4dv] = "VertexAttribL4dv",
   [DISPATCH_CMD_VertexAttribLPointer] = "VertexAttribLPointer",
   [DISPATCH_CMD_VertexArrayVertexAttribLOffsetEXT] = "VertexArrayVertexAttribLOffsetEXT",
   [DISPATCH_CMD_ReleaseShaderCompiler] = "ReleaseShaderCompiler",
   [DISPATCH_CMD_ShaderBinary] = "ShaderBinary",
   [DISPATCH_CMD_ClearDepthf] = "ClearDepthf",
   [DISPATCH_CMD_DepthRangef] = "DepthRangef",
   [DISPATCH_CMD_ProgramBinary] = "ProgramBinary",
   [DISPATCH_CMD_ProgramParameteri] = "ProgramParameteri",
   [DISPATCH_CMD_DebugMessageControl] = "DebugMessageControl",
   [DISPATCH_CMD_DebugMessageInsert] = "DebugMessageInsert",
   [DISPATCH_CMD_GetnPolygonStippleARB] = "GetnPolygonStippleARB",
   [DISPATCH_CMD_GetnTexImageARB] = "GetnTexImageARB",
   [DISPATCH_CMD_ReadnPixelsARB] = "ReadnPixelsARB",
   [DISPATCH_CMD_GetnCompressedTexImageARB] = "GetnCompressedTexImageARB",
   [DISPATCH_CMD_DrawArraysInstancedBaseInstance] = "DrawArraysInstancedBaseInstance",
   [DISPATCH_CMD_DrawElementsInstancedBaseInstance] = "DrawElementsInstancedBaseInstance",
   [DISPATCH_CMD_DrawElementsInstancedBaseVertexBaseInstance] = "DrawElementsInstancedBaseVertexBaseInstance",
   [DISPATCH_CMD_DrawTransformFeedbackInstanced] = "DrawTransformFeedbackInstanced",
   [DISPATCH_CMD_DrawTransformFeedbackStreamInstanced] = "DrawTransformFeedbackStreamInstanced",
   [DISPATCH_CMD_BindImageTexture] = "BindImageTexture",
   [DISPATCH_CMD_MemoryBarrier] = "MemoryBarrier",
   [DISPATCH_CMD_TexStorage1D] = "TexStorage1D",
   [DISPATCH_CMD_TexStorage2D] = "TexStorage2D",
   [DISPATCH_CMD_TexStorage3D] = "TexStorage3D",
   [DISPATCH_CMD_PushDebugGroup] = "PushDebugGroup",
   [DISPATCH_CMD_PopDebugGroup] = "PopDebugGroup",
   [DISPATCH_CMD_ObjectLabel] = "ObjectLabel",
   [DISPATCH_CMD_DispatchCompute] = "DispatchCompute",
   [DISPATCH_CMD_DispatchComputeIndirect] = "DispatchComputeIndirect",
   [DISPATCH_CMD_CopyImageSubData] = "CopyImageSubData",
   [DISPATCH_CMD_TextureView] = "TextureView",
   [DISPATCH_CMD_BindVertexBuffer] = "BindVertexBuffer",
   [DISPATCH_CMD_VertexAttribFormat] = "VertexAttribFormat",
   [DISPATCH_CMD_VertexAttribIFormat] = "VertexAttribIFormat",
   [DISPATCH_CMD_VertexAttribLFormat] = "VertexAttribLFormat",
   [DISPATCH_CMD_VertexAttribBinding] = "VertexAttribBinding",
   [DISPATCH_CMD_VertexBindingDivisor] = "VertexBindingDivisor",
   [DISPATCH_CMD_VertexArrayBindVertexBufferEXT] = "VertexArrayBindVertexBufferEXT",
   [DISPATCH_CMD_VertexArrayBindVertexBufferEXT_packed] = "VertexArrayBindVertexBufferEXT_packed",
   [DISPATCH_CMD_VertexArrayVertexAttribFormatEXT] = "VertexArrayVertexAttribFormatEXT",
   [DISPATCH_CMD_VertexArrayVertexAttribIFormatEXT] = "VertexArrayVertexAttribIFormatEXT",
   [DISPATCH_CMD_VertexArrayVertexAttribLFormatEXT] = "VertexArrayVertexAttribLFormatEXT",
   [DISPATCH_CMD_VertexArrayVertexAttribBindingEXT] = "VertexArrayVertexAttribBindingEXT",
   [DISPATCH_CMD_VertexArrayVertexBindingDivisorEXT] = "VertexArrayVertexBindingDivisorEXT",
   [DISPATCH_CMD_FramebufferParameteri] = "FramebufferParameteri",
   [DISPATCH_CMD_NamedFramebufferParameteriEXT] = "NamedFramebufferParameteriEXT",
   [DISPATCH_CMD_InvalidateTexSubImage] = "InvalidateTexSubImage",
   [DISPATCH_CMD_InvalidateTexImage] = "InvalidateTexImage",
   [DISPATCH_CMD_InvalidateBufferSubData] = "InvalidateBufferSubData",
   [DISPATCH_CMD_InvalidateBufferData] = "InvalidateBufferData",
   [DISPATCH_CMD_InvalidateSubFramebuffer] = "InvalidateSubFramebuffer",
   [DISPATCH_CMD_InvalidateFramebuffer] = "InvalidateFramebuffer",
   [DISPATCH_CMD_ShaderStorageBlockBinding] = "ShaderStorageBlockBinding",
   [DISPATCH_CMD_TexBufferRange] = "TexBufferRange",
   [DISPATCH_CMD_TextureBufferRangeEXT] = "TextureBufferRangeEXT",
   [DISPATCH_CMD_TexStorage2DMultisample] = "TexStorage2DMultisample",
   [DISPATCH_CMD_TexStorage3DMultisample] = "TexStorage3DMultisample",
   [DISPATCH_CMD_TextureStorage2DMultisampleEXT] = "TextureStorage2DMultisampleEXT",
   [DISPATCH_CMD_TextureStorage3DMultisampleEXT] = "TextureStorage3DMultisampleEXT",
   [DISPATCH_CMD_BindBuffersBase] = "BindBuffersBase",
   [DISPATCH_CMD_BindBuffersRange] = "BindBuffersRange",
   [DISPATCH_CMD_BindTextures] = "BindTextures",
   [DISPATCH_CMD_BindSamplers] = "BindSamplers",
   [DISPATCH_CMD_BindImageTextures] = "BindImageTextures",
   [DISPATCH_CMD_BindVertexBuffers] = "BindVertexBuffers",
   [DISPATCH_CMD_MakeTextureHandleResidentARB] = "MakeTextureHandleResidentARB",
   [DISPATCH_CMD_MakeTextureHandleNonResidentARB] = "MakeTextureHandleNonResidentARB",
   [DISPATCH_CMD_MakeImageHandleResidentARB] = "MakeImageHandleResidentARB",
   [DISPATCH_CMD_MakeImageHandleNonResidentARB] = "MakeImageHandleNonResidentARB",
   [DISPATCH_CMD_UniformHandleui64ARB] = "UniformHandleui64ARB",
   [DISPATCH_CMD_UniformHandleui64vARB] = "UniformHandleui64vARB",
   [DISPATCH_CMD_ProgramUniformHandleui64ARB] = "ProgramUniformHandleui64ARB",
   [DISPATCH_CMD_ProgramUniformHandleui64vARB] = "ProgramUniformHandleui64vARB",
   [DISPATCH_CMD_VertexAttribL1ui64ARB] = "VertexAttribL1ui64ARB",
   [DISPATCH_CMD_VertexAttribL1ui64vARB] = "VertexAttribL1ui64vARB",
   [DISPATCH_CMD_DispatchComputeGroupSizeARB] = "DispatchComputeGroupSizeARB",
   [DISPATCH_CMD_MultiDrawArraysIndirectCountARB] = "MultiDrawArraysIndirectCountARB",
   [DISPATCH_CMD_MultiDrawElementsIndirectCountARB] = "MultiDrawElementsIndirectCountARB",
   [DISPATCH_CMD_TexPageCommitmentARB] = "TexPageCommitmentARB",
   [DISPATCH_CMD_TexturePageCommitmentEXT] = "TexturePageCommitmentEXT",
   [DISPATCH_CMD_ClipControl] = "ClipControl",
   [DISPATCH_CMD_TransformFeedbackBufferBase] = "TransformFeedbackBufferBase",
   [DISPATCH_CMD_TransformFeedbackBufferRange] = "TransformFeedbackBufferRange",
   [DISPATCH_CMD_NamedBufferData] = "NamedBufferData",
   [DISPATCH_CMD_NamedBufferSubData] = "NamedBufferSubData",
   [DISPATCH_CMD_CopyNamedBufferSubData] = "CopyNamedBufferSubData",
   [DISPATCH_CMD_UnmapNamedBufferEXT] = "UnmapNamedBufferEXT",
   [DISPATCH_CMD_FlushMappedNamedBufferRange] = "FlushMappedNamedBufferRange",
   [DISPATCH_CMD_NamedFramebufferRenderbuffer] = "NamedFramebufferRenderbuffer",
   [DISPATCH_CMD_NamedFramebufferParameteri] = "NamedFramebufferParameteri",
   [DISPATCH_CMD_NamedFramebufferTexture] = "NamedFramebufferTexture",
   [DISPATCH_CMD_NamedFramebufferTextureLayer] = "NamedFramebufferTextureLayer",
   [DISPATCH_CMD_NamedFramebufferDrawBuffer] = "NamedFramebufferDrawBuffer",
   [DISPATCH_CMD_NamedFramebufferDrawBuffers] = "NamedFramebufferDrawBuffers",
   [DISPATCH_CMD_NamedFramebufferReadBuffer] = "NamedFramebufferReadBuffer",
   [DISPATCH_CMD_InvalidateNamedFramebufferData] = "InvalidateNamedFramebufferData",
   [DISPATCH_CMD_InvalidateNamedFramebufferSubData] = "InvalidateNamedFramebufferSubData",
   [DISPATCH_CMD_ClearNamedFramebufferiv] = "ClearNamedFramebufferiv",
   [DISPATCH_CMD_ClearNamedFramebufferuiv] = "ClearNamedFramebufferuiv",
   [DISPATCH_CMD_ClearNamedFramebufferfv] = "ClearNamedFramebufferfv",
   [DISPATCH_CMD_ClearNamedFramebufferfi] = "ClearNamedFramebufferfi",
   [DISPATCH_CMD_BlitNamedFramebuffer] = "BlitNamedFramebuffer",
   [DISPATCH_CMD_NamedRenderbufferStorage] = "NamedRenderbufferStorage",
   [DISPATCH_CMD_NamedRenderbufferStorageMultisample] = "NamedRenderbufferStorageMultisample",
   [DISPATCH_CMD_TextureBuffer] = "TextureBuffer",
   [DISPATCH_CMD_TextureBufferRange] = "TextureBufferRange",
   [DISPATCH_CMD_TextureStorage1D] = "TextureStorage1D",
   [DISPATCH_CMD_TextureStorage2D] = "TextureStorage2D",
   [DISPATCH_CMD_TextureStorage3D] = "TextureStorage3D",
   [DISPATCH_CMD_TextureStorage2DMultisample] = "TextureStorage2DMultisample",
   [DISPATCH_CMD_TextureStorage3DMultisample] = "TextureStorage3DMultisample",
   [DISPATCH_CMD_TextureSubImage1D] = "TextureSubImage1D",
   [DISPATCH_CMD_TextureSubImage2D] = "TextureSubImage2D",
   [DISPATCH_CMD_TextureSubImage3D] = "TextureSubImage3D",
   [DISPATCH_CMD_CompressedTextureSubImage1D] = "CompressedTextureSubImage1D",
   [DISPATCH_CMD_CompressedTextureSubImage2D] = "CompressedTextureSubImage2D",
   [DISPATCH_CMD_CompressedTextureSubImage3D] = "CompressedTextureSubImage3D",
   [DISPATCH_CMD_CopyTextureSubImage1D] = "CopyTextureSubImage1D",
   [DISPATCH_CMD_CopyTextureSubImage2D] = "CopyTextureSubImage2D",
   [DISPATCH_CMD_CopyTextureSubImage3D] = "CopyTextureSubImage3D",
   [DISPATCH_CMD_TextureParameterf] = "TextureParameterf",
   [DISPATCH_CMD_TextureParameterfv] = "TextureParameterfv",
   [DISPATCH_CMD_TextureParameteri] = "TextureParameteri",
   [DISPATCH_CMD_TextureParameterIiv] = "TextureParameterIiv",
   [DISPATCH_CMD_TextureParameterIuiv] = "TextureParameterIuiv",
   [DISPATCH_CMD_TextureParameteriv] = "TextureParameteriv",
   [DISPATCH_CMD_GenerateTextureMipmap] = "GenerateTextureMipmap",
   [DISPATCH_CMD_BindTextureUnit] = "BindTextureUnit",
   [DISPATCH_CMD_GetTextureImage] = "GetTextureImage",
   [DISPATCH_CMD_GetCompressedTextureImage] = "GetCompressedTextureImage",
   [DISPATCH_CMD_DisableVertexArrayAttrib] = "DisableVertexArrayAttrib",
   [DISPATCH_CMD_EnableVertexArrayAttrib] = "EnableVertexArrayAttrib",
   [DISPATCH_CMD_VertexArrayElementBuffer] = "VertexArrayElementBuffer",
   [DISPATCH_CMD_VertexArrayVertexBuffer] = "VertexArrayVertexBuffer",
   [DISPATCH_CMD_VertexArrayVertexBuffer_packed] = "VertexArrayVertexBuffer_packed",
   [DISPATCH_CMD_VertexArrayVertexBuffers] = "VertexArrayVertexBuffers",
   [DISPATCH_CMD_VertexArrayAttribFormat] = "VertexArrayAttribFormat",
   [DISPATCH_CMD_VertexArrayAttribIFormat] = "VertexArrayAttribIFormat",
   [DISPATCH_CMD_VertexArrayAttribLFormat] = "VertexArrayAttribLFormat",
   [DISPATCH_CMD_VertexArrayAttribBinding] = "VertexArrayAttribBinding",
   [DISPATCH_CMD_VertexArrayBindingDivisor] = "VertexArrayBindingDivisor",
   [DISPATCH_CMD_GetQueryBufferObjectiv] = "GetQueryBufferObjectiv",
   [DISPATCH_CMD_GetQueryBufferObjectuiv] = "GetQueryBufferObjectuiv",
   [DISPATCH_CMD_GetQueryBufferObjecti64v] = "GetQueryBufferObjecti64v",
   [DISPATCH_CMD_GetQueryBufferObjectui64v] = "GetQueryBufferObjectui64v",
   [DISPATCH_CMD_GetTextureSubImage] = "GetTextureSubImage",
   [DISPATCH_CMD_GetCompressedTextureSubImage] = "GetCompressedTextureSubImage",
   [DISPATCH_CMD_TextureBarrierNV] = "TextureBarrierNV",
   [DISPATCH_CMD_BufferPageCommitmentARB] = "BufferPageCommitmentARB",
   [DISPATCH_CMD_NamedBufferPageCommitmentEXT] = "NamedBufferPageCommitmentEXT",
   [DISPATCH_CMD_NamedBufferPageCommitmentARB] = "NamedBufferPageCommitmentARB",
   [DISPATCH_CMD_PrimitiveBoundingBox] = "PrimitiveBoundingBox",
   [DISPATCH_CMD_BlendBarrier] = "BlendBarrier",
   [DISPATCH_CMD_Uniform1i64ARB] = "Uniform1i64ARB",
   [DISPATCH_CMD_Uniform2i64ARB] = "Uniform2i64ARB",
   [DISPATCH_CMD_Uniform3i64ARB] = "Uniform3i64ARB",
   [DISPATCH_CMD_Uniform4i64ARB] = "Uniform4i64ARB",
   [DISPATCH_CMD_Uniform1i64vARB] = "Uniform1i64vARB",
   [DISPATCH_CMD_Uniform2i64vARB] = "Uniform2i64vARB",
   [DISPATCH_CMD_Uniform3i64vARB] = "Uniform3i64vARB",
   [DISPATCH_CMD_Uniform4i64vARB] = "Uniform4i64vARB",
   [DISPATCH_CMD_Uniform1ui64ARB] = "Uniform1ui64ARB",
   [DISPATCH_CMD_Uniform2ui64ARB] = "Uniform2ui64ARB",
   [DISPATCH_CMD_Uniform3ui64ARB] = "Uniform3ui64ARB",
   [DISPATCH_CMD_Uniform4ui64ARB] = "Uniform4ui64ARB",
   [DISPATCH_CMD_Uniform1ui64vARB] = "Uniform1ui64vARB",
   [DISPATCH_CMD_Uniform2ui64vARB] = "Uniform2ui64vARB",
   [DISPATCH_CMD_Uniform3ui64vARB] = "Uniform3ui64vARB",
   [DISPATCH_CMD_Uniform4ui64vARB] = "Uniform4ui64vARB",
   [DISPATCH_CMD_ProgramUniform1i64ARB] = "ProgramUniform1i64ARB",
   [DISPATCH_CMD_ProgramUniform2i64ARB] = "ProgramUniform2i64ARB",
   [DISPATCH_CMD_ProgramUniform3i64ARB] = "ProgramUniform3i64ARB",
   [DISPATCH_CMD_ProgramUniform4i64ARB] = "ProgramUniform4i64ARB",
   [DISPATCH_CMD_ProgramUniform1i64vARB] = "ProgramUniform1i64vARB",
   [DISPATCH_CMD_ProgramUniform2i64vARB] = "ProgramUniform2i64vARB",
   [DISPATCH_CMD_ProgramUniform3i64vARB] = "ProgramUniform3i64vARB",
   [DISPATCH_CMD_ProgramUniform4i64vARB] = "ProgramUniform4i64vARB",
   [DISPATCH_CMD_ProgramUniform1ui64ARB] = "ProgramUniform1ui64ARB",
   [DISPATCH_CMD_ProgramUniform2ui64ARB] = "ProgramUniform2ui64ARB",
   [DISPATCH_CMD_ProgramUniform3ui64ARB] = "ProgramUniform3ui64ARB",
   [DISPATCH_CMD_ProgramUniform4ui64ARB] = "ProgramUniform4ui64ARB",
   [DISPATCH_CMD_ProgramUniform1ui64vARB] = "ProgramUniform1ui64vARB",
   [DISPATCH_CMD_ProgramUniform2ui64vARB] = "ProgramUniform2ui64vARB",
   [DISPATCH_CMD_ProgramUniform3ui64vARB] = "ProgramUniform3ui64vARB",
   [DISPATCH_CMD_ProgramUniform4ui64vARB] = "ProgramUniform4ui64vARB",
   [DISPATCH_CMD_MaxShaderCompilerThreadsKHR] = "MaxShaderCompilerThreadsKHR",
   [DISPATCH_CMD_SpecializeShaderARB] = "SpecializeShaderARB",
   [DISPATCH_CMD_ColorPointerEXT] = "ColorPointerEXT",
   [DISPATCH_CMD_EdgeFlagPointerEXT] = "EdgeFlagPointerEXT",
   [DISPATCH_CMD_IndexPointerEXT] = "IndexPointerEXT",
   [DISPATCH_CMD_NormalPointerEXT] = "NormalPointerEXT",
   [DISPATCH_CMD_TexCoordPointerEXT] = "TexCoordPointerEXT",
   [DISPATCH_CMD_VertexPointerEXT] = "VertexPointerEXT",
   [DISPATCH_CMD_LockArraysEXT] = "LockArraysEXT",
   [DISPATCH_CMD_UnlockArraysEXT] = "UnlockArraysEXT",
   [DISPATCH_CMD_ViewportArrayv] = "ViewportArrayv",
   [DISPATCH_CMD_ViewportIndexedf] = "ViewportIndexedf",
   [DISPATCH_CMD_ViewportIndexedfv] = "ViewportIndexedfv",
   [DISPATCH_CMD_ScissorArrayv] = "ScissorArrayv",
   [DISPATCH_CMD_ScissorIndexed] = "ScissorIndexed",
   [DISPATCH_CMD_ScissorIndexedv] = "ScissorIndexedv",
   [DISPATCH_CMD_DepthRangeArrayv] = "DepthRangeArrayv",
   [DISPATCH_CMD_DepthRangeIndexed] = "DepthRangeIndexed",
   [DISPATCH_CMD_FramebufferSampleLocationsfvARB] = "FramebufferSampleLocationsfvARB",
   [DISPATCH_CMD_NamedFramebufferSampleLocationsfvARB] = "NamedFramebufferSampleLocationsfvARB",
   [DISPATCH_CMD_EvaluateDepthValuesARB] = "EvaluateDepthValuesARB",
   [DISPATCH_CMD_WindowPos4dMESA] = "WindowPos4dMESA",
   [DISPATCH_CMD_WindowPos4dvMESA] = "WindowPos4dvMESA",
   [DISPATCH_CMD_WindowPos4fMESA] = "WindowPos4fMESA",
   [DISPATCH_CMD_WindowPos4fvMESA] = "WindowPos4fvMESA",
   [DISPATCH_CMD_WindowPos4iMESA] = "WindowPos4iMESA",
   [DISPATCH_CMD_WindowPos4ivMESA] = "WindowPos4ivMESA",
   [DISPATCH_CMD_WindowPos4sMESA] = "WindowPos4sMESA",
   [DISPATCH_CMD_WindowPos4svMESA] = "WindowPos4svMESA",
   [DISPATCH_CMD_MultiModeDrawArraysIBM] = "MultiModeDrawArraysIBM",
   [DISPATCH_CMD_MultiModeDrawElementsIBM] = "MultiModeDrawElementsIBM",
   [DISPATCH_CMD_VertexAttrib1sNV] = "VertexAttrib1sNV",
   [DISPATCH_CMD_VertexAttrib1svNV] = "VertexAttrib1svNV",
   [DISPATCH_CMD_VertexAttrib2sNV] = "VertexAttrib2sNV",
   [DISPATCH_CMD_VertexAttrib2svNV] = "VertexAttrib2svNV",
   [DISPATCH_CMD_VertexAttrib3sNV] = "VertexAttrib3sNV",
   [DISPATCH_CMD_VertexAttrib3svNV] = "VertexAttrib3svNV",
   [DISPATCH_CMD_VertexAttrib4sNV] = "VertexAttrib4sNV",
   [DISPATCH_CMD_VertexAttrib4svNV] = "VertexAttrib4svNV",
   [DISPATCH_CMD_VertexAttrib1fNV] = "VertexAttrib1fNV",
   [DISPATCH_CMD_VertexAttrib1fvNV] = "VertexAttrib1fvNV",
   [DISPATCH_CMD_VertexAttrib2fNV] = "VertexAttrib2fNV",
   [DISPATCH_CMD_VertexAttrib2fvNV] = "VertexAttrib2fvNV",
   [DISPATCH_CMD_VertexAttrib3fNV] = "VertexAttrib3fNV",
   [DISPATCH_CMD_VertexAttrib3fvNV] = "VertexAttrib3fvNV",
   [DISPATCH_CMD_VertexAttrib4fNV] = "VertexAttrib4fNV",
   [DISPATCH_CMD_VertexAttrib4fvNV] = "VertexAttrib4fvNV",
   [DISPATCH_CMD_VertexAttrib1dNV] = "VertexAttrib1dNV",
   [DISPATCH_CMD_VertexAttrib1dvNV] = "VertexAttrib1dvNV",
   [DISPATCH_CMD_VertexAttrib2dNV] = "VertexAttrib2dNV",
   [DISPATCH_CMD_VertexAttrib2dvNV] = "VertexAttrib2dvNV",
   [DISPATCH_CMD_VertexAttrib3dNV] = "VertexAttrib3dNV",
   [DISPATCH_CMD_VertexAttrib3dvNV] = "VertexAttrib3dvNV",
   [DISPATCH_CMD_VertexAttrib4dNV] = "VertexAttrib4dNV",
   [DISPATCH_CMD_VertexAttrib4dvNV] = "VertexAttrib4dvNV",
   [DISPATCH_CMD_VertexAttrib4ubNV] = "VertexAttrib4ubNV",
   [DISPATCH_CMD_VertexAttrib4ubvNV] = "VertexAttrib4ubvNV",
   [DISPATCH_CMD_VertexAttribs1svNV] = "VertexAttribs1svNV",
   [DISPATCH_CMD_VertexAttribs2svNV] = "VertexAttribs2svNV",
   [DISPATCH_CMD_VertexAttribs3svNV] = "VertexAttribs3svNV",
   [DISPATCH_CMD_VertexAttribs4svNV] = "VertexAttribs4svNV",
   [DISPATCH_CMD_VertexAttribs1fvNV] = "VertexAttribs1fvNV",
   [DISPATCH_CMD_VertexAttribs2fvNV] = "VertexAttribs2fvNV",
   [DISPATCH_CMD_VertexAttribs3fvNV] = "VertexAttribs3fvNV",
   [DISPATCH_CMD_VertexAttribs4fvNV] = "VertexAttribs4fvNV",
   [DISPATCH_CMD_VertexAttribs1dvNV] = "VertexAttribs1dvNV",
   [DISPATCH_CMD_VertexAttribs2dvNV] = "VertexAttribs2dvNV",
   [DISPATCH_CMD_VertexAttribs3dvNV] = "VertexAttribs3dvNV",
   [DISPATCH_CMD_VertexAttribs4dvNV] = "VertexAttribs4dvNV",
   [DISPATCH_CMD_VertexAttribs4ubvNV] = "VertexAttribs4ubvNV",
   [DISPATCH_CMD_BindFragmentShaderATI] = "BindFragmentShaderATI",
   [DISPATCH_CMD_DeleteFragmentShaderATI] = "DeleteFragmentShaderATI",
   [DISPATCH_CMD_BeginFragmentShaderATI] = "BeginFragmentShaderATI",
   [DISPATCH_CMD_EndFragmentShaderATI] = "EndFragmentShaderATI",
   [DISPATCH_CMD_PassTexCoordATI] = "PassTexCoordATI",
   [DISPATCH_CMD_SampleMapATI] = "SampleMapATI",
   [DISPATCH_CMD_ColorFragmentOp1ATI] = "ColorFragmentOp1ATI",
   [DISPATCH_CMD_ColorFragmentOp2ATI] = "ColorFragmentOp2ATI",
   [DISPATCH_CMD_ColorFragmentOp3ATI] = "ColorFragmentOp3ATI",
   [DISPATCH_CMD_AlphaFragmentOp1ATI] = "AlphaFragmentOp1ATI",
   [DISPATCH_CMD_AlphaFragmentOp2ATI] = "AlphaFragmentOp2ATI",
   [DISPATCH_CMD_AlphaFragmentOp3ATI] = "AlphaFragmentOp3ATI",
   [DISPATCH_CMD_SetFragmentShaderConstantATI] = "SetFragmentShaderConstantATI",
   [DISPATCH_CMD_ActiveStencilFaceEXT] = "ActiveStencilFaceEXT",
   [DISPATCH_CMD_DepthBoundsEXT] = "DepthBoundsEXT",
   [DISPATCH_CMD_BindRenderbufferEXT] = "BindRenderbufferEXT",
   [DISPATCH_CMD_BindFramebufferEXT] = "BindFramebufferEXT",
   [DISPATCH_CMD_ProvokingVertex] = "ProvokingVertex",
   [DISPATCH_CMD_ColorMaski] = "ColorMaski",
   [DISPATCH_CMD_Enablei] = "Enablei",
   [DISPATCH_CMD_Disablei] = "Disablei",
   [DISPATCH_CMD_DeletePerfMonitorsAMD] = "DeletePerfMonitorsAMD",
   [DISPATCH_CMD_SelectPerfMonitorCountersAMD] = "SelectPerfMonitorCountersAMD",
   [DISPATCH_CMD_BeginPerfMonitorAMD] = "BeginPerfMonitorAMD",
   [DISPATCH_CMD_EndPerfMonitorAMD] = "EndPerfMonitorAMD",
   [DISPATCH_CMD_CopyImageSubDataNV] = "CopyImageSubDataNV",
   [DISPATCH_CMD_MatrixLoadfEXT] = "MatrixLoadfEXT",
   [DISPATCH_CMD_MatrixLoaddEXT] = "MatrixLoaddEXT",
   [DISPATCH_CMD_MatrixMultfEXT] = "MatrixMultfEXT",
   [DISPATCH_CMD_MatrixMultdEXT] = "MatrixMultdEXT",
   [DISPATCH_CMD_MatrixLoadIdentityEXT] = "MatrixLoadIdentityEXT",
   [DISPATCH_CMD_MatrixRotatefEXT] = "MatrixRotatefEXT",
   [DISPATCH_CMD_MatrixRotatedEXT] = "MatrixRotatedEXT",
   [DISPATCH_CMD_MatrixScalefEXT] = "MatrixScalefEXT",
   [DISPATCH_CMD_MatrixScaledEXT] = "MatrixScaledEXT",
   [DISPATCH_CMD_MatrixTranslatefEXT] = "MatrixTranslatefEXT",
   [DISPATCH_CMD_MatrixTranslatedEXT] = "MatrixTranslatedEXT",
   [DISPATCH_CMD_MatrixOrthoEXT] = "MatrixOrthoEXT",
   [DISPATCH_CMD_MatrixFrustumEXT] = "MatrixFrustumEXT",
   [DISPATCH_CMD_MatrixPushEXT] = "MatrixPushEXT",
   [DISPATCH_CMD_MatrixPopEXT] = "MatrixPopEXT",
   [DISPATCH_CMD_ClientAttribDefaultEXT] = "ClientAttribDefaultEXT",
   [DISPATCH_CMD_PushClientAttribDefaultEXT] = "PushClientAttribDefaultEXT",
   [DISPATCH_CMD_TextureParameteriEXT] = "TextureParameteriEXT",
   [DISPATCH_CMD_TextureParameterivEXT] = "TextureParameterivEXT",
   [DISPATCH_CMD_TextureParameterfEXT] = "TextureParameterfEXT",
   [DISPATCH_CMD_TextureParameterfvEXT] = "TextureParameterfvEXT",
   [DISPATCH_CMD_TextureImage1DEXT] = "TextureImage1DEXT",
   [DISPATCH_CMD_TextureImage2DEXT] = "TextureImage2DEXT",
   [DISPATCH_CMD_TextureImage3DEXT] = "TextureImage3DEXT",
   [DISPATCH_CMD_TextureSubImage1DEXT] = "TextureSubImage1DEXT",
   [DISPATCH_CMD_TextureSubImage2DEXT] = "TextureSubImage2DEXT",
   [DISPATCH_CMD_TextureSubImage3DEXT] = "TextureSubImage3DEXT",
   [DISPATCH_CMD_CopyTextureImage1DEXT] = "CopyTextureImage1DEXT",
   [DISPATCH_CMD_CopyTextureImage2DEXT] = "CopyTextureImage2DEXT",
   [DISPATCH_CMD_CopyTextureSubImage1DEXT] = "CopyTextureSubImage1DEXT",
   [DISPATCH_CMD_CopyTextureSubImage2DEXT] = "CopyTextureSubImage2DEXT",
   [DISPATCH_CMD_CopyTextureSubImage3DEXT] = "CopyTextureSubImage3DEXT",
   [DISPATCH_CMD_GetTextureImageEXT] = "GetTextureImageEXT",
   [DISPATCH_CMD_BindMultiTextureEXT] = "BindMultiTextureEXT",
   [DISPATCH_CMD_EnableClientStateiEXT] = "EnableClientStateiEXT",
   [DISPATCH_CMD_DisableClientStateiEXT] = "DisableClientStateiEXT",
   [DISPATCH_CMD_MultiTexEnviEXT] = "MultiTexEnviEXT",
   [DISPATCH_CMD_MultiTexEnvivEXT] = "MultiTexEnvivEXT",
   [DISPATCH_CMD_MultiTexEnvfEXT] = "MultiTexEnvfEXT",
   [DISPATCH_CMD_MultiTexEnvfvEXT] = "MultiTexEnvfvEXT",
   [DISPATCH_CMD_MultiTexParameteriEXT] = "MultiTexParameteriEXT",
   [DISPATCH_CMD_MultiTexParameterivEXT] = "MultiTexParameterivEXT",
   [DISPATCH_CMD_MultiTexParameterfEXT] = "MultiTexParameterfEXT",
   [DISPATCH_CMD_MultiTexParameterfvEXT] = "MultiTexParameterfvEXT",
   [DISPATCH_CMD_GetMultiTexImageEXT] = "GetMultiTexImageEXT",
   [DISPATCH_CMD_MultiTexImage1DEXT] = "MultiTexImage1DEXT",
   [DISPATCH_CMD_MultiTexImage2DEXT] = "MultiTexImage2DEXT",
   [DISPATCH_CMD_MultiTexImage3DEXT] = "MultiTexImage3DEXT",
   [DISPATCH_CMD_MultiTexSubImage1DEXT] = "MultiTexSubImage1DEXT",
   [DISPATCH_CMD_MultiTexSubImage2DEXT] = "MultiTexSubImage2DEXT",
   [DISPATCH_CMD_MultiTexSubImage3DEXT] = "MultiTexSubImage3DEXT",
   [DISPATCH_CMD_CopyMultiTexImage1DEXT] = "CopyMultiTexImage1DEXT",
   [DISPATCH_CMD_CopyMultiTexImage2DEXT] = "CopyMultiTexImage2DEXT",
   [DISPATCH_CMD_CopyMultiTexSubImage1DEXT] = "CopyMultiTexSubImage1DEXT",
   [DISPATCH_CMD_CopyMultiTexSubImage2DEXT] = "CopyMultiTexSubImage2DEXT",
   [DISPATCH_CMD_CopyMultiTexSubImage3DEXT] = "CopyMultiTexSubImage3DEXT",
   [DISPATCH_CMD_MultiTexGendEXT] = "MultiTexGendEXT",
   [DISPATCH_CMD_MultiTexGendvEXT] = "MultiTexGendvEXT",
   [DISPATCH_CMD_MultiTexGenfEXT] = "MultiTexGenfEXT",
   [DISPATCH_CMD_MultiTexGenfvEXT] = "MultiTexGenfvEXT",
   [DISPATCH_CMD_MultiTexGeniEXT] = "MultiTexGeniEXT",
   [DISPATCH_CMD_MultiTexGenivEXT] = "MultiTexGenivEXT",
   [DISPATCH_CMD_MultiTexCoordPointerEXT] = "MultiTexCoordPointerEXT",
   [DISPATCH_CMD_MatrixLoadTransposefEXT] = "MatrixLoadTransposefEXT",
   [DISPATCH_CMD_MatrixLoadTransposedEXT] = "MatrixLoadTransposedEXT",
   [DISPATCH_CMD_MatrixMultTransposefEXT] = "MatrixMultTransposefEXT",
   [DISPATCH_CMD_MatrixMultTransposedEXT] = "MatrixMultTransposedEXT",
   [DISPATCH_CMD_CompressedTextureImage1DEXT] = "CompressedTextureImage1DEXT",
   [DISPATCH_CMD_CompressedTextureImage2DEXT] = "CompressedTextureImage2DEXT",
   [DISPATCH_CMD_CompressedTextureImage3DEXT] = "CompressedTextureImage3DEXT",
   [DISPATCH_CMD_CompressedTextureSubImage1DEXT] = "CompressedTextureSubImage1DEXT",
   [DISPATCH_CMD_CompressedTextureSubImage2DEXT] = "CompressedTextureSubImage2DEXT",
   [DISPATCH_CMD_CompressedTextureSubImage3DEXT] = "CompressedTextureSubImage3DEXT",
   [DISPATCH_CMD_GetCompressedTextureImageEXT] = "GetCompressedTextureImageEXT",
   [DISPATCH_CMD_CompressedMultiTexImage1DEXT] = "CompressedMultiTexImage1DEXT",
   [DISPATCH_CMD_CompressedMultiTexImage2DEXT] = "CompressedMultiTexImage2DEXT",
   [DISPATCH_CMD_CompressedMultiTexImage3DEXT] = "CompressedMultiTexImage3DEXT",
   [DISPATCH_CMD_CompressedMultiTexSubImage1DEXT] = "CompressedMultiTexSubImage1DEXT",
   [DISPATCH_CMD_CompressedMultiTexSubImage2DEXT] = "CompressedMultiTexSubImage2DEXT",
   [DISPATCH_CMD_CompressedMultiTexSubImage3DEXT] = "CompressedMultiTexSubImage3DEXT",
   [DISPATCH_CMD_GetCompressedMultiTexImageEXT] = "GetCompressedMultiTexImageEXT",
   [DISPATCH_CMD_NamedBufferDataEXT] = "NamedBufferDataEXT",
   [DISPATCH_CMD_NamedBufferSubDataEXT] = "NamedBufferSubDataEXT",
   [DISPATCH_CMD_FlushMappedNamedBufferRangeEXT] = "FlushMappedNamedBufferRangeEXT",
   [DISPATCH_CMD_FramebufferDrawBufferEXT] = "FramebufferDrawBufferEXT",
   [DISPATCH_CMD_FramebufferDrawBuffersEXT] = "FramebufferDrawBuffersEXT",
   [DISPATCH_CMD_FramebufferReadBufferEXT] = "FramebufferReadBufferEXT",
   [DISPATCH_CMD_NamedFramebufferTexture1DEXT] = "NamedFramebufferTexture1DEXT",
   [DISPATCH_CMD_NamedFramebufferTexture2DEXT] = "NamedFramebufferTexture2DEXT",
   [DISPATCH_CMD_NamedFramebufferTexture3DEXT] = "NamedFramebufferTexture3DEXT",
   [DISPATCH_CMD_NamedFramebufferRenderbufferEXT] = "NamedFramebufferRenderbufferEXT",
   [DISPATCH_CMD_NamedRenderbufferStorageEXT] = "NamedRenderbufferStorageEXT",
   [DISPATCH_CMD_GenerateTextureMipmapEXT] = "GenerateTextureMipmapEXT",
   [DISPATCH_CMD_GenerateMultiTexMipmapEXT] = "GenerateMultiTexMipmapEXT",
   [DISPATCH_CMD_NamedRenderbufferStorageMultisampleEXT] = "NamedRenderbufferStorageMultisampleEXT",
   [DISPATCH_CMD_NamedCopyBufferSubDataEXT] = "NamedCopyBufferSubDataEXT",
   [DISPATCH_CMD_VertexArrayVertexOffsetEXT] = "VertexArrayVertexOffsetEXT",
   [DISPATCH_CMD_VertexArrayVertexOffsetEXT_packed] = "VertexArrayVertexOffsetEXT_packed",
   [DISPATCH_CMD_VertexArrayColorOffsetEXT] = "VertexArrayColorOffsetEXT",
   [DISPATCH_CMD_VertexArrayColorOffsetEXT_packed] = "VertexArrayColorOffsetEXT_packed",
   [DISPATCH_CMD_VertexArrayEdgeFlagOffsetEXT] = "VertexArrayEdgeFlagOffsetEXT",
   [DISPATCH_CMD_VertexArrayIndexOffsetEXT] = "VertexArrayIndexOffsetEXT",
   [DISPATCH_CMD_VertexArrayIndexOffsetEXT_packed] = "VertexArrayIndexOffsetEXT_packed",
   [DISPATCH_CMD_VertexArrayNormalOffsetEXT] = "VertexArrayNormalOffsetEXT",
   [DISPATCH_CMD_VertexArrayNormalOffsetEXT_packed] = "VertexArrayNormalOffsetEXT_packed",
   [DISPATCH_CMD_VertexArrayTexCoordOffsetEXT] = "VertexArrayTexCoordOffsetEXT",
   [DISPATCH_CMD_VertexArrayTexCoordOffsetEXT_packed] = "VertexArrayTexCoordOffsetEXT_packed",
   [DISPATCH_CMD_VertexArrayMultiTexCoordOffsetEXT] = "VertexArrayMultiTexCoordOffsetEXT",
   [DISPATCH_CMD_VertexArrayFogCoordOffsetEXT] = "VertexArrayFogCoordOffsetEXT",
   [DISPATCH_CMD_VertexArrayFogCoordOffsetEXT_packed] = "VertexArrayFogCoordOffsetEXT_packed",
   [DISPATCH_CMD_VertexArraySecondaryColorOffsetEXT] = "VertexArraySecondaryColorOffsetEXT",
   [DISPATCH_CMD_VertexArraySecondaryColorOffsetEXT_packed] = "VertexArraySecondaryColorOffsetEXT_packed",
   [DISPATCH_CMD_VertexArrayVertexAttribOffsetEXT] = "VertexArrayVertexAttribOffsetEXT",
   [DISPATCH_CMD_VertexArrayVertexAttribIOffsetEXT] = "VertexArrayVertexAttribIOffsetEXT",
   [DISPATCH_CMD_EnableVertexArrayEXT] = "EnableVertexArrayEXT",
   [DISPATCH_CMD_DisableVertexArrayEXT] = "DisableVertexArrayEXT",
   [DISPATCH_CMD_EnableVertexArrayAttribEXT] = "EnableVertexArrayAttribEXT",
   [DISPATCH_CMD_DisableVertexArrayAttribEXT] = "DisableVertexArrayAttribEXT",
   [DISPATCH_CMD_NamedProgramStringEXT] = "NamedProgramStringEXT",
   [DISPATCH_CMD_NamedProgramLocalParameter4fEXT] = "NamedProgramLocalParameter4fEXT",
   [DISPATCH_CMD_NamedProgramLocalParameter4fvEXT] = "NamedProgramLocalParameter4fvEXT",
   [DISPATCH_CMD_NamedProgramLocalParameter4dEXT] = "NamedProgramLocalParameter4dEXT",
   [DISPATCH_CMD_NamedProgramLocalParameter4dvEXT] = "NamedProgramLocalParameter4dvEXT",
   [DISPATCH_CMD_TextureBufferEXT] = "TextureBufferEXT",
   [DISPATCH_CMD_MultiTexBufferEXT] = "MultiTexBufferEXT",
   [DISPATCH_CMD_TextureParameterIivEXT] = "TextureParameterIivEXT",
   [DISPATCH_CMD_TextureParameterIuivEXT] = "TextureParameterIuivEXT",
   [DISPATCH_CMD_MultiTexParameterIivEXT] = "MultiTexParameterIivEXT",
   [DISPATCH_CMD_MultiTexParameterIuivEXT] = "MultiTexParameterIuivEXT",
   [DISPATCH_CMD_NamedProgramLocalParameters4fvEXT] = "NamedProgramLocalParameters4fvEXT",
   [DISPATCH_CMD_BindImageTextureEXT] = "BindImageTextureEXT",
   [DISPATCH_CMD_SubpixelPrecisionBiasNV] = "SubpixelPrecisionBiasNV",
   [DISPATCH_CMD_ConservativeRasterParameterfNV] = "ConservativeRasterParameterfNV",
   [DISPATCH_CMD_ConservativeRasterParameteriNV] = "ConservativeRasterParameteriNV",
   [DISPATCH_CMD_DeletePerfQueryINTEL] = "DeletePerfQueryINTEL",
   [DISPATCH_CMD_BeginPerfQueryINTEL] = "BeginPerfQueryINTEL",
   [DISPATCH_CMD_EndPerfQueryINTEL] = "EndPerfQueryINTEL",
   [DISPATCH_CMD_AlphaToCoverageDitherControlNV] = "AlphaToCoverageDitherControlNV",
   [DISPATCH_CMD_PolygonOffsetClampEXT] = "PolygonOffsetClampEXT",
   [DISPATCH_CMD_WindowRectanglesEXT] = "WindowRectanglesEXT",
   [DISPATCH_CMD_FramebufferFetchBarrierEXT] = "FramebufferFetchBarrierEXT",
   [DISPATCH_CMD_TextureStorage1DEXT] = "TextureStorage1DEXT",
   [DISPATCH_CMD_TextureStorage2DEXT] = "TextureStorage2DEXT",
   [DISPATCH_CMD_TextureStorage3DEXT] = "TextureStorage3DEXT",
   [DISPATCH_CMD_RenderbufferStorageMultisampleAdvancedAMD] = "RenderbufferStorageMultisampleAdvancedAMD",
   [DISPATCH_CMD_NamedRenderbufferStorageMultisampleAdvancedAMD] = "NamedRenderbufferStorageMultisampleAdvancedAMD",
   [DISPATCH_CMD_StencilFuncSeparateATI] = "StencilFuncSeparateATI",
   [DISPATCH_CMD_ProgramEnvParameters4fvEXT] = "ProgramEnvParameters4fvEXT",
   [DISPATCH_CMD_ProgramLocalParameters4fvEXT] = "ProgramLocalParameters4fvEXT",
   [DISPATCH_CMD_InternalBufferSubDataCopyMESA] = "InternalBufferSubDataCopyMESA",
   [DISPATCH_CMD_InternalSetError] = "InternalSetError",
   [DISPATCH_CMD_DrawArraysUserBuf] = "DrawArraysUserBuf",
   [DISPATCH_CMD_DrawElementsUserBuf] = "DrawElementsUserBuf",
   [DISPATCH_CMD_DrawElementsUserBufPacked] = "DrawElementsUserBufPacked",
   [DISPATCH_CMD_MultiDrawArraysUserBuf] = "MultiDrawArraysUserBuf",
   [DISPATCH_CMD_MultiDrawElementsUserBuf] = "MultiDrawElementsUserBuf",
   [DISPATCH_CMD_DrawArraysInstancedBaseInstanceDrawID] = "DrawArraysInstancedBaseInstanceDrawID",
   [DISPATCH_CMD_DrawElementsInstancedBaseVertexBaseInstanceDrawID] = "DrawElementsInstancedBaseVertexBaseInstanceDrawID",
   [DISPATCH_CMD_DrawElementsPacked] = "DrawElementsPacked",
   [DISPATCH_CMD_InternalInvalidateFramebufferAncillaryMESA] = "InternalInvalidateFramebufferAncillaryMESA",
   [DISPATCH_CMD_InternalReleaseBufferMESA] = "InternalReleaseBufferMESA",
   [DISPATCH_CMD_ClearColorIiEXT] = "ClearColorIiEXT",
   [DISPATCH_CMD_ClearColorIuiEXT] = "ClearColorIuiEXT",
   [DISPATCH_CMD_TexParameterIiv] = "TexParameterIiv",
   [DISPATCH_CMD_TexParameterIuiv] = "TexParameterIuiv",
   [DISPATCH_CMD_VertexAttribI1iEXT] = "VertexAttribI1iEXT",
   [DISPATCH_CMD_VertexAttribI2iEXT] = "VertexAttribI2iEXT",
   [DISPATCH_CMD_VertexAttribI3iEXT] = "VertexAttribI3iEXT",
   [DISPATCH_CMD_VertexAttribI4iEXT] = "VertexAttribI4iEXT",
   [DISPATCH_CMD_VertexAttribI1uiEXT] = "VertexAttribI1uiEXT",
   [DISPATCH_CMD_VertexAttribI2uiEXT] = "VertexAttribI2uiEXT",
   [DISPATCH_CMD_VertexAttribI3uiEXT] = "VertexAttribI3uiEXT",
   [DISPATCH_CMD_VertexAttribI4uiEXT] = "VertexAttribI4uiEXT",
   [DISPATCH_CMD_VertexAttribI1iv] = "VertexAttribI1iv",
   [DISPATCH_CMD_VertexAttribI2ivEXT] = "VertexAttribI2ivEXT",
   [DISPATCH_CMD_VertexAttribI3ivEXT] = "VertexAttribI3ivEXT",
   [DISPATCH_CMD_VertexAttribI4ivEXT] = "VertexAttribI4ivEXT",
   [DISPATCH_CMD_VertexAttribI1uiv] = "VertexAttribI1uiv",
   [DISPATCH_CMD_VertexAttribI2uivEXT] = "VertexAttribI2uivEXT",
   [DISPATCH_CMD_VertexAttribI3uivEXT] = "VertexAttribI3uivEXT",
   [DISPATCH_CMD_VertexAttribI4uivEXT] = "VertexAttribI4uivEXT",
   [DISPATCH_CMD_VertexAttribI4bv] = "VertexAttribI4bv",
   [DISPATCH_CMD_VertexAttribI4sv] = "VertexAttribI4sv",
   [DISPATCH_CMD_VertexAttribI4ubv] = "VertexAttribI4ubv",
   [DISPATCH_CMD_VertexAttribI4usv] = "VertexAttribI4usv",
   [DISPATCH_CMD_VertexAttribIPointer] = "VertexAttribIPointer",
   [DISPATCH_CMD_Uniform1ui] = "Uniform1ui",
   [DISPATCH_CMD_Uniform2ui] = "Uniform2ui",
   [DISPATCH_CMD_Uniform3ui] = "Uniform3ui",
   [DISPATCH_CMD_Uniform4ui] = "Uniform4ui",
   [DISPATCH_CMD_Uniform1uiv] = "Uniform1uiv",
   [DISPATCH_CMD_Uniform2uiv] = "Uniform2uiv",
   [DISPATCH_CMD_Uniform3uiv] = "Uniform3uiv",
   [DISPATCH_CMD_Uniform4uiv] = "Uniform4uiv",
   [DISPATCH_CMD_BindFragDataLocation] = "BindFragDataLocation",
   [DISPATCH_CMD_ClearBufferiv] = "ClearBufferiv",
   [DISPATCH_CMD_ClearBufferuiv] = "ClearBufferuiv",
   [DISPATCH_CMD_ClearBufferfv] = "ClearBufferfv",
   [DISPATCH_CMD_ClearBufferfi] = "ClearBufferfi",
   [DISPATCH_CMD_BeginTransformFeedback] = "BeginTransformFeedback",
   [DISPATCH_CMD_EndTransformFeedback] = "EndTransformFeedback",
   [DISPATCH_CMD_BindBufferRange] = "BindBufferRange",
   [DISPATCH_CMD_BindBufferBase] = "BindBufferBase",
   [DISPATCH_CMD_BeginConditionalRender] = "BeginConditionalRender",
   [DISPATCH_CMD_EndConditionalRender] = "EndConditionalRender",
   [DISPATCH_CMD_PrimitiveRestartIndex] = "PrimitiveRestartIndex",
   [DISPATCH_CMD_FramebufferTexture] = "FramebufferTexture",
   [DISPATCH_CMD_PrimitiveRestartNV] = "PrimitiveRestartNV",
   [DISPATCH_CMD_BindBufferOffsetEXT] = "BindBufferOffsetEXT",
   [DISPATCH_CMD_BindTransformFeedback] = "BindTransformFeedback",
   [DISPATCH_CMD_DeleteTransformFeedbacks] = "DeleteTransformFeedbacks",
   [DISPATCH_CMD_PauseTransformFeedback] = "PauseTransformFeedback",
   [DISPATCH_CMD_ResumeTransformFeedback] = "ResumeTransformFeedback",
   [DISPATCH_CMD_DrawTransformFeedback] = "DrawTransformFeedback",
   [DISPATCH_CMD_DeleteMemoryObjectsEXT] = "DeleteMemoryObjectsEXT",
   [DISPATCH_CMD_MemoryObjectParameterivEXT] = "MemoryObjectParameterivEXT",
   [DISPATCH_CMD_TexStorageMem2DEXT] = "TexStorageMem2DEXT",
   [DISPATCH_CMD_TexStorageMem2DMultisampleEXT] = "TexStorageMem2DMultisampleEXT",
   [DISPATCH_CMD_TexStorageMem3DEXT] = "TexStorageMem3DEXT",
   [DISPATCH_CMD_TexStorageMem3DMultisampleEXT] = "TexStorageMem3DMultisampleEXT",
   [DISPATCH_CMD_BufferStorageMemEXT] = "BufferStorageMemEXT",
   [DISPATCH_CMD_TextureStorageMem2DEXT] = "TextureStorageMem2DEXT",
   [DISPATCH_CMD_TextureStorageMem2DMultisampleEXT] = "TextureStorageMem2DMultisampleEXT",
   [DISPATCH_CMD_TextureStorageMem3DEXT] = "TextureStorageMem3DEXT",
   [DISPATCH_CMD_TextureStorageMem3DMultisampleEXT] = "TextureStorageMem3DMultisampleEXT",
   [DISPATCH_CMD_NamedBufferStorageMemEXT] = "NamedBufferStorageMemEXT",
   [DISPATCH_CMD_TexStorageMem1DEXT] = "TexStorageMem1DEXT",
   [DISPATCH_CMD_TextureStorageMem1DEXT] = "TextureStorageMem1DEXT",
   [DISPATCH_CMD_DeleteSemaphoresEXT] = "DeleteSemaphoresEXT",
   [DISPATCH_CMD_SemaphoreParameterui64vEXT] = "SemaphoreParameterui64vEXT",
   [DISPATCH_CMD_WaitSemaphoreEXT] = "WaitSemaphoreEXT",
   [DISPATCH_CMD_ImportMemoryFdEXT] = "ImportMemoryFdEXT",
   [DISPATCH_CMD_ImportSemaphoreFdEXT] = "ImportSemaphoreFdEXT",
   [DISPATCH_CMD_ViewportSwizzleNV] = "ViewportSwizzleNV",
   [DISPATCH_CMD_Vertex2hNV] = "Vertex2hNV",
   [DISPATCH_CMD_Vertex2hvNV] = "Vertex2hvNV",
   [DISPATCH_CMD_Vertex3hNV] = "Vertex3hNV",
   [DISPATCH_CMD_Vertex3hvNV] = "Vertex3hvNV",
   [DISPATCH_CMD_Vertex4hNV] = "Vertex4hNV",
   [DISPATCH_CMD_Vertex4hvNV] = "Vertex4hvNV",
   [DISPATCH_CMD_Normal3hNV] = "Normal3hNV",
   [DISPATCH_CMD_Normal3hvNV] = "Normal3hvNV",
   [DISPATCH_CMD_Color3hNV] = "Color3hNV",
   [DISPATCH_CMD_Color3hvNV] = "Color3hvNV",
   [DISPATCH_CMD_Color4hNV] = "Color4hNV",
   [DISPATCH_CMD_Color4hvNV] = "Color4hvNV",
   [DISPATCH_CMD_TexCoord1hNV] = "TexCoord1hNV",
   [DISPATCH_CMD_TexCoord1hvNV] = "TexCoord1hvNV",
   [DISPATCH_CMD_TexCoord2hNV] = "TexCoord2hNV",
   [DISPATCH_CMD_TexCoord2hvNV] = "TexCoord2hvNV",
   [DISPATCH_CMD_TexCoord3hNV] = "TexCoord3hNV",
   [DISPATCH_CMD_TexCoord3hvNV] = "TexCoord3hvNV",
   [DISPATCH_CMD_TexCoord4hNV] = "TexCoord4hNV",
   [DISPATCH_CMD_TexCoord4hvNV] = "TexCoord4hvNV",
   [DISPATCH_CMD_MultiTexCoord1hNV] = "MultiTexCoord1hNV",
   [DISPATCH_CMD_MultiTexCoord1hvNV] = "MultiTexCoord1hvNV",
   [DISPATCH_CMD_MultiTexCoord2hNV] = "MultiTexCoord2hNV",
   [DISPATCH_CMD_MultiTexCoord2hvNV] = "MultiTexCoord2hvNV",
   [DISPATCH_CMD_MultiTexCoord3hNV] = "MultiTexCoord3hNV",
   [DISPATCH_CMD_MultiTexCoord3hvNV] = "MultiTexCoord3hvNV",
   [DISPATCH_CMD_MultiTexCoord4hNV] = "MultiTexCoord4hNV",
   [DISPATCH_CMD_MultiTexCoord4hvNV] = "MultiTexCoord4hvNV",
   [DISPATCH_CMD_VertexAttrib1hNV] = "VertexAttrib1hNV",
   [DISPATCH_CMD_VertexAttrib1hvNV] = "VertexAttrib1hvNV",
   [DISPATCH_CMD_VertexAttrib2hNV] = "VertexAttrib2hNV",
   [DISPATCH_CMD_VertexAttrib2hvNV] = "VertexAttrib2hvNV",
   [DISPATCH_CMD_VertexAttrib3hNV] = "VertexAttrib3hNV",
   [DISPATCH_CMD_VertexAttrib3hvNV] = "VertexAttrib3hvNV",
   [DISPATCH_CMD_VertexAttrib4hNV] = "VertexAttrib4hNV",
   [DISPATCH_CMD_VertexAttrib4hvNV] = "VertexAttrib4hvNV",
   [DISPATCH_CMD_VertexAttribs1hvNV] = "VertexAttribs1hvNV",
   [DISPATCH_CMD_VertexAttribs2hvNV] = "VertexAttribs2hvNV",
   [DISPATCH_CMD_VertexAttribs3hvNV] = "VertexAttribs3hvNV",
   [DISPATCH_CMD_VertexAttribs4hvNV] = "VertexAttribs4hvNV",
   [DISPATCH_CMD_FogCoordhNV] = "FogCoordhNV",
   [DISPATCH_CMD_FogCoordhvNV] = "FogCoordhvNV",
   [DISPATCH_CMD_SecondaryColor3hNV] = "SecondaryColor3hNV",
   [DISPATCH_CMD_SecondaryColor3hvNV] = "SecondaryColor3hvNV",
   [DISPATCH_CMD_MemoryBarrierByRegion] = "MemoryBarrierByRegion",
   [DISPATCH_CMD_DrawMeshTasksEXT] = "DrawMeshTasksEXT",
   [DISPATCH_CMD_DrawMeshTasksIndirectEXT] = "DrawMeshTasksIndirectEXT",
   [DISPATCH_CMD_MultiDrawMeshTasksIndirectEXT] = "MultiDrawMeshTasksIndirectEXT",
   [DISPATCH_CMD_MultiDrawMeshTasksIndirectCountEXT] = "MultiDrawMeshTasksIndirectCountEXT",
   [DISPATCH_CMD_AlphaFuncx] = "AlphaFuncx",
   [DISPATCH_CMD_ClearColorx] = "ClearColorx",
   [DISPATCH_CMD_ClearDepthx] = "ClearDepthx",
   [DISPATCH_CMD_Color4x] = "Color4x",
   [DISPATCH_CMD_DepthRangex] = "DepthRangex",
   [DISPATCH_CMD_Fogx] = "Fogx",
   [DISPATCH_CMD_Fogxv] = "Fogxv",
   [DISPATCH_CMD_Frustumx] = "Frustumx",
   [DISPATCH_CMD_LightModelx] = "LightModelx",
   [DISPATCH_CMD_LightModelxv] = "LightModelxv",
   [DISPATCH_CMD_Lightx] = "Lightx",
   [DISPATCH_CMD_Lightxv] = "Lightxv",
   [DISPATCH_CMD_LineWidthx] = "LineWidthx",
   [DISPATCH_CMD_LoadMatrixx] = "LoadMatrixx",
   [DISPATCH_CMD_Materialx] = "Materialx",
   [DISPATCH_CMD_Materialxv] = "Materialxv",
   [DISPATCH_CMD_MultMatrixx] = "MultMatrixx",
   [DISPATCH_CMD_MultiTexCoord4x] = "MultiTexCoord4x",
   [DISPATCH_CMD_Normal3x] = "Normal3x",
   [DISPATCH_CMD_Orthox] = "Orthox",
   [DISPATCH_CMD_PointSizex] = "PointSizex",
   [DISPATCH_CMD_PolygonOffsetx] = "PolygonOffsetx",
   [DISPATCH_CMD_Rotatex] = "Rotatex",
   [DISPATCH_CMD_SampleCoveragex] = "SampleCoveragex",
   [DISPATCH_CMD_Scalex] = "Scalex",
   [DISPATCH_CMD_TexEnvx] = "TexEnvx",
   [DISPATCH_CMD_TexEnvxv] = "TexEnvxv",
   [DISPATCH_CMD_TexParameterx] = "TexParameterx",
   [DISPATCH_CMD_Translatex] = "Translatex",
   [DISPATCH_CMD_ClipPlanex] = "ClipPlanex",
   [DISPATCH_CMD_PointParameterx] = "PointParameterx",
   [DISPATCH_CMD_PointParameterxv] = "PointParameterxv",
   [DISPATCH_CMD_TexParameterxv] = "TexParameterxv",
   [DISPATCH_CMD_TexGenxOES] = "TexGenxOES",
   [DISPATCH_CMD_TexGenxvOES] = "TexGenxvOES",
   [DISPATCH_CMD_ClipPlanef] = "ClipPlanef",
   [DISPATCH_CMD_Frustumf] = "Frustumf",
   [DISPATCH_CMD_Orthof] = "Orthof",
   [DISPATCH_CMD_DrawTexiOES] = "DrawTexiOES",
   [DISPATCH_CMD_DrawTexivOES] = "DrawTexivOES",
   [DISPATCH_CMD_DrawTexfOES] = "DrawTexfOES",
   [DISPATCH_CMD_DrawTexfvOES] = "DrawTexfvOES",
   [DISPATCH_CMD_DrawTexsOES] = "DrawTexsOES",
   [DISPATCH_CMD_DrawTexsvOES] = "DrawTexsvOES",
   [DISPATCH_CMD_DrawTexxOES] = "DrawTexxOES",
   [DISPATCH_CMD_DrawTexxvOES] = "DrawTexxvOES",
   [DISPATCH_CMD_PointSizePointerOES] = "PointSizePointerOES",
   [DISPATCH_CMD_DiscardFramebufferEXT] = "DiscardFramebufferEXT",
   [DISPATCH_CMD_FramebufferTexture2DMultisampleEXT] = "FramebufferTexture2DMultisampleEXT",
   [DISPATCH_CMD_DepthRangeArrayfvOES] = "DepthRangeArrayfvOES",
   [DISPATCH_CMD_DepthRangeIndexedfOES] = "DepthRangeIndexedfOES",
   [DISPATCH_CMD_FramebufferParameteriMESA] = "FramebufferParameteriMESA",
};
